@@ -322,11 +322,11 @@ void TopLevel::setupActions()
 {
   // file menu...
   actSave = KStdAction::save(queryView, SLOT(saveQuery()), actionCollection());
-  actSave->setText("&Save...");
+  actSave->setText(i18n("&Save..."));
   actSave->setEnabled(false);
   actPrint = KStdAction::print(queryView, SLOT(printQuery()), actionCollection());
   actPrint->setEnabled(false);
-  actStartQuery = new KAction(i18n("St&art Query"),"redo", 0 , this,
+  actStartQuery = new KAction(i18n("St&art Query"),"reload", 0 , this,
                   SLOT(doDefine()), actionCollection(), "start_query");
   actStopQuery = new KAction(i18n("St&op Query"),"stop", 0 , this,
                  SLOT(stopClients()), actionCollection(), "stop_query");
@@ -386,7 +386,7 @@ void TopLevel::setupActions()
   new KAction(i18n("Clear Input Field"), "query_erase", 0 , this,
               SLOT(clearInput()), actionCollection(), "clear_query");
 
-  actQueryLabel = new DictLabelAction(i18n("&Look for"), actionCollection(), "look_label");
+  actQueryLabel = new DictLabelAction(i18n("&Look for:"), actionCollection(), "look_label");
   actQueryCombo = new DictComboAction(i18n("Query"), actionCollection(), "query_combo",true,true);
   connect(actQueryCombo,SIGNAL(activated(const QString &)), SLOT(define(const QString&)));
   actDbLabel = new DictLabelAction(i18n("&in"), actionCollection(), "in_label");
@@ -781,9 +781,7 @@ void TopLevel::showSetsDialog()
 void TopLevel::hideSetsDialog()
 {
   if (setsDlg) {
-    disconnect(setsDlg,SIGNAL(setsChanged()),this,SLOT(setsChanged()));
-    disconnect(setsDlg,SIGNAL(dialogClosed()),this,SLOT(hideSetsDialog()));
-    delete setsDlg;
+    setsDlg->delayedDestruct();
     setsDlg = 0L;
   }
 }
