@@ -2,7 +2,7 @@
 *                                kmainwidget.cpp
 *                             -------------------
 *
-*    Revision     : $Id: kmainwidget.cpp,v 1.65.2.3 2003/01/03 02:17:36 pfeiffer Exp $
+*    Revision     : $Id: kmainwidget.cpp,v 1.65.2.11 2003/06/20 12:53:50 pfeiffer Exp $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -47,6 +47,7 @@
 #include <qdropsite.h>
 #include <qpopupmenu.h>
 
+#include <kprotocolinfo.h>
 #include <kfiledialog.h>
 #include <kapplication.h>
 #include <kstandarddirs.h>
@@ -68,6 +69,7 @@
 #include <kconfig.h>
 #include <kio/netaccess.h>
 
+#include "safedelete.h"
 #include "settings.h"
 #include "transfer.h"
 #include "transferlist.h"
@@ -141,7 +143,7 @@ KMainWidget::KMainWidget(bool bStartDocked)
     logFileName = locateLocal("appdata", "logs/");
     logFileName += tmp;
 
-    lastClipboard = QApplication::clipboard()->text( QClipboard::Clipboard );
+    lastClipboard = QApplication::clipboard()->text( QClipboard::Clipboard ).stripWhiteSpace();
     // Load all settings from KConfig
     ksettings.load();
 
@@ -954,19 +956,18 @@ void KMainWidget::slotCheckClipboard()
     //sDebugIn << endl;
 #endif
 
-    QString clipData = QApplication::clipboard()->text();
+    QString clipData = QApplication::clipboard()->text( QClipboard::Clipboard ).stripWhiteSpace();
 
     if (clipData != lastClipboard) {
         sDebug << "New clipboard event" << endl;
 
         lastClipboard = clipData;
-        if (clipData.isEmpty() || clipData.stripWhiteSpace().isEmpty()) {
+        if ( lastClipboard.isEmpty() )
             return;
-        }
 
-        KURL url = KURL::fromPathOrURL(lastClipboard.stripWhiteSpace());
+        KURL url = KURL::fromPathOrURL( lastClipboard );
 
-        if (!url.isMalformed() && !url.isLocalFile() && ksettings.b_autoPaste)
+        if (!url.isMalformed() && !url.isLocalFile())
             slotPasteTransfer();
     }
 
@@ -1012,8 +1013,7 @@ void KMainWidget::slotPasteTransfer()
 
 // destFile must be a filename, not a directory! And it will be deleted, if
 // it exists already, without further notice.
-void KMainWidget::addTransferEx(const KURL& url, const KURL& destFile,
-                                bool bShowIndividual)
+void KMainWidget::addTransferEx(const KURL& url, const KURL& destFile)
 {
 #ifdef _DEBUG
     sDebugIn << endl;
@@ -1038,7 +1038,7 @@ void KMainWidget::addTransferEx(const KURL& url, const KURL& destFile,
             if (df.isEmpty()) {           // if we didn't provide destination
                 if (!b_expertMode) {
                     // open the filedialog for confirmation
-                    KFileDialog dlg( destDir, QString::null, 
+                    KFileDialog dlg( destDir, QString::null,
                                      0L, "save_as", true);
                     dlg.setCaption(i18n("Save As"));
                     dlg.setSelection(url.fileName());
@@ -1073,10 +1073,11 @@ void KMainWidget::addTransferEx(const KURL& url, const KURL& destFile,
 
             if(KIO::NetAccess::exists(destURL))
             {
-                if (KMessageBox::warningYesNo(this,i18n("Destination file already exists.\nDo you want to overwrite it?"))==KMessageBox::Yes)
+                if (KMessageBox::warningYesNo(this,i18n("Destination file \n%1\nalready exists.\nDo you want to overwrite it?").arg( destURL.prettyURL()) )
+                                              == KMessageBox::Yes)
                 {
                     bDestisMalformed=false;
-                    KIO::NetAccess::del(destURL);
+                    SafeDelete::deleteFile( destURL );
                 }
                 else
                 {
@@ -1095,14 +1096,14 @@ void KMainWidget::addTransferEx(const KURL& url, const KURL& destFile,
         // simply delete it, the calling process should have asked if you
         // really want to delete (at least khtml does)
         if(KIO::NetAccess::exists(destURL))
-            KIO::NetAccess::del(destURL);
+            SafeDelete::deleteFile( destURL );
     }
 
     // create a new transfer item
     Transfer *item = myTransferList->addTransfer(url, destURL);
     item->updateAll(); // update the remaining fields
 
-    if (bShowIndividual)
+    if (ksettings.b_showIndividual)
         item->showIndividual();
 
     myTransferList->clearSelection();
@@ -1141,17 +1142,26 @@ void KMainWidget::addTransfers( const KURL::List& src, const QString& destDir )
         {
             // create a proper destination file from destDir
             KURL destURL = KURL::fromPathOrURL( destDir );
-            destURL.adjustPath( +1 );
-            destURL.setFileName( urlsToDownload.first().fileName() );
-            if(KIO::NetAccess::exists(destURL))
+            QString fileName = urlsToDownload.first().fileName();
+
+            // in case the fileName is empty, we simply ask for a filename in
+            // addTransferEx. Do NOT attempt to use an empty filename, that
+            // would be a directory (and we don't want to overwrite that!)
+            if ( !fileName.isEmpty() )
             {
-                if (KMessageBox::warningYesNo(this,i18n("Destination file already exists.\nDo you want to overwrite it?"))==KMessageBox::Yes)
+                destURL.adjustPath( +1 );
+                destURL.setFileName( fileName );
+                if(KIO::NetAccess::exists(destURL))
                 {
-                    KIO::NetAccess::del(destURL);
+                    if (KMessageBox::warningYesNo(this,i18n("Destination file \n%1\nalready exists.\nDo you want to overwrite it?").arg( destURL.prettyURL()) )
+                        == KMessageBox::Yes)
+                {
+                        SafeDelete::deleteFile( destURL );
                     destFile = destURL;
                 }
             }
         }
+        }
 
         addTransferEx( urlsToDownload.first(), destFile );
         return;
@@ -1179,6 +1189,7 @@ void KMainWidget::addTransfers( const KURL::List& src, const QString& destDir )
     }
 
     // dest is now finally the real destination directory for all the files
+    dest.adjustPath( +1 );
 
     // create new transfer items
     KURL::List::ConstIterator it = urlsToDownload.begin();
@@ -1190,15 +1201,18 @@ void KMainWidget::addTransfers( const KURL::List& src, const QString& destDir )
             continue;
 
         KURL destURL = dest;
-        destURL.adjustPath( +1 );
-        destURL.setFileName( (*it).fileName() );
+        QString fileName = (*it).fileName();
+        if ( fileName.isEmpty() ) // simply use the full url as filename
+            fileName = KURL::encode_string_no_slash( (*it).prettyURL() );
+        
+        destURL.setFileName( fileName );
 
         if(KIO::NetAccess::exists(destURL))
         {
             if (KMessageBox::warningYesNo(this,i18n("Destination file already exists.\nDo you want to overwrite it?"))
                 == KMessageBox::Yes)
             {
-                KIO::NetAccess::del(destURL);
+                SafeDelete::deleteFile( destURL );
             }
         }
 
@@ -1334,7 +1348,7 @@ void KMainWidget::slotTransferTimeout()
     }
 
     if (ksettings.b_autoDisconnect && ksettings.b_timedDisconnect && ksettings.disconnectTime <= QTime::currentTime() && ksettings.disconnectDate == QDate::currentDate()) {
-        disconnect();
+        onlineDisconnect();
     }
 
 #ifdef _DEBUG
@@ -1377,7 +1391,7 @@ void KMainWidget::slotStatusChanged(Transfer * item, int _operation)
         if (myTransferList->isQueueEmpty()) {
             // no items in the TransferList or we have donwload all items
             if (ksettings.b_autoDisconnect)
-                disconnect();
+                onlineDisconnect();
 
             if (ksettings.b_autoShutdown) {
                 slotQuit();
@@ -1522,23 +1536,14 @@ void KMainWidget::slotOpenIndividual()
 #endif
 }
 
-void KMainWidget::closeEvent(QCloseEvent *_event)
+bool KMainWidget::queryClose()
 {
-#ifdef _DEBUG
-    sDebugIn<<"type="<<_event->type() << endl;
-#else
-    Q_UNUSED( _event )
-#endif
-
+    if( kapp->sessionSaving())
+	return true;
     hide();
-
-#ifdef _DEBUG
-    sDebugOut << endl;
-#endif
+    return false;
 }
 
-
-
 void KMainWidget::setAutoSave()
 {
 #ifdef _DEBUG
@@ -1792,8 +1797,10 @@ void KMainWidget::slotToggleAutoPaste()
 
     if (ksettings.b_autoPaste) {
         log(i18n("Auto paste on."));
+        clipboardTimer->start(1000);
     } else {
         log(i18n("Auto paste off."));
+        clipboardTimer->stop();
     }
     m_paAutoPaste->setChecked(ksettings.b_autoPaste);
 
@@ -1809,10 +1816,13 @@ void KMainWidget::slotToggleDropTarget()
     sDebugIn << endl;
 #endif
 
-    if (m_paDropTarget->isChecked())
+    if (m_paDropTarget->isChecked()) {
         kdrop->show();
-    else
+        kdrop->updateStickyState();
+    }
+    else {
         kdrop->hide();
+    }
 
 
 #ifdef _DEBUG
@@ -2063,7 +2073,7 @@ void KMainWidget::updateStatusBar()
 }
 
 
-void KMainWidget::disconnect()
+void KMainWidget::onlineDisconnect()
 {
 #ifdef _DEBUG
     sDebugIn << endl;
@@ -2309,7 +2319,7 @@ QString KMainWidget::getSaveDirectoryFor( const QString& filename ) const
 
 bool KMainWidget::sanityChecksSuccessful( const KURL& url )
 {
-    if (url.isMalformed())
+    if (url.isMalformed() || !KProtocolInfo::supportsReading( url ) )
     {
         if (!ksettings.b_expertMode)
             KMessageBox::error(this, i18n("Malformed URL:\n%1").arg(url.prettyURL()), i18n("Error"));
@@ -2359,4 +2369,29 @@ bool KMainWidget::sanityChecksSuccessful( const KURL& url )
     return true;
 }
 
+bool KMainWidget::isDropTargetVisible() const
+{
+    return m_paDropTarget->isChecked();
+}
+
+void KMainWidget::setDropTargetVisible( bool setVisible )
+{
+    if ( setVisible != isDropTargetVisible() )
+    {
+        m_paDropTarget->setChecked( !m_paDropTarget->isChecked() );
+        slotToggleDropTarget();
+    }
+}
+
+void KMainWidget::setOfflineMode( bool offline )
+{
+    if ( ksettings.b_offlineMode != offline )
+        slotToggleOfflineMode();
+}
+
+bool KMainWidget::isOfflineMode() const
+{
+    return ksettings.b_offlineMode;
+}
+
 #include "kmainwidget.moc"
