@@ -2,7 +2,7 @@
 *                                transferlist.cpp
 *                             -------------------
 *
-*    Revision     : $Id: transferlist.cpp,v 1.19.2.1 2002/12/10 02:03:58 pfeiffer Exp $
+*    Revision     : $Id: transferlist.cpp,v 1.19.2.3 2003/07/22 21:22:57 deller Exp $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -122,7 +122,7 @@ TransferList::~TransferList()
 }
 
 
-Transfer *TransferList::addTransfer(const KURL & _source, const KURL & _dest, 
+Transfer *TransferList::addTransfer(const KURL & _source, const KURL & _dest,
                                     bool canShow)
 {
     Transfer *last = static_cast<Transfer*>( lastItem() );
@@ -162,18 +162,16 @@ void TransferList::setSelected(QListViewItem * item, bool selected)
 
 void TransferList::moveToBegin(Transfer * item)
 {
-    TransferIterator it(this);
-
     //        ASSERT(item);
 
-    Transfer *new_item = new Transfer(this, item->getSrc(), item->getDest());
+    item->synchronousAbort();
 
+    Transfer *new_item = new Transfer(this, item->getSrc(), item->getDest());
     new_item->copy(item);
 
     delete item;
 
     clearSelection();
-    new_item->updateAll();
 }
 
 
@@ -181,6 +179,8 @@ void TransferList::moveToEnd(Transfer * item)
 {
     //        ASSERT(item);
 
+    item->synchronousAbort();
+
     Transfer *last = static_cast<Transfer*>( lastItem() );
     Transfer *new_item = new Transfer(this, last, item->getSrc(), item->getDest());
     new_item->copy(item);
@@ -188,7 +188,6 @@ void TransferList::moveToEnd(Transfer * item)
     delete item;
 
     clearSelection();
-    new_item->updateAll();
 }
 
 
@@ -255,15 +254,15 @@ void TransferList::readTransfers(const KURL& file)
             str.sprintf("Item%d", i);
             config.setGroup(str);
 
-            src  = KURL::fromPathOrURL( config.readEntry("Source") );
-            dest = KURL::fromPathOrURL( config.readEntry("Dest") );
+            src  = KURL::fromPathOrURL( config.readPathEntry("Source") );
+            dest = KURL::fromPathOrURL( config.readPathEntry("Dest") );
             item = addTransfer( src, dest, false ); // don't show!
 
             if (!item->read(&config, i))
                 delete item;
-            else 
+            else
             {
-                // configuration read, now we know the status to determine 
+                // configuration read, now we know the status to determine
                 // whether to show or not
                 item->maybeShow();
             }
