@@ -134,7 +134,7 @@ void AwayPicker::mAwayTextChanged(void)
 void AwayPicker::mRenAwayClicked(void)
 {
 	CHOOSE_FIRST(mAwayList, i18n("Choose a message first."));
-	KLineEditDlg lineDialog(i18n("Enter a new name for the message."), mAwayList->currentText(), this);
+	KLineEditDlg lineDialog(i18n("Enter a new name for the message:"), mAwayList->currentText(), this);
 	if(lineDialog.exec() != Accepted) return;
 
 	awayMessageNames[mAwayList->currentItem()] = lineDialog.text();
@@ -142,7 +142,7 @@ void AwayPicker::mRenAwayClicked(void)
 }
 void AwayPicker::mAddAwayClicked(void)
 {
-	KLineEditDlg lineDialog(i18n("Enter a name for the new away message."), QString::null, this);
+	KLineEditDlg lineDialog(i18n("Enter a name for the new away message:"), QString::null, this);
 	if(lineDialog.exec() != Accepted) return;
 
 	awayMessageNames += lineDialog.text();
