@@ -37,20 +37,20 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 	QVBox *uBox = addVBoxPage(i18n("User Information")); PE_SETUPBOX(uBox);
 
 	QHBox *uNameBox = new QHBox(uBox); PE_SETUPBOX(uNameBox);
-	new QLabel(i18n("Screen Name"), uNameBox);
+	new QLabel(i18n("Screen name:"), uNameBox);
 	uName = new KLineEdit(uNameBox);
 	uName->setMaxLength(30);
-	new QLabel(i18n("Password"), uNameBox);
+	new QLabel(i18n("Password:"), uNameBox);
 	uPwd = new KLineEdit(uNameBox);
 	uPwd->setMaxLength(30);
 	uPwd->setEchoMode(KLineEdit::Password);
 
-	uSave = new QCheckBox(i18n("Save Password"), uBox);
+	uSave = new QCheckBox(i18n("Save password"), uBox);
 
 	QVBox *uInfoBox = new QVBox(uBox); PE_SETUPBOX(uInfoBox);
-	new QLabel(i18n("User Information"), uInfoBox);
+	new QLabel(i18n("User information:"), uInfoBox);
 	uInfo = new KEdit(uInfoBox);
-	
+
 	// *******************************************
 	// Part 2 : buddy (l)ist information
 	// listinfo parts, tab 4 parts
@@ -61,9 +61,9 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 
 	QHBox *lGroupBox = new QHBox(lBox1); PE_SETUPBOX(lGroupBox);
 	KButtonBox *lGroupBBox = new KButtonBox(lGroupBox, Qt::Vertical);
-	QButton *lAddGroup = lGroupBBox->addButton(i18n("Add"));
+	QButton *lAddGroup = lGroupBBox->addButton(i18n("Add..."));
 	QButton *lDelGroup = lGroupBBox->addButton(i18n("Remove"));
-	QButton *lRenGroup = lGroupBBox->addButton(i18n("Rename"));
+	QButton *lRenGroup = lGroupBBox->addButton(i18n("Rename..."));
 	lGroupBBox->layout();
 	lGroup = new QListBox(lGroupBox);
 
@@ -72,7 +72,7 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 
 	QHBox *lBuddyBox = new QHBox(lBox2); PE_SETUPBOX(lBuddyBox);
 	KButtonBox *lBuddyBBox = new KButtonBox(lBuddyBox, Qt::Vertical);
-	QButton *lAddBuddy = lBuddyBBox->addButton(i18n("Add"));
+	QButton *lAddBuddy = lBuddyBBox->addButton(i18n("Add..."));
 	QButton *lDelBuddy = lBuddyBBox->addButton(i18n("Remove"));
 	lBuddyBBox->layout();
 	lBuddy = new QListBox(lBuddyBox);
@@ -88,7 +88,7 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 
 	QHBox *pPermitBox = new QHBox(pBox1); PE_SETUPBOX(pPermitBox);
 	KButtonBox *pPermitBBox = new KButtonBox(pPermitBox, Qt::Vertical);
-	QButton *pAddPermit = pPermitBBox->addButton(i18n("Add"));
+	QButton *pAddPermit = pPermitBBox->addButton(i18n("Add..."));
 	QButton *pDelPermit = pPermitBBox->addButton(i18n("Remove"));
 	pPermitBBox->layout();
 	pPermit = new QListBox(pPermitBox);
@@ -98,7 +98,7 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 
 	QHBox *pDenyBox = new QHBox(pBox2); PE_SETUPBOX(pDenyBox);
 	KButtonBox *pDenyBBox = new KButtonBox(pDenyBox, Qt::Vertical);
-	QButton *pAddDeny = pDenyBBox->addButton(i18n("Add"));
+	QButton *pAddDeny = pDenyBBox->addButton(i18n("Add..."));
 	QButton *pDelDeny = pDenyBBox->addButton(i18n("Remove"));
 	pDenyBBox->layout();
 	pDeny = new QListBox(pDenyBox);
@@ -106,10 +106,10 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 	pState = new QButtonGroup(2, Vertical, i18n("Permission Setting"), pBox);
 	pState->setMargin( marginHint() );
 	pState->setExclusive(true);
-	new QRadioButton(i18n("Permit All"), pState);
-	new QRadioButton(i18n("Use Permit List"), pState);
-	new QRadioButton(i18n("Deny All"), pState);
-	new QRadioButton(i18n("Use Deny List"), pState);
+	new QRadioButton(i18n("Permit all"), pState);
+	new QRadioButton(i18n("Use permit list"), pState);
+	new QRadioButton(i18n("Deny all"), pState);
+	new QRadioButton(i18n("Use deny list"), pState);
 
 	QVBoxLayout *pLayout = new QVBoxLayout(pBox, marginHint(), spacingHint());
 	pLayout->addWidget(pBoxRoot, true);
@@ -124,9 +124,9 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 
 	QHBox *mListBox = new QHBox(mBox1); PE_SETUPBOX(mListBox);
 	KButtonBox *mListBBox = new KButtonBox(mListBox, Qt::Vertical);
-	QButton *mAddAway = mListBBox->addButton(i18n("Add"));
+	QButton *mAddAway = mListBBox->addButton(i18n("Add..."));
 	QButton *mDelAway = mListBBox->addButton(i18n("Remove"));
-	QButton *mRenAway = mListBBox->addButton(i18n("Rename"));
+	QButton *mRenAway = mListBBox->addButton(i18n("Rename..."));
 	mListBBox->layout();
 	mAwayList = new QListBox(mListBox);
 
@@ -139,18 +139,18 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 	// tab 1
 	QFrame *aBox = addPage(i18n("Main Window"));
 
-	aHide = new QCheckBox(i18n("Hide Window on Start"), aBox);
+	aHide = new QCheckBox(i18n("Hide window on start"), aBox);
 	
 	QButtonGroup *aColumns = new QButtonGroup(2, Vertical, i18n("Display Columns"), aBox);
 	aColumns->setMargin( marginHint() );
 	aColumns->setExclusive(false);
-	aIdle = new QCheckBox(i18n("Idle Time"), aColumns);
-	aClass = new QCheckBox(i18n("User Class"), aColumns);
-	aWarn = new QCheckBox(i18n("Warning Level"), aColumns);
-	aSignon = new QCheckBox(i18n("Signon Time"), aColumns);
+	aIdle = new QCheckBox(i18n("Idle time"), aColumns);
+	aClass = new QCheckBox(i18n("User class"), aColumns);
+	aWarn = new QCheckBox(i18n("Warning level"), aColumns);
+	aSignon = new QCheckBox(i18n("Sign-on time"), aColumns);
 	aNick = new QCheckBox(i18n("Nickname"), aColumns);
 
-	aGrouping = new QButtonGroup(2, Horizontal, i18n("Show Buddies by"), aBox);
+	aGrouping = new QButtonGroup(2, Horizontal, i18n("Show Buddies By"), aBox);
 	aGrouping->setMargin( marginHint() );
 	aGrouping->setExclusive(true);
 	new QRadioButton(i18n("Group"), aGrouping);
@@ -166,18 +166,18 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 	// tab 2, tab 4 parts
 	QFrame *bBox = addPage(i18n("Chat Windows"));
 
-	bLog = new QCheckBox(i18n("Log Chats"), bBox);
-	bTimestamp = new QCheckBox(i18n("Timestamp Chats"), bBox);
-	bICQ = new QCheckBox(i18n("ICQ Mode (no HTML sent)"), bBox);
+	bLog = new QCheckBox(i18n("Log chats"), bBox);
+	bTimestamp = new QCheckBox(i18n("Timestamp chats"), bBox);
+	bICQ = new QCheckBox(i18n("ICQ mode (no HTML sent)"), bBox);
 
 	QVGroupBox *bText = new QVGroupBox(bBox);
 	bText->setMargin(marginHint());
 	bText->setFrameStyle(QFrame::Box | QFrame::Sunken);
-	bText->setTitle(i18n("My message appearance"));
+	bText->setTitle(i18n("My Message Appearance"));
 	QHBox *bColor = new QHBox(bText); PE_SETUPBOX(bColor);
-	new QLabel(i18n("Text Color"), bColor);
+	new QLabel(i18n("Text color:"), bColor);
 	bForeground = new KColorButton(bColor);
-	new QLabel(i18n("Background Color"), bColor);
+	new QLabel(i18n("Background color:"), bColor);
 	bBackground = new KColorButton(bColor);
 	bBold = new QCheckBox(i18n("Bold"), bText);
 
@@ -192,8 +192,8 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 	// tab 3
 	QFrame *nBox = addPage(i18n("Network"));
 
-	nKeepAlive = new QCheckBox(i18n("Keep Connection Alive"), nBox);
-	nAutoConnect = new QCheckBox(i18n("Automatically Connect on Startup"), nBox);
+	nKeepAlive = new QCheckBox(i18n("Keep connection alive"), nBox);
+	nAutoConnect = new QCheckBox(i18n("Automatically connect on startup"), nBox);
 
 	// ******* Server
 	QVGroupBox *nBigServerBox = new QVGroupBox(nBox);
@@ -203,7 +203,7 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 
 	nUseCustom = new QCheckBox(i18n("Specify custom server, rather than default (AOL) server"), nBigServerBox);
 	QHBox *nServerBox = new QHBox(nBigServerBox); PE_SETUPBOX(nServerBox);
-	new QLabel(i18n("TOC Server and port"), nServerBox);
+	new QLabel(i18n("TOC server and port:"), nServerBox);
 	nServer = new QLineEdit(nServerBox);
 	nServerPort = new KRestrictedLine(nServerBox);
 	nServerPort->setValidChars("0123456789\t");
@@ -211,7 +211,7 @@ ProfileEditor::ProfileEditor(KitUserProfile *parent, const char *name)
 	nServerPort->setFixedWidth(50);
 
 	QHBox *nAuthBox = new QHBox(nBigServerBox); PE_SETUPBOX(nAuthBox);
-	new QLabel(i18n("Authorisation server"), nAuthBox);
+	new QLabel(i18n("Authorization server:"), nAuthBox);
 	nAuth = new QLineEdit(nAuthBox);
 	nAuthPort = new KRestrictedLine(nAuthBox);
 	nAuthPort->setValidChars("0123456789\t");
@@ -451,7 +451,7 @@ void ProfileEditor::mAwayTextChanged(void)
 
 void ProfileEditor::lAddGroupClicked(void)
 {
-	KLineEditDlg lineDialog(i18n("Enter the name of the group to add."), QString::null, this);
+	KLineEditDlg lineDialog(i18n("Enter the name of the group to add:"), QString::null, this);
 	if(lineDialog.exec() != Accepted) return;
 
 	QString name = lineDialog.text();
@@ -465,7 +465,7 @@ void ProfileEditor::lAddGroupClicked(void)
 void ProfileEditor::lRenGroupClicked(void)
 {
 	CHOOSE_FIRST(lGroup, i18n("Choose a group first."));
-	KLineEditDlg lineDialog(i18n("Enter a new name for the group."), lGroup->currentText(), this);
+	KLineEditDlg lineDialog(i18n("Enter a new name for the group:"), lGroup->currentText(), this);
 	if(lineDialog.exec() != Accepted) return;
 
 	QString name = lineDialog.text();
@@ -488,7 +488,7 @@ void ProfileEditor::lDelGroupClicked(void)
 void ProfileEditor::lAddBuddyClicked(void)
 {
 	CHOOSE_FIRST(lGroup, i18n("Choose a group first."));
-	KLineEditDlg lineDialog(i18n("Enter the name to add to group %1").arg(lGroup->currentText()), QString::null, this);
+	KLineEditDlg lineDialog(i18n("Enter the name to add to group %1:").arg(lGroup->currentText()), QString::null, this);
 	if(lineDialog.exec() != Accepted) return;
 
 	QString name = lineDialog.text();
@@ -513,7 +513,7 @@ void ProfileEditor::lDelBuddyClicked(void)
 }
 void ProfileEditor::pAddPermitClicked(void)
 {
-	KLineEditDlg lineDialog(i18n("Enter the name to add to your permit list."), QString::null, this);
+	KLineEditDlg lineDialog(i18n("Enter the name to add to your permit list:"), QString::null, this);
 	if(lineDialog.exec() != Accepted) return;
 
 	QString name = lineDialog.text();
@@ -538,7 +538,7 @@ void ProfileEditor::pDelPermitClicked(void)
 }
 void ProfileEditor::pAddDenyClicked(void)
 {
-	KLineEditDlg lineDialog(i18n("Enter the name to add to your deny list."), QString::null, this);
+	KLineEditDlg lineDialog(i18n("Enter the name to add to your deny list:"), QString::null, this);
 	if(lineDialog.exec() != Accepted) return;
 
 	QString name = lineDialog.text();
@@ -564,7 +564,7 @@ void ProfileEditor::pDelDenyClicked(void)
 void ProfileEditor::mRenAwayClicked(void)
 {
 	CHOOSE_FIRST(mAwayList, i18n("Choose a message first."));
-	KLineEditDlg lineDialog(i18n("Enter a new name for the message."), mAwayList->currentText(), this);
+	KLineEditDlg lineDialog(i18n("Enter a new name for the message:"), mAwayList->currentText(), this);
 	if(lineDialog.exec() != Accepted) return;
 
 	awayMessageNames[mAwayList->currentItem()] = lineDialog.text();
@@ -572,7 +572,7 @@ void ProfileEditor::mRenAwayClicked(void)
 }
 void ProfileEditor::mAddAwayClicked(void)
 {
-	KLineEditDlg lineDialog(i18n("Enter a name for the new away message."), QString::null, this);
+	KLineEditDlg lineDialog(i18n("Enter a name for the new away message:"), QString::null, this);
 	if(lineDialog.exec() != Accepted) return;
 
 	awayMessageNames += lineDialog.text();
