@@ -30,6 +30,7 @@ struct KitUserData
 	int savePassword;
 
 	int keepAlive;
+	bool autoConnect;
 	int useCustomServer;
 	QString server;
 	int serverPort;
@@ -58,12 +59,6 @@ struct KitUserData
 	bool bold;
 	int fontSize;
 	bool icqMode;
-
-	bool useSocks;
-	bool useSocksAuth;
-	QString socksServer;
-	unsigned short socksPort;
-	QString socksName, socksPassword;
 };
 
 class KitUserProfile : public QObject
