@@ -7,31 +7,67 @@
 #include "config.h"
 
 #include <kaction.h>
-#include <kglobalsettings.h>
-#include <kglobal.h>
 #include <kcolorbutton.h>
 #include <kcolordialog.h>
+#include <kdebug.h>
 #include <kfile.h>
-#include <kiconloader.h>
-#include <ktextedit.h>
+#include <kglobalsettings.h>
+#include <kglobal.h>
 #include <khtmlview.h>
-#include <kmenubar.h>
-#include <knotifyclient.h>
-#include <kstandarddirs.h>
-#include <kpopupmenu.h>
-#include <kmessagebox.h>
+#include <kiconloader.h>
 #include <klocale.h>
+#include <kmenubar.h>
+#include <kmessagebox.h>
+#include <knotifyclient.h>
+#include <kpopupmenu.h>
+#include <kstandarddirs.h>
+#include <ktextedit.h>
 #include <qlayout.h>
 #include <qtextcodec.h>
 #include <qvbox.h>
-#include <kdebug.h>
 
 #include "aim.h"
 #include "kitapp.h"
 #include "kithtmlpart.h"
 #include "tmessage.h"
 
-// helper functions
+QString htmlEscape(QString string)
+{
+	string.replace('&', "&amp;");
+	string.replace('<', "&lt;");
+	string.replace('>', "&gt;");
+	return string;
+}
+
+QString htmlQuote(QString string)
+{
+	string = htmlEscape(string);
+	string.replace('"', "\\\"");
+	string = QString("\"%1\"").arg(string);
+	return string;
+}
+
+QString htmlFont(const QFont &font)
+{
+	QString fontString;
+
+	if(font.italic())
+		fontString += "font-style: italic;\n";
+
+	fontString += QString("font-weight: %1;\n").arg(font.weight() * 10);
+
+	if(font.pointSize() != -1)
+		fontString += QString("font-size: %1pt;\n").arg(font.pointSize());
+	else if(font.pixelSize() != -1)
+		fontString += QString("font-size: %1px;\n").arg(font.pixelSize());
+	else
+		fontString += QString("font-size: %1pt;\n").arg(font.pointSizeFloat());
+
+	fontString += QString("font-family: %1;\n").arg(htmlQuote(font.family()));
+
+	return fontString;
+}
+
 inline bool tagIsOpen(const QString &html, const QString &tag)
 {
 	return html.contains("<" + tag, false) > html.contains("</" + tag + ">", false);
@@ -134,7 +170,7 @@ QString stripTags(const QString &oldstr)
 	// 3) replace <body> with <div>, inserting a STYLE= value to apply text and
 	// background colors
 	bodyPos = newstr.find("<BODY BGCOLOR=");
-	if(bodyPos != -1) newstr.replace(bodyPos, 15, "<span STYLE=\"font-style: normal; background: ");
+	if(bodyPos != -1) newstr.replace(bodyPos, 15, "<span style=\"font-style: normal; background: ");
 	// merge font in with span
 	if(bodyPos != -1) newstr.replace(QRegExp(">\\w*<\\w*font", false), "" );
 	// 3b) remove </body>
@@ -250,7 +286,7 @@ TMessage::~TMessage()
 void TMessage::messageIn(const QString &message, bool isAuto)
 {
 	if(useSound)
-		KNotifyClient::event("Message Received");
+		KNotifyClient::event( 0, "Message Received");
 	updateHTML(message, displayName, "0000FF", isAuto);
 	sendAuto();
 }
@@ -365,7 +401,7 @@ void TMessage::send(void)
 	}
 	// press on
 	if(useSound)
-		KNotifyClient::event("Message Sent");
+		KNotifyClient::event( 0, "Message Sent");
 }
 void TMessage::sendAuto(void)
 {
@@ -373,7 +409,7 @@ void TMessage::sendAuto(void)
 	if(!isAway) return;
 	awayMessageSent = true;
 	if(useSound)
-		KNotifyClient::event("Message Sent");
+		KNotifyClient::event(0, "Message Sent");
 	emit messageOut(awayMessage, name, true);
 	updateHTML(awayMessage, myName, "FF0000", true);
 }
@@ -543,7 +579,7 @@ void TMessage::openLogFile(void)
 }
 void TMessage::initializeHTML()
 {
-	conversationBuffer = QString("<HTML><HEAD><TITLE>") + displayName + QString("</TITLE></HEAD><BODY BGCOLOR=\"#FFFFFF\">");
+	conversationBuffer = QString("<html><head><style type=\"text/css\">p {margin: .3em; ") + htmlFont(KGlobalSettings::generalFont()) + QString("} body: {background-color: #ffffff;} }</style><title>") + displayName + QString("</title></head><body>");
 	conversationLength = 0;
 	htmlpart->begin();
 	// do this so khtml picks up the default encoding
