@@ -229,6 +229,7 @@ AccountDialog::AccountDialog( const QString & caption, KMAccount *account,
   : KDialogBase( parent, name, modal, caption, Ok|Cancel|Help, Ok, true ),
     mAccount(account)
 {
+  mValidator = new QRegExpValidator( QRegExp( "[A-Za-z0-9-_:.]*" ), 0 );
   mServerTest = 0;
   setHelp("receiving-mail");
 
@@ -262,7 +263,10 @@ AccountDialog::AccountDialog( const QString & caption, KMAccount *account,
 
 AccountDialog::~AccountDialog()
 {
+  delete mValidator;
+  mValidator = 0;
   delete mServerTest;
+  mServerTest = 0;
 }
 
 void AccountDialog::makeLocalAccountPage()
@@ -502,8 +506,7 @@ void AccountDialog::makePopAccountPage()
   mPop.hostEdit = new QLineEdit( page1 );
   // only letters, digits, '-', '.', ':' (IPv6) and '_' (for Windows
   // compatibility) are allowed
-  mPop.hostEdit->setValidator(
-    new QRegExpValidator( QRegExp( "[A-Za-z0-9-_:.]*" ), 0 ) );
+  mPop.hostEdit->setValidator(mValidator);
   label->setBuddy( mPop.hostEdit );
   grid->addWidget( mPop.hostEdit, 3, 1 );
 
@@ -673,8 +676,7 @@ void AccountDialog::makeImapAccountPage()
   mImap.hostEdit = new QLineEdit( page1 );
   // only letters, digits, '-', '.', ':' (IPv6) and '_' (for Windows
   // compatibility) are allowed
-  mImap.hostEdit->setValidator(
-    new QRegExpValidator( QRegExp( "[A-Za-z0-9-_:.]*" ), 0 ) );
+  mImap.hostEdit->setValidator(mValidator);
   label->setBuddy( mImap.hostEdit );
   grid->addWidget( mImap.hostEdit, 3, 1 );
 
