@@ -727,6 +727,7 @@ public:
 
   void setup();
   void apply();
+
   void installProfile( KConfig * profile );
 
 protected:
@@ -764,6 +765,7 @@ class SecurityPageCryptPlugTab : public ConfigurationPage
   Q_OBJECT
 public:
   SecurityPageCryptPlugTab( QWidget * parent = 0, const char* name = 0 );
+  ~SecurityPageCryptPlugTab();
 
   // no icons:
   static QString iconLabel() { return QString::null; }
@@ -774,6 +776,7 @@ public:
 
   void setup();
   void apply();
+  void dismiss();
   //void savePluginsConfig( bool silent );
 
 public slots:
@@ -799,6 +802,7 @@ private:
   QLineEdit     *mNameEdit;
   KURLRequester *mLocationRequester;
   QLineEdit     *mUpdateURLEdit;
+  CryptPlugWrapperList *mlistCryptoAdd;
 };
 
 class SecurityPage : public TabbedConfigurationPage {
@@ -814,7 +818,7 @@ public:
   // OpenPGP tab is special:
   void setup();
   void apply();
-  void dismiss() {}
+  void dismiss();
   void installProfile( KConfig * profile );
 
   typedef SecurityPageGeneralTab GeneralTab;
