@@ -124,10 +124,10 @@ void KMAccount::readConfig(KConfig& config)
   QString folderName;
 
   mFolder = 0;
-  folderName = config.readEntry("Folder", "");
+  folderName = config.readEntry("Folder");
   setCheckInterval(config.readNumEntry("check-interval", 0));
   setCheckExclude(config.readBoolEntry("check-exclude", false));
-  setPrecommand(config.readEntry("precommand"));
+  setPrecommand(config.readPathEntry("precommand"));
 
   if (!folderName.isEmpty())
   {
