@@ -12,6 +12,7 @@
 #include <qsignal.h>
 #include <qguardedptr.h>
 #include <kprocess.h>
+#include <kdeversion.h>
 
 class KMAcctMgr;
 class KMFolder;
@@ -36,7 +37,11 @@ signals:
   void finished(bool);
 
 protected:
+#if KDE_VERSION >= 306
+  KProcess mPrecommandProcess;
+#else
   KShellProcess mPrecommandProcess;
+#endif
   QString mPrecommand;
 };
 
@@ -60,7 +65,7 @@ public:
   /**
    * Returns account name
    */
-  const QString& name(void) const { return mName; }
+  QString name(void) const { return mName; }
   virtual void setName(const QString&);
 
   /**
@@ -114,7 +119,7 @@ public:
   /**
    * This can be used to provide a more complex calculation later if we want
    */
-  inline const int defaultCheckInterval(void) const { return DefaultCheckInterval; }
+  inline int defaultCheckInterval(void) const { return DefaultCheckInterval; }
 
   /**
    * Set/get whether account should be part of the accounts checked
