@@ -175,7 +175,7 @@ void KMAcctExpPop::readConfig(KConfig& config)
   KMAcctExpPopInherited::readConfig(config);
 
 
-  mLogin = config.readEntry("login", "");
+  mLogin = config.readEntry("login");
   mUseSSL = config.readNumEntry("use-ssl", FALSE);
   mUseTLS = config.readNumEntry("use-tls", FALSE);
   mAuth = config.readEntry("auth", "USER");
