@@ -142,7 +142,7 @@ void KMAcctImap::readConfig(KConfig& config)
 {
   KMAcctImapInherited::readConfig(config);
 
-  mLogin = config.readEntry("login", "");
+  mLogin = config.readEntry("login");
   mStorePasswd = config.readNumEntry("store-passwd", FALSE);
   if (mStorePasswd)
   {
