@@ -247,12 +247,12 @@ if( fileD0.open( IO_WriteOnly ) ) {
 void KMAcctLocal::readConfig(KConfig& config)
 {
   KMAcctLocalInherited::readConfig(config);
-  mLocation = config.readEntry("Location", mLocation);
+  mLocation = config.readPathEntry("Location", mLocation);
   QString locktype = config.readEntry("LockType", "procmail_lockfile" );
 
   if( locktype == "procmail_lockfile" ) {
     mLock = procmail_lockfile;
-    mProcmailLockFileName = config.readEntry("ProcmailLockFile",
+    mProcmailLockFileName = config.readPathEntry("ProcmailLockFile",
       mLocation + ".lock");
   } else if( locktype == "mutt_dotlock" )
     mLock = mutt_dotlock;
