@@ -222,7 +222,7 @@ void KMAcctMaildir::processNewMail(bool)
 void KMAcctMaildir::readConfig(KConfig& config)
 {
   KMAcctMaildirInherited::readConfig(config);
-  mLocation = config.readEntry("Location", mLocation);
+  mLocation = config.readPathEntry("Location", mLocation);
 }
 
 
