@@ -704,6 +704,7 @@ protected:
   QPopupMenu *mAttachMenu;
   bool mAutoSign, mAutoPgpSign, mAutoPgpEncrypt, mAutoDeleteMsg;
   bool mLastSignActionState, mLastEncryptActionState;
+  bool mLastIdentityHasOpenPgpKey;
   KMFolder *mFolder;
   long mShowHeaders;
   QString mExtEditor;
@@ -724,6 +725,7 @@ protected:
   uint mId;
   QString mOldSigText;
   QStringList mTransportHistory;
+  QString mBcc;
 
   KAction *attachPK, *attachMPK,
           *attachRemoveAction, *attachSaveAction, *attachPropertiesAction;
