@@ -4,6 +4,7 @@
 #include "kmfiltermgr.h"
 
 // other kmail headers
+#include "kmfilter.h"
 #include "kmfilterdlg.h"
 
 // other KDE headers
@@ -14,20 +15,22 @@
 #include <qregexp.h>
 #include <qstringlist.h>
 #include <qstring.h>
+#include <qfile.h>
 
 // other headers
 #include <assert.h>
 
 
 //-----------------------------------------------------------------------------
-KMFilterMgr::KMFilterMgr(bool popFilter): KMFilterMgrInherited(),
-  bPopFilter(popFilter)
+KMFilterMgr::KMFilterMgr( bool popFilter )
+  : QPtrList<KMFilter>(),
+    mEditDialog( 0 ),
+    bPopFilter( popFilter ),
+    mShowLater( false )
 {
   if (bPopFilter)
     kdDebug(5006) << "pPopFilter set" << endl;
   setAutoDelete(TRUE);
-  mEditDialog = NULL;
-  mShowLater = false;
 }
 
 
@@ -43,9 +46,8 @@ KMFilterMgr::~KMFilterMgr()
 void KMFilterMgr::readConfig(void)
 {
   KConfig* config = kapp->config();
-  int i, numFilters;
+  int numFilters;
   QString grpName;
-  KMFilter* filter;
 
   clear();
 
@@ -58,10 +60,10 @@ void KMFilterMgr::readConfig(void)
     numFilters = config->readNumEntry("filters",0);
   }
 
-  for (i=0; i<numFilters; i++) {
+  for ( int i=0 ; i < numFilters ; ++i ) {
     grpName.sprintf("%s #%d", (bPopFilter ? "PopFilter" : "Filter") , i);
     KConfigGroupSaver saver(config, grpName);
-    filter = new KMFilter(config, bPopFilter);
+    KMFilter * filter = new KMFilter(config, bPopFilter);
     filter->purify();
     if ( filter->isEmpty() ) {
       kdDebug(5006) << "KMFilter::readConfig: filter\n" << filter->asString()
@@ -113,6 +115,14 @@ void KMFilterMgr::writeConfig(bool withSync)
 //-----------------------------------------------------------------------------
 int KMFilterMgr::process(KMMessage* msg, FilterSet aSet)
 {
+/*
+QFile fileD0( "testdat_xx-kmfiltermngr-0" );
+if( fileD0.open( IO_WriteOnly ) ) {
+    QDataStream ds( &fileD0 );
+    ds.writeRawBytes( msg->asString(), msg->asString().length() );
+    fileD0.close();  // If data is 0 we just create a zero length file.
+}
+*/
   if(bPopFilter) {
     QPtrListIterator<KMFilter> it(*this);
     for (it.toFirst() ; it.current() ; ++it) {
@@ -173,7 +183,14 @@ int KMFilterMgr::process(KMMessage* msg, FilterSet aSet)
     // readd the message if it wasn't moved:
     if ( msgTaken && parent && !msg->parent() )
       parent->addMsg( msg );
-
+/*
+QFile fileD1( "testdat_xx-kmfiltermngr-1" );
+if( fileD1.open( IO_WriteOnly ) ) {
+    QDataStream ds( &fileD1 );
+    ds.writeRawBytes( msg->asString(), msg->asString().length() );
+    fileD1.close();  // If data is 0 we just create a zero length file.
+}
+*/
     if (status < 0) // No filters matched, keep copy of message
       status = 1;
 
@@ -196,18 +213,18 @@ void KMFilterMgr::cleanup(void)
 //-----------------------------------------------------------------------------
 int KMFilterMgr::tempOpenFolder(KMFolder* aFolder)
 {
-  assert(aFolder!=NULL);
+  assert( aFolder );
 
   int rc = aFolder->open();
   if (rc) return rc;
 
-  mOpenFolders.append(aFolder);
-  return rc;
+  mOpenFolders.append( aFolder );
+  return 0;
 }
 
 
 //-----------------------------------------------------------------------------
-void KMFilterMgr::openDialog( QWidget *parent )
+void KMFilterMgr::openDialog( QWidget * )
 {
   if( !mEditDialog )
   {
@@ -215,15 +232,14 @@ void KMFilterMgr::openDialog( QWidget *parent )
     // We can't use the parent as long as the dialog is modeless
     // and there is one shared dialog for all top level windows.
     //
-    (void)parent;
-      mEditDialog = new KMFilterDlg( 0, "filterdialog", bPopFilter );
+    mEditDialog = new KMFilterDlg( 0, "filterdialog", bPopFilter );
   }
   mEditDialog->show();
 }
 
 
 //-----------------------------------------------------------------------------
-void KMFilterMgr::createFilter( const QCString field, const QString value )
+void KMFilterMgr::createFilter( const QCString & field, const QString & value )
 {
   openDialog( 0 );
   mEditDialog->createFilter( field, value );
@@ -243,20 +259,6 @@ bool KMFilterMgr::folderRemoved(KMFolder* aFolder, KMFolder* aNewFolder)
 }
 
 
-//-----------------------------------------------------------------------------
-void KMFilterMgr::setShowLaterMsgs(bool aShow)
-{
-  mShowLater = aShow;
-}
-
-
-//-----------------------------------------------------------------------------
-bool KMFilterMgr::showLaterMsgs()
-{
-  return mShowLater;
-}
-
-
 //-----------------------------------------------------------------------------
 void KMFilterMgr::dump(void)
 {
