@@ -1328,8 +1328,8 @@ void KMFolder::readConfig()
   mCompactable = config->readBoolEntry("Compactable", TRUE);
 
   mUseCustomIcons = config->readBoolEntry("UseCustomIcons", FALSE );
-  mNormalIconPath = config->readEntry("NormalIconPath");
-  mUnreadIconPath = config->readEntry("UnreadIconPath");
+  mNormalIconPath = config->readPathEntry("NormalIconPath");
+  mUnreadIconPath = config->readPathEntry("UnreadIconPath");
   if ( mUseCustomIcons )
       mNeedsRepainting = true;
   iconsFromPath();
