@@ -2,7 +2,7 @@
 #define __KMFOLDERDIA
 
 #include <kdialogbase.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 class KMAcctFolder;
 class QCheckBox;
@@ -14,6 +14,8 @@ class QGroupBox;
 class KMFolder;
 class KMFolderDir;
 class KIntNumInput;
+class KIconButton;
+class IdentityCombo;
 template <typename T> class QGuardedPtr;
 
 /** Dialog for handling the properties of a mail folder
@@ -28,12 +30,11 @@ public:
 
 protected slots:
   virtual void slotOk( void );
-  virtual void slotHoldsML( bool );
   virtual void slotExpireFolder( bool );
   void slotReadExpiryUnitChanged( int );
   void slotUnreadExpiryUnitChanged( int );
-
-  /*
+  virtual void slotChangeIcon( QString icon );
+  /* 
    * is called if the folder dropdown changes
    * then we update the other items to reflect the capabilities
    */
@@ -45,12 +46,16 @@ protected:
   QLineEdit *nameEdit;
   KMAcctFolder* folder;
   KMFolder *mFolder;
-  KMFolderDir* mFolderDir;
+  KMFolderDir *mFolderDir;
+  KIconButton *mNormalIconButton;
+  KIconButton *mUnreadIconButton;
+  QCheckBox   *mIconsCheckBox;
+  
   QValueList<QGuardedPtr<KMFolder> > mFolders;
 
   QCheckBox *holdsMailingList, *markAnyMessage, *expireFolder;
   QLineEdit *mailingListPostAddress;
-  QComboBox *identity;
+  IdentityCombo *identity;
   QGroupBox *expGroup, *mtGroup;
 //   QLineEdit *mailingListAdminAddress;
 
