@@ -163,8 +163,7 @@ bool KMFolderDir::reload(void)
   for (fileInfo=fiList->first(); fileInfo; fileInfo=fiList->next())
   {
     fname = fileInfo->fileName();
-    if ((fname[0]=='.') &&
-        !(fname.right(10)==".directory"))
+    if ((fname[0]=='.') && !fname.endsWith(".directory")) // hidden file
       continue;
     else if (fname == ".directory")
       continue;
@@ -172,7 +171,9 @@ bool KMFolderDir::reload(void)
     {
       QString maildir(fname + "/new");
       // see if this is a maildir before assuming a subdir
-      if (!mImap && dir.exists(maildir))
+      if (!mImap
+          && !( ( fname[0] == '.' ) && fname.endsWith( ".directory" ) )
+          && dir.exists(maildir))
       {
         folder = new KMFolderMaildir(this, fname);
         append(folder);
