@@ -31,10 +31,6 @@
 #include <sys/stat.h>
 #include <sys/file.h>
 
-#ifndef isblank
-#  define isblank(x) ((x)==' '||(x)=='\t')
-#endif
-
 #ifndef MAX_LINE
 #define MAX_LINE 4096
 #endif
@@ -443,7 +439,7 @@ int KMFolderMbox::unlock()
   {
     case FCNTL:
       if (mIndexStream) fcntl(fileno(mIndexStream), F_SETLK, &fl);
-      fcntl(fileno(mStream), F_SETLK, F_UNLCK);
+      fcntl(fileno(mStream), F_SETLK, &fl);
       rc = errno;
       break;
 
@@ -543,6 +539,7 @@ int KMFolderMbox::createIndexFromContents()
   *xstatus = '\0';
   xmarkStr = "";
   replyToIdStr = "";
+  referencesStr = "";
   msgIdStr = "";
   needStatus = 3;
 
@@ -569,15 +566,49 @@ int KMFolderMbox::createIndexFromContents()
 
 	if (size > 0)
 	{
-	  if ((replyToIdStr.isEmpty() || (replyToIdStr[0] != '<'))  &&
-	      !referencesStr.isEmpty() && referencesStr[0] == '<') {
-	    replyToIdStr = referencesStr;
-	  }
+          msgIdStr = msgIdStr.stripWhiteSpace();
+          if( !msgIdStr.isEmpty() ) {
+            int rightAngle;
+            rightAngle = msgIdStr.find( '>' );
+            if( rightAngle != -1 )
+              msgIdStr.truncate( rightAngle + 1 );
+          }
+
+          replyToIdStr = replyToIdStr.stripWhiteSpace();
+          if( !replyToIdStr.isEmpty() ) {
+            int rightAngle;
+            rightAngle = replyToIdStr.find( '>' );
+            if( rightAngle != -1 )
+              replyToIdStr.truncate( rightAngle + 1 );
+          }
+
+          referencesStr = referencesStr.stripWhiteSpace();
+          if( !referencesStr.isEmpty() ) {
+            int leftAngle, rightAngle;
+            leftAngle = referencesStr.findRev( '<' );
+            if( leftAngle != -1 )
+              referencesStr = referencesStr.mid( leftAngle );
+            rightAngle = referencesStr.find( '>' );
+            if( rightAngle != -1 )
+              referencesStr.truncate( rightAngle + 1 );
+
+            if( replyToIdStr.isEmpty() || ( replyToIdStr[0] != '<' ) ) {
+              // use the last reference, instead of missing In-Reply-To
+              replyToIdStr = referencesStr;
+            }
+          }
+
 	  mi = new KMMsgInfo(this);
-	  mi->init(subjStr, fromStr, toStr, 0, KMMsgStatusNew, xmarkStr, replyToIdStr, msgIdStr, 
-		   KMMsgEncryptionStateUnknown, KMMsgSignatureStateUnknown, offs, size);
+          mi->init( subjStr.stripWhiteSpace(),
+                    fromStr.stripWhiteSpace(),
+                    toStr.stripWhiteSpace(),
+                    0, KMMsgStatusNew,
+                    xmarkStr.stripWhiteSpace(),
+                    replyToIdStr, msgIdStr,
+                    KMMsgEncryptionStateUnknown, KMMsgSignatureStateUnknown,
+                    offs, size );
 	  mi->setStatus("RO","O");
-	  mi->setDate(dateStr);
+	  mi->setDate( dateStr.stripWhiteSpace() );
 	  mi->setDirty(FALSE);
 	  mMsgList.append(mi);
 
@@ -616,68 +647,52 @@ int KMFolderMbox::createIndexFromContents()
     if (!inHeader) continue;
 
     /* -sanders Make all messages read when auto-recreating index
-    if ((needStatus & 1) && strncasecmp(line, "Status:", 7) == 0 &&
-	isblank(line[7]))
+    if ((needStatus & 1) && strncasecmp(line, "Status:", 7) == 0)
     {
       for(i=0; i<4 && line[i+8] > ' '; i++)
 	status[i] = line[i+8];
       status[i] = '\0';
       needStatus &= ~1;
     }
-    else if ((needStatus & 2) && strncasecmp(line, "X-Status:", 9)==0 &&
-	     isblank(line[9]))
+    else if ((needStatus & 2) && strncasecmp(line, "X-Status:", 9)==0)
     {
       for(i=0; i<4 && line[i+10] > ' '; i++)
 	xstatus[i] = line[i+10];
       xstatus[i] = '\0';
       needStatus &= ~2;
     }
-    else*/ if (strncasecmp(line,"X-KMail-Mark:",13)==0 && isblank(line[13]))
-        xmarkStr = QCString(line+14);
-    else if (strncasecmp(line,"In-Reply-To:",12)==0 && isblank(line[12])) {
-      int rightAngle;
-      replyToIdStr = QCString(line+13);
-      rightAngle = replyToIdStr.find( '>' );
-      if (rightAngle != -1)
-	replyToIdStr.truncate( rightAngle + 1 );
+    else*/ if (strncasecmp(line,"X-KMail-Mark:",13)==0)
+        xmarkStr = QCString(line+13);
+    else if (strncasecmp(line,"In-Reply-To:",12)==0) {
+      replyToIdStr = QCString(line+12);
+      lastStr = &replyToIdStr;
     }
-    else if (strncasecmp(line,"References:",11)==0 && isblank(line[11])) {
-      int leftAngle, rightAngle;
-      referencesStr = QCString(line+12);
-      leftAngle = referencesStr.findRev( '<' );
-      if (leftAngle != -1)
-	referencesStr = referencesStr.mid( leftAngle );
-      rightAngle = referencesStr.find( '>' );
-      if (rightAngle != -1)
-	referencesStr.truncate( rightAngle + 1 );
+    else if (strncasecmp(line,"References:",11)==0) {
+      referencesStr = QCString(line+11);
+      lastStr = &referencesStr;
     }
-    else if (strncasecmp(line,"Message-Id:",11)==0 && isblank(line[11])) {
-      int rightAngle;
-      msgIdStr = QCString(line+12);
-      rightAngle = msgIdStr.find( '>' );
-      if (rightAngle != -1)
-	msgIdStr.truncate( rightAngle + 1 );
+    else if (strncasecmp(line,"Message-Id:",11)==0) {
+      msgIdStr = QCString(line+11);
+      lastStr = &msgIdStr;
     }
-    else if (strncasecmp(line,"Date:",5)==0 && isblank(line[5]))
+    else if (strncasecmp(line,"Date:",5)==0)
     {
-        dateStr = QCString(line+6);
+        dateStr = QCString(line+5);
       lastStr = &dateStr;
     }
-    else if (strncasecmp(line,"From:", 5)==0 &&
-	     isblank(line[5]))
+    else if (strncasecmp(line,"From:", 5)==0)
     {
-        fromStr = QCString(line+6);
+        fromStr = QCString(line+5);
       lastStr = &fromStr;
     }
-    else if (strncasecmp(line,"To:", 3)==0 &&
-	     isblank(line[3]))
+    else if (strncasecmp(line,"To:", 3)==0)
     {
-        toStr = QCString(line+4);
+        toStr = QCString(line+3);
       lastStr = &toStr;
     }
-    else if (strncasecmp(line,"Subject:",8)==0 && isblank(line[8]))
+    else if (strncasecmp(line,"Subject:",8)==0)
     {
-        subjStr = QCString(line+9);
+        subjStr = QCString(line+8);
       lastStr = &subjStr;
     }
   }
