@@ -670,7 +670,7 @@ void KMHeaders::readConfig (void)
   // Backing pixmap support
   { // area for config group "Pixmaps"
     KConfigGroupSaver saver(config, "Pixmaps");
-    QString pixmapFile = config->readEntry("Headers","");
+    QString pixmapFile = config->readEntry("Headers");
     mPaintInfo.pixmapOn = FALSE;
     if (pixmapFile != "") {
       mPaintInfo.pixmapOn = TRUE;
@@ -728,6 +728,7 @@ void KMHeaders::reset(void)
   updateMessageList();
   setCurrentMsg(id);
   setTopItemByIndex(top);
+  ensureCurrentItemVisible();
 }
 
 //-----------------------------------------------------------------------------
