@@ -3,13 +3,15 @@
 
 #include <qwidget.h>
 #include <qstrlist.h>
-#define private public
 #include <klistview.h>
-#include <qarray.h>
+#include <kfoldertree.h>
+#include <qmemarray.h>
 #include <qmap.h>
 #include <qdragobject.h>
 #include <qdict.h>
 #include "kmmessage.h"
+#include "kmime_util.h"
+#include <kpopupmenu.h>
 
 class KMFolder;
 class KMMessage;
@@ -20,54 +22,10 @@ class KMHeaderItem;
 class QPixmap;
 class QIconSet;
 class QDateTime;
-#ifdef SCORING
-class KMScoringManager;
-#endif
 
 typedef QPtrList<KMMsgBase> KMMessageList;
 typedef QMap<int,KMFolder*> KMMenuToFolder;
 
-/** A special drag class for header list to folder tree DnD operations */
-class KMHeaderToFolderDrag: public QStoredDrag {
-public:
-    KMHeaderToFolderDrag( QWidget * parent = 0, const char * name = 0 );
-    ~KMHeaderToFolderDrag() {};
-
-    static bool canDecode( QDropEvent* e );
-};
-
-typedef enum  {
-      CTime,
-      Localized,
-      FancyDate
-} KMDateDisplay;
-
-/** Information shared by all items in a list view */
-struct KMPaintInfo {
-  bool pixmapOn;
-  QPixmap pixmap;
-  QColor colFore;
-  QColor colBack;
-  QColor colNew;
-  QColor colUnread;
-  QColor colFlag;
-  bool showSize;      // Do we display the message size?
-#ifdef SCORING
-  bool showScore;
-#endif
-  bool orderOfArrival;
-  bool status;
-  int flagCol;
-  int senderCol;
-  int subCol;
-  int dateCol;
-#ifdef SCORING
-  int scoreCol;
-#endif
-  int sizeCol;
-  KMDateDisplay dateDisplay;
-};
-
 /** The widget that shows the contents of folders */
 #define KMHeadersInherited KListView
 class KMHeaders : public KListView
@@ -92,9 +50,6 @@ public:
     if id>count() the last message is shown. */
   virtual void setCurrentMsg(int msgId);
 
-  /** Provide information about number of messages in a folder */
-  void setFolderInfoStatus();
-
   /** Get a list of all items in the current thread */
   QPtrList<QListViewItem> currentThread() const;
 
@@ -108,25 +63,21 @@ public:
   virtual void setMsgRead(int msgId=-1);
   virtual void deleteMsg(int msgId=-1);
   virtual void applyFiltersOnMsg(int msgId=-1);
-  virtual void saveMsg(int msgId = -1);
   virtual void undo();
   virtual bool canUndo() const;
-  virtual void forwardMsg();
-  virtual void forwardAttachedMsg();
-  virtual void bounceMsg();
-  virtual void replyToMsg(QString selection=QString::null);
-  virtual void noQuoteReplyToMsg();
-  virtual void redirectMsg();
-  virtual void replyAllToMsg(QString selection=QString::null);
-  virtual void replyListToMsg(QString selection=QString::null);
   virtual void resendMsg();
+  virtual void prepareMove( KMMsgBase **curMsg, int *contentX, int *contentY );
+  virtual void finalizeMove( KMMsgBase *curMsg, int contentX, int contentY );
 
-  /** If destination==NULL the messages are deleted, otherwise
+  /** If destination is 0 then the messages are deleted, otherwise
     they are moved to this folder. */
   virtual void moveMsgToFolder(KMFolder* destination, int msgId=-1);
 
-  /** Messages are duplicated and added to given folder. */
-  virtual void copyMsgToFolder(KMFolder* destination, int msgId=-1);
+  /** Messages are duplicated and added to given folder.
+      If aMsg is set this one will be written to the destination folder. */
+  virtual void copyMsgToFolder(KMFolder* destination,
+                               int msgId=-1,
+                               KMMessage* aMsg = 0);
 
  /** Returns list of selected messages or a list with the message with
     the given Id if msgId >= 0. Do not delete the returned list. */
@@ -145,7 +96,7 @@ public:
   KMMainWin* owner(void) const { return mOwner; }
 
   /** PaintInfo pointer */
-  const KMPaintInfo *paintInfo(void) const { return &mPaintInfo; }
+  const KPaintInfo *paintInfo(void) const { return &mPaintInfo; }
 
   /** Read config options. */
   virtual void readConfig(void);
@@ -191,12 +142,13 @@ public:
   /** return a string relativ to the current time */
   static QString fancyDate( time_t otime );
 
-  static QString formatDate( time_t otime, KMDateDisplay date );
-
   QFont dateFont;
 
   bool noRepaint;
 
+  // filter events for popup
+  bool eventFilter ( QObject *o, QEvent *e );
+
 signals:
   /** emitted when the list view item corresponding to this message
       has been selected */
@@ -252,9 +204,19 @@ public slots:
 
   virtual void ensureCurrentItemVisible();
 
+  /** switch size-column */
+  void slotToggleSizeColumn();
+
+  /** Provide information about number of messages in a folder */
+  void setFolderInfoStatus();
+
 protected:
   static QPixmap *pixNew, *pixUns, *pixDel, *pixOld, *pixRep, *pixSent,
-    *pixQueued, *pixFwd, *pixFlag;
+    *pixQueued, *pixFwd, *pixFlag,
+    *pixFullySigned, *pixPartiallySigned, *pixUndefinedSigned,
+    *pixFullyEncrypted, *pixPartiallyEncrypted, *pixUndefinedEncrypted,
+      *pixFiller, *pixEncryptionProblematic,
+      *pixSignatureProblematic;
 
   /** Look for color changes */
   virtual bool event(QEvent *e);
@@ -280,6 +242,9 @@ protected:
   /** Write per-folder config options. */
   virtual void writeFolderConfig(void);
 
+  /** Write global config options. */
+  virtual void writeConfig(void);
+
   /** Handle shift and control selection */
   virtual void contentsMousePressEvent(QMouseEvent*);
   virtual void contentsMouseReleaseEvent(QMouseEvent* e);
@@ -315,9 +280,6 @@ private:
   /** Is equivalent to clearing the list and inserting an item for
       each message in the current folder */
   virtual void updateMessageList(bool set_selection=FALSE);
-#ifdef SCORING
-  virtual int  messageScore(int msgId);
-#endif
 
   /** Currently associated folder */
   KMFolder* mFolder;
@@ -342,10 +304,6 @@ private:
 
   /** are we currently showing the size field? */
   bool showingSize;
-#ifdef SCORING
-  /** are we currently showing the score field? */
-  bool showingScore;
-#endif
   /** Updated as side effect of KMHeaders::getMsg */
   int getMsgIndex;
   /** ditto */
@@ -353,17 +311,14 @@ private:
   /** ditto */
   KMHeaderItem* getMsgItem;
   /** @ref KMHeaders::selectedMsgs isn't reentrant */
-  KMMessageList mSelMsgList;
+  KMMessageList mSelMsgBaseList;
+  QPtrList<KMMessage> mSelMsgList;
   KMHeaderItem* mPrevCurrent;
 
   /** For shift selection */
   QListViewItem *beginSelection, *endSelection;
   /** Current colours and backing pixmap */
-  KMPaintInfo mPaintInfo;
-
-#ifdef SCORING
-  KMScoringManager *mScoringManager;
-#endif
+  KPaintInfo mPaintInfo;
 
   int mSortCol;
   bool mSortDescending;
@@ -389,12 +344,14 @@ private:
   bool writeSortOrder();
   bool readSortOrder(bool set_selection=FALSE);
 
-  /** cached values for fancyDate */
-  static QDateTime *now;
-  static time_t now_time;
-
+  KMime::DateFormatter mDate;
   /** value of config key Behaviour/LoopOnGotoUnread */
   bool mLoopOnGotoUnread;
+  bool mJumpToUnread;
+
+  /** popup to switch columns */
+  KPopupMenu* mPopup;
+  int mSizeColumn;
 };
 
 #endif
