@@ -183,10 +183,10 @@ void Signature::readConfig( const KConfigBase * config )
     mText = config->readEntry( sigTextKey );
   } else if ( sigType == sigTypeFileValue ) {
     mType = FromFile;
-    mUrl = config->readEntry( sigFileKey );
+    mUrl = config->readPathEntry( sigFileKey );
   } else if ( sigType == sigTypeCommandValue ) {
     mType = FromCommand;
-    mUrl = config->readEntry( sigCommandKey );
+    mUrl = config->readPathEntry( sigCommandKey );
   } else {
     mType = Disabled;
   }
@@ -271,7 +271,7 @@ void KMIdentity::readConfig( const KConfigBase * config )
   mIdentity = config->readEntry("Identity");
   mFullName = config->readEntry("Name");
   mEmailAddr = config->readEntry("Email Address");
-  mVCardFile = config->readEntry("VCardFile");
+  mVCardFile = config->readPathEntry("VCardFile");
   mOrganization = config->readEntry("Organization");
   mPgpIdentity = config->readEntry("Default PGP Key").local8Bit();
   mReplyToAddr = config->readEntry("Reply-To Address");
