@@ -609,9 +609,9 @@ void KMKernel::init()
   KConfigGroupSaver saver(cfg, "General");
   the_firstStart = cfg->readBoolEntry("first-start", true);
   cfg->writeEntry("first-start", false);
-  the_previousVersion = cfg->readEntry("previous-version", "");
+  the_previousVersion = cfg->readEntry("previous-version");
   cfg->writeEntry("previous-version", KMAIL_VERSION);
-  foldersPath = cfg->readEntry("folders", "");
+  foldersPath = cfg->readPathEntry("folders");
 
   if (foldersPath.isEmpty())
   {
@@ -792,10 +792,10 @@ void KMKernel::cleanupLoop()
   bool expire = false;
   // Expire old messages in all folders.
   if (closed_by_user) {
-    if (config->readNumEntry("when-to-expire")==expireAtExit) {
+    if (config->readNumEntry("when-to-expire", expireManual)==expireAtExit) {
       expire = true;
 
-      if (config->readBoolEntry("warn-before-expire")) {
+      if (config->readBoolEntry("warn-before-expire", true)) {
 	expire = canExpire();
       }
     }
