@@ -2668,7 +2668,7 @@ QString KMMessage::generateMessageId( const QString& addr )
   KConfigGroup general( kapp->config(), "General" );
 
   if( general.readBoolEntry( "useCustomMessageIdSuffix", false ) )
-    msgIdSuffix = general.readEntry( "myMessageIdSuffix", "" );
+    msgIdSuffix = general.readEntry( "myMessageIdSuffix" );
 
   if( !msgIdSuffix.isEmpty() )
     msgIdStr += '@' + msgIdSuffix;
