@@ -25,6 +25,10 @@ class KMMessagePart;
 class KMMsgInfo;
 class KMHeaders;
 
+namespace KMime {
+  class CharFreq;
+}
+
 class DwBodyPart;
 class DwMediaType;
 class DwHeaders;
@@ -184,8 +188,10 @@ public:
     by function asQuotedString().
     THIS FUNCTION WILL BE REPLACED ONCE KMime IS FULLY INTEGRATED
     (khz, June 05 2002)*/
-  virtual void parseTextStringFromDwPart( DwBodyPart& dwPart,
+  virtual void parseTextStringFromDwPart( DwBodyPart * mainBody,
+					  DwBodyPart * firstBodyPart,
                                           QCString& parsedString,
+                                          const QTextCodec*& codec,
                                           bool& isHTML ) const;
 
   /** Returns message body with quoting header and indented by the
@@ -281,11 +287,26 @@ public:
   virtual QString subject(void) const;
   virtual void setSubject(const QString& aStr);
 
+  /** Check for prefixes @p prefixRegExps in @p str. If none
+      is found, @p newPrefix + ' ' is prepended to @p str and the
+      resulting string is returned. If @p replace is true, any
+      sequence of whitespace-delimited prefixes at the beginning of
+      @p str is replaced by @p newPrefix.
+  **/
+  static QString replacePrefixes( const QString& str,
+                                  const QStringList& prefixRegExps,
+                                  bool replace,
+                                  const QString& newPrefix );
+
+  /** Returns @p str with all "forward" and "reply" prefixes stripped off.
+   **/
+  static QString stripOffPrefixes( const QString& str );
+
   /** Check for prefixes @p prefixRegExps in @ref #subject(). If none
       is found, @p newPrefix + ' ' is prepended to the subject and the
       resulting string is returned. If @p replace is true, any
       sequence of whitespace-delimited prefixes at the beginning of
-      @ref #subject() is replaced by newPrefix
+      @ref #subject() is replaced by @p newPrefix.
   **/
   QString cleanSubject(const QStringList& prefixRegExps, bool replace,
 		       const QString& newPrefix) const;
@@ -392,6 +413,13 @@ public:
   virtual void setBodyEncoded(const QCString& aStr);
   virtual void setBodyEncodedBinary(const QByteArray& aStr);
 
+  /** Returns a list of content-transfer-encodings that can be used with
+      the given result of the character frequency analysis of a message or
+      message part under the given restrictions. */
+  static QValueList<int> determineAllowedCtes( const KMime::CharFreq& cf,
+                                               bool allow8Bit,
+                                               bool willBeSigned );
+
   /** Sets body, encoded in the best fitting
     content-transfer-encoding, which is determined by character
     frequency count.
@@ -399,13 +427,16 @@ public:
     @param aBuf       input buffer
     @param allowedCte return: list of allowed cte's
     @param allow8Bit  whether "8bit" is allowed as cte.
+    @param willBeSigned whether "7bit"/"8bit" is allowed as cte according to RFC 3156
   */
-  virtual void setBodyAndGuessCte(const QByteArray& aBuf,
-                  QValueList<int>& allowedCte,
-                  bool allow8Bit=false);
-  virtual void setBodyAndGuessCte(const QCString& aBuf,
-                  QValueList<int>& allowedCte,
-                  bool allow8Bit=false);
+  virtual void setBodyAndGuessCte( const QByteArray& aBuf,
+                                   QValueList<int>& allowedCte,
+                                   bool allow8Bit = false,
+                                   bool willBeSigned = false );
+  virtual void setBodyAndGuessCte( const QCString& aBuf,
+                                   QValueList<int>& allowedCte,
+                                   bool allow8Bit = false,
+                                   bool willBeSigned = false );
 
   /** Returns a decoded version of the body from the current content transfer
       encoding. The first method returns a null terminated string, the second
@@ -526,12 +557,12 @@ public:
   virtual void setCharset(const QCString& aStr);
 
   /** Get the charset the user selected for the message to display */
-  virtual QTextCodec* codec(void) const
+  virtual const QTextCodec* codec(void) const
   { return mCodec; }
 
   /** Set the charset the user selected for the message to display */
-  virtual void setCodec(QTextCodec* aCodec)
-  { mCodec = aCodec; }
+  virtual void setCodec( const QTextCodec* aCodec, bool autoDetect )
+  { mCodec = aCodec; mAutoDetectCodec = autoDetect; }
 
   /** Allow decoding of HTML for quoting */
   void setDecodeHTML(bool aDecodeHTML)
@@ -619,7 +650,8 @@ protected:
   bool       mNeedsAssembly, mIsComplete, mTransferInProgress, mDecodeHTML;
   static int sHdrStyle;
   static QString sForwardStr;
-  QTextCodec* mCodec;
+  const QTextCodec* mCodec;
+  bool mAutoDetectCodec;
 
   QString mFileName;
   off_t mFolderOffset;
