@@ -7,6 +7,7 @@
 #include <kcharsets.h>
 
 #include <kmime_util.h>
+#include <kmime_codecs.h>
 #include <mimelib/mimepp.h>
 #include <qregexp.h>
 #include <qtextcodec.h>
@@ -337,7 +338,7 @@ QString KMMsgBase::decodeRFC2047String(const QCString& aStr)
   QCString charset;
   char *pos, *beg, *end, *mid=0;
   QCString str, cstr, LWSP_buffer;
-  char encoding='Q', ch;
+  char encoding='Q';
   bool valid, lastWasEncodedWord=FALSE;
   const int maxLen=200;
   int i;
@@ -422,15 +423,14 @@ QString KMMsgBase::decodeRFC2047String(const QCString& aStr)
     if (valid)
     {
       // valid encoding: decode and throw away separating LWSP
-      ch = *pos;
-      *pos = '\0';
-      str = QCString(mid).left((int)(mid - pos - 1));
+      str = QCString(mid, pos-mid+1 /* +1 adds trailing NUL */);
       if (encoding == 'Q')
       {
 	// decode quoted printable text
-	for (i=str.length()-1; i>=0; i--)
-	  if (str[i]=='_') str[i]=' ';
-	cstr = decodeQuotedPrintable(str);
+        QByteArray in; in.setRawData( mid, pos - mid );
+        const QByteArray enc = KMime::Codec::codecForName( "q" )->decode( in );
+        in.resetRawData( mid, pos - mid );
+        cstr = QCString( enc.data(), enc.size() + 1 /* +1 adds trailing NUL */ );
       }
       else
       {
@@ -442,7 +442,6 @@ QString KMMsgBase::decodeRFC2047String(const QCString& aStr)
       result += codec->toUnicode(cstr);
       lastWasEncodedWord = TRUE;
 
-      *pos = ch;
       pos = end -1;
     }
     else
@@ -577,48 +576,60 @@ QCString KMMsgBase::encodeRFC2047String(const QString& _str,
 
 
 //-----------------------------------------------------------------------------
-QCString KMMsgBase::encodeRFC2231String(const QString& _str,
-  const QCString& charset)
+QCString KMMsgBase::encodeRFC2231String( const QString& _str,
+                                         const QCString& charset )
 {
-  if (_str.isEmpty()) return QCString();
+  if ( _str.isEmpty() )
+    return QCString();
+
   QCString cset;
-  if (charset.isEmpty()) cset = QCString(kernel->networkCodec()->mimeName()).lower();
-    else cset = charset;
+  if ( charset.isEmpty() )
+    cset = QCString( kernel->networkCodec()->mimeName() ).lower();
+  else
+    cset = charset;
   QTextCodec *codec = codecForName(cset);
   QCString latin;
-  if (charset == "us-ascii") latin = toUsAscii(_str);
-  else if (codec) latin = codec->fromUnicode(_str);
-    else latin = _str.local8Bit();
+  if ( charset == "us-ascii" )
+    latin = toUsAscii( _str );
+  else if ( codec )
+    latin = codec->fromUnicode( _str );
+  else
+    latin = _str.local8Bit();
 
-  char *l = latin.data();
-  char hexcode;
-  int i;
-  bool quote;
-  while (*l)
-  {
-    if (*l < 32) break;
-    l++;
+  char *l;
+  for ( l = latin.data(); *l; ++l ) {
+    if ( ( *l & 0xE0 == 0 ) || ( *l & 0x80 ) )
+      // *l is control character or 8-bit char
+      break;
   }
-  if (!*l) return latin;
+  if ( !*l )
+    return latin;
+
   QCString result = cset + "''";
-  l = latin.data();
-  while (*l)
-  {
-    quote = *l < 0;
-    for (i = 0; i < 17; i++) if (*l == especials[i]) quote = true;
-    if (quote)
-    {
+  for ( l = latin.data(); *l; ++l ) {
+    bool needsQuoting = ( *l & 0x80 );
+    if( !needsQuoting ) {
+      int len = especials.length();
+      for ( int i = 0; i < len; i++ )
+        if ( *l == especials[i] ) {
+          needsQuoting = true;
+          break;
+        }
+    }
+    if ( needsQuoting ) {
       result += '%';
-      hexcode = ((*l & 0xF0) >> 4) + 48;
-      if (hexcode >= 58) hexcode += 7;
+      unsigned char hexcode;
+      hexcode = ( ( *l & 0xF0 ) >> 4 ) + 48;
+      if ( hexcode >= 58 )
+        hexcode += 7;
       result += hexcode;
-      hexcode = (*l & 0x0F) + 48;
-      if (hexcode >= 58) hexcode += 7;
+      hexcode = ( *l & 0x0F ) + 48;
+      if ( hexcode >= 58 )
+        hexcode += 7;
       result += hexcode;
     } else {
       result += *l;
     }
-    l++;
   }
   return result;
 }
@@ -648,13 +659,10 @@ QString KMMsgBase::decodeRFC2231String(const QCString& _str)
     }
     p++;
   }
-  QString result;
   QTextCodec *codec = codecForName(charset);
   if (!codec) codec = kernel->networkCodec();
-  if (codec) result = codec->toUnicode(st);
-  else result = kernel->networkCodec()->toUnicode(st);
-
-  return result;
+  assert( codec );
+  return codec->toUnicode(st);
 }
 
 //-----------------------------------------------------------------------------
