@@ -2,6 +2,7 @@
 
 
 // my includes:
+#include <config.h>
 #include "kmmsgpartdlg.h"
 
 // other KMail includes:
@@ -35,14 +36,19 @@
 // other includes:
 #include <assert.h>
 
+// Using this define is save now since we made sure the
+// respective check boxes are enabled only if an active
+// plugin is there.
+#define AEGYPTEN
+
 static const struct {
   KMMsgPartDialog::Encoding encoding;
   const char * displayName;
 } encodingTypes[] = {
-  { KMMsgPartDialog::SevenBit, I18N_NOOP("none (7bit text)") },
-  { KMMsgPartDialog::EightBit, I18N_NOOP("none (8bit text)") },
-  { KMMsgPartDialog::QuotedPrintable, I18N_NOOP("quoted printable") },
-  { KMMsgPartDialog::Base64, I18N_NOOP("base 64") },
+  { KMMsgPartDialog::SevenBit, I18N_NOOP("None (7-bit text)") },
+  { KMMsgPartDialog::EightBit, I18N_NOOP("None (8-bit text)") },
+  { KMMsgPartDialog::QuotedPrintable, I18N_NOOP("Quoted Printable") },
+  { KMMsgPartDialog::Base64, I18N_NOOP("Base 64") },
 };
 static const int numEncodingTypes =
   sizeof encodingTypes / sizeof *encodingTypes;
@@ -142,7 +148,7 @@ KMMsgPartDialog::KMMsgPartDialog( const QString & caption,
   // row 4: "Encoding" combobox and label:
   mEncoding = new QComboBox( false, plainPage() );
   mEncoding->insertStringList( mI18nizedEncodings );
-  label = new QLabel( mEncoding, i18n("&Encoding"), plainPage() );
+  label = new QLabel( mEncoding, i18n("&Encoding:"), plainPage() );
   glay->addWidget( label, 4, 0 );
   glay->addWidget( mEncoding, 4, 1 );
 
@@ -373,6 +379,8 @@ KMMsgPartDialogCompat::KMMsgPartDialogCompat( const char *, bool readOnly)
     mDescription->setEnabled(false);
     mEncoding->setEnabled(false);
     mInline->setEnabled(false);
+    mEncrypted->setEnabled(false);
+    mSigned->setEnabled(false);
   }
 }
 
@@ -423,7 +431,7 @@ void KMMsgPartDialogCompat::applyChanges()
     if ( encoding.isEmpty() ) encoding = "utf-8";
     QCString encName = KMMsgBase::encodeRFC2231String( name, encoding );
 
-    cDisp += " filename";
+    cDisp += "\n\tfilename";
     if ( name != QString( encName ) )
       cDisp += "*=" + encName;
     else
