@@ -46,6 +46,8 @@ KMSender::KMSender()
   mSendAborted = false;
   mSentMessages = 0;
   mTotalMessages = 0;
+  mSentBytes = 0;
+  mTotalBytes = 0;
 }
 
 
@@ -159,17 +161,14 @@ bool KMSender::send(KMMessage* aMsg, short sendNow)
 }
 
 
-bool KMSender::sendSingleMail( KMMessage*)
-{
-
-  return true;
-
-}
-
 //-----------------------------------------------------------------------------
-void KMSender::outboxMsgAdded()
+void KMSender::outboxMsgAdded(int idx)
 {
     ++mTotalMessages;
+    KMMsgBase* msg = kernel->outboxFolder()->getMsgBase(idx);
+    Q_ASSERT(msg);
+    if ( msg )
+        mTotalBytes += msg->msgSize();
 }
 
 
@@ -185,10 +184,15 @@ bool KMSender::sendQueued(void)
   }
 
   // open necessary folders
-  kernel->outboxFolder()->open();
-  mTotalMessages = kernel->outboxFolder()->count();
-  connect(kernel->outboxFolder(), SIGNAL(msgAdded(int)),
-          this, SLOT(outboxMsgAdded()));
+  KMFolder* outbox = kernel->outboxFolder();
+  outbox->open();
+  mTotalMessages = outbox->count();
+  mTotalBytes = 0;
+  for( int i = 0 ; i<mTotalMessages ; ++i )
+      mTotalBytes += outbox->getMsgBase(i)->msgSize();
+
+  connect(outbox, SIGNAL(msgAdded(int)),
+          this, SLOT(outboxMsgAdded(int)));
   mCurrentMsg = 0;
 
   kernel->sentFolder()->open();
@@ -198,6 +202,13 @@ bool KMSender::sendQueued(void)
   return TRUE;
 }
 
+//-----------------------------------------------------------------------------
+void KMSender::emitProgressInfo( int currentFileProgress )
+{
+  int percent = (mTotalBytes) ? ( 100 * (mSentBytes+currentFileProgress) / mTotalBytes ) : 0;
+  if (percent > 100) percent = 100;
+  KMBroadcastStatus::instance()->setStatusProgressPercent("Sender", percent);
+}
 
 //-----------------------------------------------------------------------------
 void KMSender::doSendMsg()
@@ -205,10 +216,11 @@ void KMSender::doSendMsg()
   KMFolder *sentFolder = 0, *imapSentFolder = 0;
   bool someSent = mCurrentMsg;
   int rc;
-  if (someSent) mSentMessages++;
-  int percent = (mTotalMessages) ? (100 * mSentMessages / mTotalMessages) : 0;
-  if (percent > 100) percent = 100;
-  KMBroadcastStatus::instance()->setStatusProgressPercent("SMTP", percent);
+  if (someSent) {
+      mSentMessages++;
+      mSentBytes += mCurrentMsg->msgSize();
+  }
+  emitProgressInfo( 0 );
 
   // Post-process sent message (filtering)
   if (mCurrentMsg  && kernel->filterMgr())
@@ -331,7 +343,7 @@ kdDebug(5006) << "KMSender::doSendMsg() post-processing: replace mCurrentMsg bod
   if (!mSendInProgress)
   {
     KMBroadcastStatus::instance()->reset();
-    KMBroadcastStatus::instance()->setStatusProgressEnable( "SMTP", true );
+    KMBroadcastStatus::instance()->setStatusProgressEnable( "Sender", true );
     connect(KMBroadcastStatus::instance(), SIGNAL(signalAbortRequested()),
       SLOT(slotAbortSend()));
     kapp->ref();
@@ -440,7 +452,7 @@ void KMSender::cleanup(void)
     mCurrentMsg = 0;
   }
   disconnect(kernel->outboxFolder(), SIGNAL(msgAdded(int)),
-             this, SLOT(outboxMsgAdded()));
+             this, SLOT(outboxMsgAdded(int)));
   kernel->sentFolder()->close();
   kernel->outboxFolder()->close();
   if (kernel->outboxFolder()->count()<0)
@@ -449,9 +461,10 @@ void KMSender::cleanup(void)
 
   mSendAborted = false;
   mSentMessages = 0;
+  mSentBytes = 0;
   disconnect(KMBroadcastStatus::instance(), SIGNAL(signalAbortRequested()),
     this, SLOT(slotAbortSend()));
-  KMBroadcastStatus::instance()->setStatusProgressEnable( "SMTP", false );
+  KMBroadcastStatus::instance()->setStatusProgressEnable( "Sender", false );
   KMBroadcastStatus::instance()->reset();
   kernel->filterMgr()->cleanup();
 }
@@ -541,13 +554,30 @@ KMSendProc* KMSender::createSendProcFromString(QString transport)
     {
       mTransportInfo->type = "smtp";
       mTransportInfo->auth = FALSE;
+      mTransportInfo->encryption = "NONE";
       QString serverport = transport.mid(7);
-      mTransportInfo->host = serverport;
-      mTransportInfo->port = "25";
       int colon = serverport.find(':');
       if (colon != -1) {
         mTransportInfo->host = serverport.left(colon);
         mTransportInfo->port = serverport.mid(colon + 1);
+      } else {
+        mTransportInfo->host = serverport;
+        mTransportInfo->port = "25";
+      }
+    } else
+    if (transport.startsWith("smtps://"))
+    {
+      mTransportInfo->type = "smtps";
+      mTransportInfo->auth = FALSE;
+      mTransportInfo->encryption = "ssl";
+      QString serverport = transport.mid(7);
+      int colon = serverport.find(':');
+      if (colon != -1) {
+        mTransportInfo->host = serverport.left(colon);
+        mTransportInfo->port = serverport.mid(colon + 1);
+      } else {
+        mTransportInfo->host = serverport;
+        mTransportInfo->port = "465";
       }
     }
     else if (transport.startsWith("file://"))
@@ -556,13 +586,20 @@ KMSendProc* KMSender::createSendProcFromString(QString transport)
       mTransportInfo->host = transport.mid(7);
     }
   }
+  while (mTransportInfo->host.endsWith("/")) {
+    mTransportInfo->host.truncate(mTransportInfo->host.length()-1);
+  }
+
+  // strip off a trailing "/"
+  while( mTransportInfo->host.endsWith( "/" ) )
+    mTransportInfo->host.truncate( mTransportInfo->host.length() - 1 );
 
   if (mTransportInfo->type == "sendmail")
     return new KMSendSendmail(this);
-  if (mTransportInfo->type == "smtp")
+  if (mTransportInfo->type == "smtp" || mTransportInfo->type == "smtps")
     return new KMSendSMTP(this);
 
-  return 0;
+  return 0L;
 }
 
 //-----------------------------------------------------------------------------
@@ -1017,6 +1054,8 @@ bool KMSendSMTP::send(KMMessage *aMsg)
   mQuery = "";
 
   mMessage = prepareStr(aMsg->asSendableString(), TRUE);
+  mMessageLength = mMessage.length();
+  mMessageOffset = 0;
 
   if ((mJob = KIO::put(destination, -1, false, false, false)))
   {
@@ -1070,11 +1109,17 @@ bool KMSendSMTP::addOneRecipient(const QString& _addr)
 
 void KMSendSMTP::dataReq(KIO::Job *, QByteArray &array)
 {
-  if(!mMessage.isEmpty())
+  // Send it by 32K chuncks
+  int chunkSize = QMIN( mMessageLength - mMessageOffset, 0x8000 );
+  if ( chunkSize > 0 ) {
+    array.duplicate(mMessage.data() + mMessageOffset, chunkSize);
+    mMessageOffset += chunkSize;
+  } else
   {
-    array.duplicate(mMessage, mMessage.length());
-    mMessage = "";
+    array.resize(0);
+    mMessage.resize(0);
   }
+  mSender->emitProgressInfo( mMessageOffset );
 }
 
 void KMSendSMTP::result(KIO::Job *_job)
