@@ -67,7 +67,7 @@ void KMTransportInfo::readConfig(int id)
   port = config->readEntry("port", "25");
   user = config->readEntry("user");
   pass = KMAccount::decryptStr(config->readEntry("pass"));
-  precommand = config->readEntry("precommand");
+  precommand = config->readPathEntry("precommand");
   encryption = config->readEntry("encryption");
   authType = config->readEntry("authtype");
   auth = config->readBoolEntry("auth");
