@@ -214,7 +214,8 @@ static void checkConfigUpdates() {
   updates << "9"
 	  << "3.1-update-identities"
 	  << "3.1-use-identity-uoids"
-          << "3.1-new-mail-notification";
+          << "3.1-new-mail-notification"
+          << "3.1.4-dont-use-UOID-0-for-any-identity";
   for ( QStringList::const_iterator it = updates.begin() ; it != updates.end() ; ++it )
     config->checkUpdate( *it, updateFile );
 #endif
