@@ -39,4 +39,4 @@ namespace KMail {
     return transportNames;
   }
 
-}; // namespace KMail
+} // namespace KMail
