@@ -214,7 +214,7 @@ QString filter_ldif::decodeBase64(QString input)
 
     int tempLen = input.length();
     for(unsigned int i=0; i<input.length(); i++) {
-        if(codes[ input[i].latin1() ] < 0) {
+        if(codes[ ( unsigned char ) input[i].latin1() ] < 0) {
 	   // std::cout << "Invalid character in base64 string: " <<
 	   // input[i].latin1() << std::endl;
 	   --tempLen; // ignore non-valid chars and padding
