@@ -1,5 +1,5 @@
 /***************************************************************************
-                          oe5_2mbox.cpp  -  description
+                          oe4_2mbox.cpp  -  description
                              -------------------
     begin                : Thu Aug 24 2000
     copyright            : (C) 2000 by Hans Dijkema
@@ -9,7 +9,7 @@
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   is under the terms of the GNU General Public License as published by  *
+ *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
@@ -27,20 +27,20 @@
 #include <unistd.h>
 
 #include "filters.hxx"
-#include "oe5_2mbox.h"
+#include "oe4_2mbox.h"
 #include "liboe.h"
 
-#define CAP	cap 
+#define CAP cap
 
-QString	      oe5_2mbox::cap = i18n("Import Outlook Express 5");
-filter *      oe5_2mbox::F = 0;
-const char *  oe5_2mbox::FOLDER = 0;
-filterInfo *  oe5_2mbox::INFO = 0;
-int           oe5_2mbox::numOfMessages = 0;
-unsigned long oe5_2mbox::added = 0;
-unsigned long oe5_2mbox::mails = 0;
+QString       oe4_2mbox::cap = i18n("Import Outlook Express 4");
+filter *      oe4_2mbox::F = 0;
+const char *  oe4_2mbox::FOLDER = 0;
+filterInfo *  oe4_2mbox::INFO = 0;
+int           oe4_2mbox::numOfMessages = 0;
+unsigned long oe4_2mbox::added = 0;
+unsigned long oe4_2mbox::mails = 0;
 
-oe5_2mbox::oe5_2mbox(const char *in,const char *out,filter *F,filterInfo *I)
+oe4_2mbox::oe4_2mbox(const char *in,const char *out,filter *F,filterInfo *I)
 {
   info=I;
   f=F;
@@ -48,16 +48,16 @@ oe5_2mbox::oe5_2mbox(const char *in,const char *out,filter *F,filterInfo *I)
   folderTo=out;
 }
 
-oe5_2mbox::~oe5_2mbox()
+oe4_2mbox::~oe4_2mbox()
 {}
 
-int oe5_2mbox::convert(void)
+int oe4_2mbox::convert(void)
 {
 oe_data *result;
 char s[1024];
   F=f;
 
-  sprintf(s,"OE5-%s",folderTo);
+  sprintf(s,"OE4-%s",folderTo);
   FOLDER=s;
   INFO=info;
 
@@ -76,7 +76,7 @@ char s[1024];
       break;
       case OE_NOTOEBOX :
         {QString msg;
-           msg=i18n("%1 is not an Outlook Express 5 mailbox").arg(folderIn);
+           msg=i18n("%1 is not an Outlook Express 4 mailbox").arg(folderIn);
            info->alert(CAP,msg);
         }
       break;
@@ -89,14 +89,14 @@ char s[1024];
     }
   }
   else {QString msg;
-    msg=i18n("%1 mails read, %2 were new KMail folders").arg(mails).arg(added);
+    msg=i18n("%n mail read, %1 were new KMail folders", "%n mails read, %1 were new KMail folders", mails).arg(added);
     info->log(msg);
   }
 
 return result->success;
 }
 
-void oe5_2mbox::addMessage(const char *string,int code)
+void oe4_2mbox::addMessage(const char *string,int code)
 {
 static KTempFile *tmp=0;
 static int status=-1;
@@ -109,8 +109,8 @@ static float perc=0.0;
       status=1;
       tmp = new KTempFile;
       tmp->setAutoDelete(true);
-      if (tmp->status() != 0 || !tmp->fstream())
-      {
+      if (tmp->status() != 0 || !tmp->fstream()) 
+      {   
           QString msg;
           msg=i18n("FATAL: Cannot open temporary file.");
           INFO->alert(CAP,msg);
@@ -127,7 +127,7 @@ static float perc=0.0;
     {
       if (status!=1 && status!=2 && status!=-1) {QString msg;
         msg=i18n("FATAL: Cannot add to ended message,\n"
-                 "skipping until message start");
+                         "skipping until message start");
         INFO->alert(CAP,msg);
         status=-1;
       }
@@ -157,7 +157,7 @@ static float perc=0.0;
 
         fprintf(tmp->fstream(),"%s",string);
         if (!tmp->close())
-        {
+        { 
           QString msg;
           msg=i18n("FATAL: Cannot write temporary file.");
           INFO->alert(CAP,msg);
@@ -175,4 +175,6 @@ static float perc=0.0;
     break;
   }
 }
+
 #undef CAP
+
