@@ -304,7 +304,7 @@ ArticleFilter::ArticleFilter(const QString &action, const QString &newsSource,
 bool ArticleFilter::matches(Article::Ptr a) const
 {
 	if (!enabled() ||
-	    (a->newsSource()->newsSourceName() != newsSource() &&
+	    (a->newsSource()->data().name != newsSource() &&
 	    newsSource() != i18n("all news sources")))
 		return false;
 	
