@@ -18,8 +18,7 @@
 #include "configiface.h"
 #include "xmlnewsaccess.h"
 
-#include <qbuffer.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qmap.h>
 #include <qpixmap.h>
 
@@ -31,10 +30,10 @@ class ConfigAccess;
 class NewsIconMgr;
 class NewsSourceBase;
 
+class QBuffer;
 class QDomDocument;
 
 class KProcess;
-class KShellProcess;
 class KURL;
 
 class Article : public XMLNewsArticle, public KShared
@@ -66,7 +65,7 @@ class NewsSourceBase : public XMLNewsSource, public KShared
 	public:
 		enum Subject {
 			Arts = 0, Business, Computers, Games, Health, Home, Recreation,
-			Reference, Science, Shopping, Society, Sports, Misc
+			Reference, Science, Shopping, Society, Sports, Misc, Magazines
 		};
 		struct Data {
 			Data(const QString &_name = I18N_NOOP("Unknown"),
@@ -196,8 +195,8 @@ class ProgramNewsSource : public NewsSourceBase
 	private:
 		static QString errorMessage(const ErrorCode);
 		
-		KShellProcess *m_program;
-		QBuffer        m_programOutput;
+		KProcess      *m_program;
+		QBuffer       *m_programOutput;
 };
 
 #endif // NEWSENGINE_H
