@@ -44,6 +44,8 @@ class NewsSourceItem : public QObject, public QCheckListItem
 		void setData(const NewsSourceBase::Data &);
 
 		void setOn(bool);
+
+		QListViewItem *parentItem() { return QCheckListItem::parent(); }
 	
 	signals:
 		void toggled();
@@ -54,6 +56,7 @@ class NewsSourceItem : public QObject, public QCheckListItem
 	private:
 		QString      m_icon;
 		bool         m_isProgram;
+		NewsSourceBase::Subject m_subject;
 		CategoryItem *m_parent;
 		NewsIconMgr  *m_newsIconMgr;
 };
