@@ -21,29 +21,91 @@
 
 #include <qcheckbox.h>
 #include <qlabel.h>
+#include <qprogressbar.h>
+#include <qtimer.h>
+#include <qvbox.h>
+
+SuggestProgressDlg::SuggestProgressDlg(const KURL &url, QWidget *parent, const char *name)
+	: KDialogBase(parent, name, true, i18n("Downloading data..."), Cancel, Cancel),
+	m_gotSourceFile(false),
+	m_gotIcon(false)
+{
+	QVBox *mainWidget = makeVBoxMainWidget();
+	
+	new QLabel(i18n("<qt>Please wait while KNewsTicker is downloading some "
+	                "data necessary to suggest reasonable values.<br/>"
+	                "<br/>"
+	                "This will not take longer than one minute.</qt>" ),
+	                mainWidget);
+
+	m_progressBar = new QProgressBar(60, mainWidget);
+	m_progressBar->setPercentageVisible(false);
+
+	m_timeoutTimer = new QTimer(this);
+	connect(m_timeoutTimer, SIGNAL(timeout()), this, SLOT(slotTimeoutTick()));
+	m_timeoutTimer->start(1000);
+
+	m_xmlSrc = new XMLNewsSource;
+	connect(m_xmlSrc, SIGNAL(loadComplete(XMLNewsSource *, bool)),
+	        this, SLOT(slotLoadComplete(XMLNewsSource *, bool)));
+	m_xmlSrc->loadFrom(url);
+
+	connect(NewsIconMgr::self(), SIGNAL(gotIcon(const KURL &, const QPixmap &)),
+	        this, SLOT(slotGotIcon(const KURL &, const QPixmap &)));
+	KURL u = url;
+	if (url.isLocalFile())
+		u = QString::null;
+	else
+		u.setEncodedPathAndQuery(QString::fromLatin1("/favicon.ico"));
+	NewsIconMgr::self()->getIcon(u);
+}
+
+SuggestProgressDlg::~SuggestProgressDlg()
+{
+	delete m_xmlSrc;
+}
+
+void SuggestProgressDlg::slotTimeoutTick()
+{
+	if (m_progressBar->progress() == m_progressBar->totalSteps()) {
+		m_timeoutTimer->stop();
+		KMessageBox::error(this, i18n("Couldn't retrieve the specified source file!"));
+		reject();
+		return;
+	}
+	m_progressBar->setProgress(m_progressBar->progress() + 1);
+}
+
+void SuggestProgressDlg::slotLoadComplete(XMLNewsSource *, bool succeeded)
+{
+	m_gotSourceFile = true;
+	m_succeeded = succeeded;
+
+	if (m_gotIcon)
+		done(succeeded ? QDialog::Accepted : QDialog::Rejected);
+}
+
+void SuggestProgressDlg::slotGotIcon(const KURL &url, const QPixmap &pixmap)
+{
+	m_gotIcon = true;
+	m_icon = pixmap;
+	m_iconURL = url;
+
+	if (m_gotIcon)
+		done(m_succeeded ? QDialog::Accepted : QDialog::Rejected);
+}
 
 NewsSourceDlgImpl::NewsSourceDlgImpl(QWidget *parent,  const char *name, bool modal, WFlags fl)
 	: NewsSourceDlg(parent, name, modal, fl),
-	m_modified(false),
-	m_gotSourceFile(false),
-	m_gotIcon(false),
-	m_xmlSrc(new XMLNewsSource()),
-	m_newsIconMgr(NewsIconMgr::self())
+	m_modified(false)
 {
+	connect(NewsIconMgr::self(), SIGNAL(gotIcon(const KURL &, const QPixmap &)),
+	        this, SLOT(slotGotIcon(const KURL &, const QPixmap &)));
+
 	for (unsigned int i = 0; i < DEFAULT_SUBJECTS; i++)
 		comboCategory->insertItem(
 				NewsSourceBase::subjectText(static_cast<NewsSourceBase::Subject>(i)));
 	
-	connect(m_xmlSrc, SIGNAL(loadComplete(XMLNewsSource *, bool)),
-			SLOT(slotLoadComplete(XMLNewsSource *, bool)));
-
-	connect(m_newsIconMgr, SIGNAL(gotIcon(const KURL &, const QPixmap &)),
-			SLOT(slotGotIcon(const KURL &, const QPixmap &)));
-}
-
-NewsSourceDlgImpl::~NewsSourceDlgImpl()
-{
-	delete m_xmlSrc;
 }
 
 void NewsSourceDlgImpl::slotCancelClicked()
@@ -103,33 +165,17 @@ void NewsSourceDlgImpl::slotSuggestClicked()
 	if (!validateURL(url))
 		return;
 	
-	m_gotSourceFile = false;
-	m_xmlSrc->loadFrom(url);
-	
-	if (url.isLocalFile())
-		url = QString::null;
+	SuggestProgressDlg dlg(url, this);
+	if (dlg.exec() == QDialog::Accepted) {
+		pixmapIcon->setPixmap(dlg.icon());
+		if (NewsIconMgr::self()->isStdIcon(dlg.icon()))
+			leIcon->clear();
 	else
-		url.setEncodedPathAndQuery(QString::fromLatin1("/favicon.ico"));
-
-	m_gotIcon = false;
-	m_newsIconMgr->getIcon(url);
-	
-	m_origCaption = caption();
-	setCaption(i18n("Fetching News Source Data..."));
-	lName->setEnabled(false);
-	leName->setEnabled(false);
-	lSourceFile->setEnabled(false);
-	urlSourceFile->setEnabled(false);
-	cbProgram->setEnabled(false);
-	lCategory->setEnabled(false);
-	comboCategory->setEnabled(false);
-	lMaxArticles->setEnabled(false);
-	sbMaxArticles->setEnabled(false);
-	lIcon->setEnabled(false);
-	leIcon->setEnabled(false);
-	bOk->setEnabled(false);
-	bSuggest->setEnabled(false);
-	bCancel->setEnabled(false);
+			leIcon->setText(dlg.iconURL().url());
+		cbProgram->setChecked(false);
+		leName->setText(dlg.xmlSrc()->newsSourceName());
+		sbMaxArticles->setValue(dlg.xmlSrc()->articles().count());
+	}
 }
 
 void NewsSourceDlgImpl::slotModified()
@@ -148,71 +194,12 @@ void NewsSourceDlgImpl::setup(const NewsSourceBase::Data &nsd, bool modify)
 	if (iconURL.protocol() == QString::fromLatin1("file"))
 		iconURL.setProtocol(QString::null);
 	leIcon->setText(iconURL.url());
-	m_newsIconMgr->getIcon(nsd.icon);
+	NewsIconMgr::self()->getIcon(nsd.icon);
 	if (modify == true) {
 		setCaption(i18n("Edit News Source"));
 	}
 }
 
-void NewsSourceDlgImpl::slotLoadComplete(XMLNewsSource *, bool succeeded)
-{
-	m_gotSourceFile = true;
-	m_succeeded = succeeded;
-
-	if (m_gotIcon)
-		showSuggestedValues();
-}
-
-void NewsSourceDlgImpl::slotGotIcon(const KURL &url, const QPixmap &pixmap)
-{
-	m_gotIcon = true;
-	m_icon = pixmap;
-	m_iconURL = url;
-
-	/*
-	 * The icon stuff has to be set here instead of in showSuggestedValues() as
-	 * it's possible that slotGotIcon() is called on startup instead of within a
-	 * "Suggest values" process.
-	 */
-	pixmapIcon->setPixmap(m_icon);
-	if (m_newsIconMgr->isStdIcon(m_icon))
-		leIcon->clear();
-	else
-		leIcon->setText(m_iconURL.url());
-
-	if (m_gotSourceFile)
-		showSuggestedValues();
-}
-
-void NewsSourceDlgImpl::showSuggestedValues()
-{
-	setCaption(m_origCaption);
-	lName->setEnabled(true);
-	leName->setEnabled(true);
-	lSourceFile->setEnabled(true);
-	urlSourceFile->setEnabled(true);
-	cbProgram->setEnabled(true);
-	lCategory->setEnabled(true);
-	comboCategory->setEnabled(true);
-	lMaxArticles->setEnabled(true);
-	sbMaxArticles->setEnabled(true);
-	lIcon->setEnabled(true);
-	leIcon->setEnabled(true);
-	bOk->setEnabled(true);
-	bSuggest->setEnabled(true);
-	bCancel->setEnabled(true);
-
-	if (!m_succeeded) {
-		KMessageBox::error(this, i18n("Couldn't retrieve the specified source file!"));
-		return;
-	}
-
-	cbProgram->setChecked(false);
-	leName->setText(m_xmlSrc->newsSourceName());
-	sbMaxArticles->setValue(m_xmlSrc->articles().count());
-	// Icon stuff was set in slotGotIcon()
-}
-
 KURL NewsSourceDlgImpl::polishedURL(const KURL &url) const
 {
 	KURL newURL = url;
@@ -235,7 +222,7 @@ bool NewsSourceDlgImpl::validateURL(const KURL &url)
 		return false;
 	}
 	
-	if (url.isMalformed() || !url.hasPath() || url.encodedPathAndQuery() == QString::fromLatin1("/")) {
+	if (!url.isValid() || !url.hasPath() || url.encodedPathAndQuery() == QString::fromLatin1("/")) {
 		KMessageBox::error(this, i18n("KNewsTicker needs a valid RDF or RSS file to"
 					" suggest sensible values. The specified source file is invalid."),
 					i18n("Invalid Source File"));
@@ -245,4 +232,9 @@ bool NewsSourceDlgImpl::validateURL(const KURL &url)
 	return true;
 }
 
+void NewsSourceDlgImpl::slotGotIcon(const KURL &, const QPixmap &pixmap)
+{
+	pixmapIcon->setPixmap(pixmap);
+}
+
 #include "newssourcedlgimpl.moc"
