@@ -14,10 +14,6 @@
     Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
 */
 
-
-#include <pthread.h>
-
-
 #include <kmessagebox.h>
 #include <kuserprofile.h>
 #include <kopenwith.h>
@@ -191,7 +187,7 @@ void KNArticleManager::showHdrs(bool clear)
     v_iew->clear();
 
   knGlobals.top->setCursorBusy(true);
-  knGlobals.top->setStatusMsg(i18n(" Creating list ..."));
+  knGlobals.top->setStatusMsg(i18n(" Creating list..."));
   knGlobals.top->secureProcessEvents();
 
   if(g_roup) {
@@ -204,27 +200,20 @@ void KNArticleManager::showHdrs(bool clear)
       knGlobals.top->articleView()->setArticle(0);
     }
 
-    if(g_roup->isLocked()) {
-      if (0!=pthread_mutex_lock(knGlobals.netAccess->nntpMutex())) {
-        kdDebug(5003) << "failed to lock nntp mutex" << endl;
-        knGlobals.top->setStatusMsg(QString::null);
-        updateStatusString();
-        knGlobals.top->setCursorBusy(false);
-        return;
-      }
-    }
+    if(g_roup->isLocked())
+      knGlobals.netAccess->nntpMutex().lock();     
 
     if(f_ilter)
       f_ilter->doFilter(g_roup);
-    else
+    else    
       for(int i=0; i<g_roup->length(); i++) {
         art=g_roup->at(i);
         art->setFilterResult(true);
         art->setFiltered(true);
-        ref=(art->idRef()!=0) ? g_roup->byId(art->idRef()) : 0;
+        ref=(art->idRef()!=0) ? g_roup->byId(art->idRef()) : 0;        
         art->setDisplayedReference(ref);
         if(ref)
-          ref->setVisibleFollowUps(true);
+          ref->setVisibleFollowUps(true); 
       }
 
     d_isableExpander=true;
@@ -297,8 +286,8 @@ void KNArticleManager::showHdrs(bool clear)
 
     d_isableExpander=false;
 
-    if (g_roup->isLocked() && (0!=pthread_mutex_unlock(knGlobals.netAccess->nntpMutex())))
-      kdDebug(5003) << "failed to unlock nntp mutex" << endl;
+    if (g_roup->isLocked())
+      knGlobals.netAccess->nntpMutex().unlock();     
   }
 
   else { //folder
@@ -419,7 +408,7 @@ void KNArticleManager::setFolder(KNFolder *f)
 {
   f_older=f;
   if(f)
-    v_iew->header()->setLabel(1, i18n("Newsgroups / To"));
+    v_iew->header()->setLabel(1, i18n("Newsgroups/To"));
 }
 
 
@@ -640,6 +629,46 @@ void KNArticleManager::setAllRead(bool r)
 }
 
 
+void KNArticleManager::setAllRead(int lastcount, bool r)
+{
+  if(!g_roup)
+    return;
+
+  int groupLength=g_roup->length();
+  int newCount=g_roup->newCount();
+  int readCount=g_roup->readCount();
+
+  if(lastcount>groupLength)
+    lastcount=groupLength;
+
+  KNRemoteArticle *a;
+  for(int i=groupLength-lastcount; i<groupLength; i++) {
+    a=g_roup->at(i);
+    if(a->getReadFlag()!=r) {
+      a->setRead(r);
+      a->setChanged(true);
+      if(!r) {
+        readCount--;
+        if (a->isNew() && !a->isIgnored())
+          newCount++;
+      }
+      else {
+        readCount++;
+        if (a->isNew() && !a->isIgnored())
+          newCount--;
+      }
+    }
+  }
+
+  g_roup->updateThreadInfo();
+  g_roup->setReadCount(readCount);
+  g_roup->setNewCount(newCount);
+
+  g_roup->updateListItem();
+  showHdrs(true);
+}
+
+
 void KNArticleManager::setRead(KNRemoteArticle::List &l, bool r, bool handleXPosts)
 {
   if(l.isEmpty())
