@@ -36,6 +36,7 @@
 #include <kaction.h>
 #include <kapplication.h>
 #include <kpgpblock.h>
+#include <kstringhandler.h>
 
 #include "resource.h"
 #include "knarticlewidget.h"
@@ -125,7 +126,7 @@ QByteArray KNMimeSource::encodedData(const char *) const
 
 
 KNArticleWidget::KNArticleWidget(KActionCollection* actColl, QWidget *parent, const char *name )
-    : KTextBrowser(parent, name), a_rticle(0), a_tt(0), h_tmlDone(false), emuKMail(false), a_ctions(actColl)
+    : KTextBrowser(parent, name), a_rticle(0), a_tt(0), h_tmlDone(false), emuKMail(false), f_inddialog(0), a_ctions(actColl)
 {
   i_nstances.append(this);
   setNotifyClick( true );
@@ -143,7 +144,7 @@ KNArticleWidget::KNArticleWidget(KActionCollection* actColl, QWidget *parent, co
   u_rlPopup->insertItem(SmallIcon("editcopy"),i18n("&Copy Link Location"), PUP_COPYURL);
   a_ttPopup=new KPopupMenu();
   a_ttPopup->insertItem(SmallIcon("fileopen"),i18n("&Open Attachment"), PUP_OPEN);
-  a_ttPopup->insertItem(SmallIcon("filesave"),i18n("&Save Attachment"), PUP_SAVE);
+  a_ttPopup->insertItem(SmallIcon("filesave"),i18n("&Save Attachment..."), PUP_SAVE);
 
   //actions
   a_ctSave              = KStdAction::save(this, SLOT(slotSave()), a_ctions);
@@ -161,7 +162,7 @@ KNArticleWidget::KNArticleWidget(KActionCollection* actColl, QWidget *parent, co
                           SLOT(slotForward()), a_ctions, "article_forward");
   a_ctCancel            = new KAction(i18n("article","&Cancel Article"), 0 , this,
                           SLOT(slotCancel()), a_ctions, "article_cancel");
-  a_ctSupersede         = new KAction(i18n("S&upersede Article..."), 0 , this,
+  a_ctSupersede         = new KAction(i18n("S&upersede Article"), 0 , this,
                           SLOT(slotSupersede()), a_ctions, "article_supersede");
   a_ctVerify            = new KAction(i18n("&Verify PGP Signature"), 0, this,
                           SLOT(slotVerify()), a_ctions, "article_verify");
@@ -197,7 +198,7 @@ KNArticleWidget::KNArticleWidget(KActionCollection* actColl, QWidget *parent, co
 
   //config
   r_ot13=false;
-  a_ctToggleRot13->setChecked(false);
+  a_ctToggleRot13->setChecked(false);   
   applyConfig();
 }
 
@@ -212,6 +213,7 @@ KNArticleWidget::~KNArticleWidget()
   delete a_ttPopup;
   delete u_rlPopup;
   delete f_actory;
+  delete t_imer;
 }
 
 void KNArticleWidget::setText( const QString& text, const QString& context )
@@ -233,6 +235,81 @@ void KNArticleWidget::scrollDown()
 }
 
 
+void KNArticleWidget::find()
+{
+  if( !f_inddialog ) {
+    f_inddialog = new KEdFind( this, "knodefind", false);
+    connect(f_inddialog,SIGNAL(search()),this,SLOT(slotFindStart()));
+    connect(f_inddialog,SIGNAL(done()),this,SLOT(slotFindDone()));
+  }
+
+  QString string = f_inddialog->getText();
+  f_inddialog->setText(string.isEmpty() ? f_ind_pattern : string);
+
+  f_ind_first = true;
+  f_ind_found = false;
+
+  f_inddialog->show();
+  f_inddialog->result();
+}
+
+void KNArticleWidget::slotFindStart()
+{
+  bool forward = !f_inddialog->get_direction();
+
+  if (f_ind_first) {
+    if (forward) {
+      f_ind_para = 0;
+      f_ind_index = 0;
+   }
+   else {
+      f_ind_para = paragraphs()-1;
+      f_ind_index = paragraphLength(f_ind_para);
+   }
+  }
+  else
+    f_ind_index++;
+
+  f_ind_pattern = f_inddialog->getText();
+  f_ind_first=!QTextEdit::find(f_ind_pattern,f_inddialog->case_sensitive(),false,forward,&f_ind_para,&f_ind_index);
+
+  if (!f_ind_first)
+    f_ind_found = true;
+  else
+    if (f_ind_found) {
+      if (forward) {
+        if ( KMessageBox::questionYesNo( this,
+             i18n("End of article reached.\n" "Continue from the beginning?"),
+  	     i18n("Find") ) == KMessageBox::Yes ) {
+          f_ind_first = true;
+    	  slotFindStart();
+        }
+      }
+      else {
+        if ( KMessageBox::questionYesNo( this,
+             i18n("Beginning of article reached.\n" "Continue from the end?"),
+  	     i18n("Find") ) == KMessageBox::Yes ) {
+          f_ind_first = true;
+   	  slotFindStart();
+        }
+      }
+    }
+  else
+    KMessageBox::information( this,
+    	i18n( "Search string '%1' not found." ).arg(KStringHandler::csqueeze(f_ind_pattern)),
+	i18n( "Find" ) );
+}
+
+void KNArticleWidget::slotFindDone()
+{
+  if (!f_inddialog)
+    return;
+
+  removeSelection();
+  f_inddialog->hide();
+}
+
+
 void KNArticleWidget::focusInEvent(QFocusEvent *e)
 {
   emit focusChanged(e);
@@ -240,7 +317,6 @@ void KNArticleWidget::focusInEvent(QFocusEvent *e)
 
 }
 
-
 void KNArticleWidget::focusOutEvent(QFocusEvent *e)
 {
   emit focusChanged(e);
@@ -319,7 +395,7 @@ void KNArticleWidget::applyConfig()
   KNConfig::Appearance *app=knGlobals.cfgManager->appearance();
   KNConfig::ReadNewsViewer *rnv=knGlobals.cfgManager->readNewsViewer();
 
-  QFont f=(a_ctToggleFixedFont->isChecked()? app->articleFixedFont():app->articleFont());
+  QFont f=(a_ctToggleFixedFont->isChecked()? app->articleFixedFont():app->articleFont());  
 
   //custom tags <articlefont>, <bodyblock>, <txt_attachment>
   QStyleSheetItem *style;
@@ -355,16 +431,17 @@ void KNArticleWidget::applyConfig()
   style->setFontSize(f.pointSize());
   style->setFontUnderline(f.underline());
   style->setFontWeight(f.weight());
-  style->setFontItalic(f.italic());
-
+  style->setFontItalic(f.italic());  
+  
   setPaper( QBrush( app->backgroundColor() ) );
-  setColor( app->textColor() );
 
   QPalette newPalette(palette());
   QColorGroup newColorGroup(newPalette.active());
+  newColorGroup.setColor(QColorGroup::Text, app->textColor());
   newColorGroup.setColor(QColorGroup::Link, app->linkColor());
   newPalette.setActive(newColorGroup);
   newColorGroup = newPalette.inactive();
+  newColorGroup.setColor(QColorGroup::Text, app->textColor());  
   newColorGroup.setColor(QColorGroup::Link, app->linkColor());
   newPalette.setInactive(newColorGroup);
   setPalette(newPalette);
@@ -372,11 +449,11 @@ void KNArticleWidget::applyConfig()
   if(!knGlobals.cfgManager->readNewsGeneral()->autoMark())
     t_imer->stop();
 
-  emuKMail = ((this==knGlobals.artWidget) && knGlobals.cfgManager->readNewsNavigation()->emulateKMail());
+  emuKMail = ((this==knGlobals.artWidget) && knGlobals.cfgManager->readNewsNavigation()->emulateKMail());  
   updateContents();
 }
 
-QString KNArticleWidget::toHtmlString(const QString &line, bool parseURLs, bool beautification, bool allowRot13)
+QString KNArticleWidget::toHtmlString(const QString &line, bool parseURLs, bool beautification, bool allowRot13, bool strictURLparsing)
 {
   QString text,result,enc;
   QRegExp regExp;
@@ -483,7 +560,7 @@ QString KNArticleWidget::toHtmlString(const QString &line, bool parseURLs, bool
         break;
 
       case 'w' :
-        if((parseURLs)&&
+        if((parseURLs)&&(!strictURLparsing)&&
            (text[idx+1].latin1()=='w')) {   // don't do all the stuff for every 'w'
           regExp.setPattern("www\\.[^\\s<>\\(\\)\"\\|\\[\\]\\{\\}]+\\.[^\\s<>\\(\\)\"\\|\\[\\]\\{\\}]+");
           if (regExp.search(text,idx)==(int)idx) {
@@ -523,22 +600,24 @@ QString KNArticleWidget::toHtmlString(const QString &line, bool parseURLs, bool
             lastReplacement=idx;
             break;
           }
-          regExp.setPattern("ftp\\.[^\\s<>\\(\\)\"\\|\\[\\]\\{\\}]+\\.[^\\s<>\\(\\)\"\\|\\[\\]\\{\\}]+");
-          if (regExp.search(text,idx)==(int)idx) {
-            matchLen = regExp.matchedLength();
-            if (text[idx+matchLen-1]=='.')   // remove trailing dot
-              matchLen--;
-            else if (text[idx+matchLen-1]==',')   // remove trailing comma
-              matchLen--;
-            else if (text[idx+matchLen-1]==':')   // remove trailing colon
-              matchLen--;
+	  if (!strictURLparsing) {
+            regExp.setPattern("ftp\\.[^\\s<>\\(\\)\"\\|\\[\\]\\{\\}]+\\.[^\\s<>\\(\\)\"\\|\\[\\]\\{\\}]+");
+            if (regExp.search(text,idx)==(int)idx) {
+              matchLen = regExp.matchedLength();
+              if (text[idx+matchLen-1]=='.')   // remove trailing dot
+                matchLen--;
+              else if (text[idx+matchLen-1]==',')   // remove trailing comma
+                matchLen--;
+              else if (text[idx+matchLen-1]==':')   // remove trailing colon
+                matchLen--;
 
-            result+=QString::fromLatin1("<a href=\"ftp://") + text.mid(idx,matchLen) +
-                    QString::fromLatin1("\">") + text.mid(idx,matchLen) + QString::fromLatin1("</a>");
-            idx+=matchLen-1;
-            lastReplacement=idx;
-            break;
-          }
+              result+=QString::fromLatin1("<a href=\"ftp://") + text.mid(idx,matchLen) +
+                      QString::fromLatin1("\">") + text.mid(idx,matchLen) + QString::fromLatin1("</a>");
+              idx+=matchLen-1;
+              lastReplacement=idx;
+              break;
+            }
+	  }
         }
         result+=text[idx];
         break;
@@ -608,13 +687,13 @@ QString KNArticleWidget::toHtmlString(const QString &line, bool parseURLs, bool
                  (text[idx+matchLen]=='.')||(text[idx+matchLen]==')'))) {
               switch (text[idx].latin1()) {
                 case '_' :
-                  result+=QString("<u>%1</u>").arg(toHtmlString(text.mid(idx+1,matchLen-2),parseURLs,beautification));
+                  result+=QString("<u>%1</u>").arg(toHtmlString(text.mid(idx+1,matchLen-2),parseURLs,beautification,strictURLparsing));
                   break;
                 case '/' :
-                  result+=QString("<i>%1</i>").arg(toHtmlString(text.mid(idx+1,matchLen-2),parseURLs,beautification));
+                  result+=QString("<i>%1</i>").arg(toHtmlString(text.mid(idx+1,matchLen-2),parseURLs,beautification,strictURLparsing));
                   break;
                 case '*' :
-                  result+=QString("<b>%1</b>").arg(toHtmlString(text.mid(idx+1,matchLen-2),parseURLs,beautification));
+                  result+=QString("<b>%1</b>").arg(toHtmlString(text.mid(idx+1,matchLen-2),parseURLs,beautification,strictURLparsing));
                   break;
               }
               idx+=matchLen-1;
@@ -718,6 +797,9 @@ void KNArticleWidget::showBlankPage()
   delete f_actory;                          // purge old image data
   f_actory = new QMimeSourceFactory();
   setMimeSourceFactory(f_actory);
+  
+  // restore background color, might have been changed by html article
+  setPaper(QBrush(knGlobals.cfgManager->appearance()->backgroundColor()));
 
   setText(QString::null);
 
@@ -752,6 +834,9 @@ void KNArticleWidget::showErrorMessage(const QString &s)
   delete f_actory;                          // purge old image data
   f_actory = new QMimeSourceFactory();
   setMimeSourceFactory(f_actory);
+  
+  // restore background color, might have been changed by html article
+  setPaper(QBrush(knGlobals.cfgManager->appearance()->backgroundColor()));
 
   QString errMsg=s;
   errMsg.replace(QRegExp("\n"),QString("<br>"));  // error messages can contain html-links, but are plain text otherwise
@@ -798,17 +883,17 @@ void KNArticleWidget::updateContents()
 
 
 void KNArticleWidget::setArticle(KNArticle *a)
-{
+{ 
   if(a_rticle && a_rticle->isOrphant())
     delete a_rticle; //don't leak orphant articles
 
   a_rticle=a;
   h_tmlDone=false;
   r_ot13=false;
-  a_ctToggleRot13->setChecked(false);
+  a_ctToggleRot13->setChecked(false);      
 
   t_imer->stop();
-
+    
   if(!a)
     showBlankPage();
   else {
@@ -857,7 +942,7 @@ void KNArticleWidget::processJob(KNJobData *j)
     if(!j->canceled()) {
       QString html;
       if (!j->success())
-        html= i18n("<b><font size=+1 color=red>An error occured!</font></b><hr><br>")+j->errorString();
+        html= i18n("<b><font size=+1 color=red>An error occurred!</font></b><hr><br>")+j->errorString();
       else
         html= QString("%1<br>%2").arg(toHtmlString(a->head(),false,false)).arg(toHtmlString(a->body(),false,false));
 
@@ -897,6 +982,9 @@ void KNArticleWidget::createHtmlPage()
   delete f_actory;                          // purge old image data
   f_actory = new QMimeSourceFactory();
   setMimeSourceFactory(f_actory);
+  
+  // restore background color, might have been changed by html article
+  setPaper(QBrush(app->backgroundColor()));
 
   //----------------------------------- <Header> ---------------------------------------
 
@@ -914,7 +1002,7 @@ void KNArticleWidget::createHtmlPage()
           headerHtml += "<tr>";
         headerHtml+=QString("<td align=right><articlefont><b>%1</b></articlefont></td><td width=\"100%\"><articlefont>%2</articlefont></td></tr>")
                       .arg(toHtmlString(header->type())+":")
-                      .arg(toHtmlString(header->asUnicodeString(),true));
+                      .arg(toHtmlString(header->asUnicodeString(),true, false, false, true));
         delete header;
         headerLines++;
       }
@@ -948,9 +1036,8 @@ void KNArticleWidget::createHtmlPage()
       } else if(hb->is("Date")) {
         KMime::Headers::Date *date=static_cast<KMime::Headers::Date*>(hb);
         headerHtml+=toHtmlString(KGlobal::locale()->formatDateTime(date->qdt(), false, true));
-      }
-      else
-        headerHtml+=toHtmlString(hb->asUnicodeString(),true);
+      } else
+        headerHtml+=toHtmlString(hb->asUnicodeString(),true, false, false, true);
 
       headerHtml += dh->headerCloseTag()+"</articlefont></td></tr>";
       headerLines++;
@@ -1117,13 +1204,18 @@ void KNArticleWidget::createHtmlPage()
 
   //Partial message
   if(ct->isPartial()) {
-    html+=i18n("<br><bodyblock><b>This article has the Mime-Type &quot;message/partial&quot;, which KNode cannot handle yet.<br>Meanwhile you can save the article as a text-file and reassemble it by hand.</b></bodyblock></qt>");
+    html+=i18n("<br><bodyblock><b>This article has the MIME type &quot;message/partial&quot;, which KNode cannot handle yet.<br>Meanwhile you can save the article as a text file and reassemble it by hand.</b></bodyblock></qt>");
     setText(html);
     h_tmlDone=true;
 
     //enable actions
     a_ctReply->setEnabled(a_rticle->type()==KMime::Base::ATremote);
     a_ctRemail->setEnabled(a_rticle->type()==KMime::Base::ATremote);
+    a_ctForward->setEnabled(true);
+    a_ctCancel->setEnabled( (a_rticle->type()==KMime::Base::ATremote) ||
+                            (a_rticle->collection()==knGlobals.folManager->sent()));
+    a_ctSupersede->setEnabled( (a_rticle->type()==KMime::Base::ATremote) ||
+                               (a_rticle->collection()==knGlobals.folManager->sent()));
     a_ctSave->setEnabled(true);
     a_ctPrint->setEnabled(true);
     a_ctSelAll->setEnabled(true);
@@ -1131,6 +1223,10 @@ void KNArticleWidget::createHtmlPage()
     a_ctSetCharset->setEnabled(true);
     a_ctSetCharsetKeyb->setEnabled(true);
     a_ctViewSource->setEnabled(true);
+        
+    //start automark-timer
+    if(a_rticle->type()==KMime::Base::ATremote && knGlobals.cfgManager->readNewsGeneral()->autoMark())
+      t_imer->start( (knGlobals.cfgManager->readNewsGeneral()->autoMarkSeconds()*1000), true);
     return;
   }
 
@@ -1252,9 +1348,8 @@ void KNArticleWidget::createHtmlPage()
   //----------------------------------  </Attachments> ---------------------------------
 
   //display html
-  html+="</qt>";
-
-  setText(QString::null);
+  html+="</qt>";  
+  clear();
   setText(html);
   h_tmlDone=true;
 
