@@ -55,13 +55,13 @@ void KNCleanUp::start()
 
   for(KNArticleCollection *c=c_olList.first(); c; c=c_olList.next()) {
     if(c->type()==KNCollection::CTgroup) {
-      d_lg->showMessage(i18n("deleting expired articles in <b>%1</b>").arg(c->name()));
+      d_lg->showMessage(i18n("Deleting expired articles in <b>%1</b>").arg(c->name()));
       kapp->processEvents();
       expireGroup(static_cast<KNGroup*>(c));
       d_lg->doProgress();
     }
     else if(c->type()==KNCollection::CTfolder) {
-      d_lg->showMessage(i18n("compacting folder <b>%1</b>").arg(c->name()));
+      d_lg->showMessage(i18n("Compacting folder <b>%1</b>").arg(c->name()));
       kapp->processEvents();
       compactFolder(static_cast<KNFolder*>(c));
       d_lg->doProgress();
@@ -122,7 +122,7 @@ void KNCleanUp::expireGroup(KNGroup *g, bool showResult)
         idRef=art->idRef();
         while(idRef!=0) {
           ref=g->byId(idRef);
-          ref->setExpired(false);
+          ref->setExpired(false);          
           idRef=ref->idRef();
         }
       }
@@ -137,7 +137,7 @@ void KNCleanUp::expireGroup(KNGroup *g, bool showResult)
       foundId=0;
       while(foundId==0 && idRef!=0) {
         ref=g->byId(idRef);
-        if(!ref->isExpired()) foundId=ref->id();
+        if(!ref->isExpired()) foundId=ref->id();        
         idRef=ref->idRef();
       }
       art->setIdRef(foundId);
@@ -259,7 +259,7 @@ KNCleanUp::ProgressDialog::ProgressDialog(int steps)
 
   QVBoxLayout *topL=new QVBoxLayout(top, 10);
 
-  QLabel *l=new QLabel(i18n("Cleaning up. Please wait ..."), top);
+  QLabel *l=new QLabel(i18n("Cleaning up. Please wait..."), top);
   topL->addWidget(l);
 
   KSeparator *sep=new KSeparator(top);
