@@ -2,7 +2,7 @@
     kncollectionviewitem.h
 
     KNode, the KDE newsreader
-    Copyright (c) 1999-2000 the KNode authors.
+    Copyright (c) 1999-2001 the KNode authors.
     See file AUTHORS for details
 
     This program is free software; you can redistribute it and/or modify
@@ -31,9 +31,13 @@ class KNCollectionViewItem : public KNLVItemBase  {
 
     void setNumber ( int column, int number );  // avoid converting back and forth in key()
     QString key(int, bool) const;
+
+    // DND
+    virtual QDragObject* dragObject();
+    virtual bool acceptDrag(QDropEvent* event) const;
     
     KNCollection *coll;
-    
+
   protected:
     bool firstColBold();
     virtual QString shortString(QString text, int col, int width, QFontMetrics fm);
