@@ -240,8 +240,8 @@ class KNComposer::Editor : public KEdit {
   protected:
 
     // DND handling
-    virtual void dragEnterEvent(QDragEnterEvent *);
-    virtual void dropEvent(QDropEvent *);
+    virtual void contentsDragEnterEvent(QDragEnterEvent *);
+    virtual void contentsDropEvent(QDropEvent *);
 
 };
 
