@@ -63,7 +63,7 @@ void KNConfig::Identity::loadConfig(KConfigBase *c)
   s_igningKey = c->readEntry("SigningKey").local8Bit();
   u_seSigFile=c->readBoolEntry("UseSigFile",false);
   u_seSigGenerator=c->readBoolEntry("UseSigGenerator",false);
-  s_igPath=c->readEntry("sigFile");
+  s_igPath=c->readPathEntry("sigFile");
   s_igText=c->readEntry("sigText");
 }
 
@@ -705,7 +705,7 @@ KNConfig::ReadNewsViewer::ReadNewsViewer()
     b_rowser = BTother;
   else
     b_rowser = BTkonq;
-  b_rowserCommand=conf->readEntry("BrowserCommand","netscape %u");
+  b_rowserCommand=conf->readPathEntry("BrowserCommand","netscape %u");
 }
 
 
@@ -1115,7 +1115,7 @@ KNConfig::PostNewsComposer::PostNewsComposer()
   c_ursorOnTop=conf->readBoolEntry("cursorOnTop",false);
   u_seExtEditor=conf->readBoolEntry("useExternalEditor",false);
   i_ntro=conf->readEntry("Intro","%NAME wrote:");
-  e_xternalEditor=conf->readEntry("externalEditor","kwrite %f");
+  e_xternalEditor=conf->readPathEntry("externalEditor","kwrite %f");
 }
 
 
