@@ -18,6 +18,7 @@
 #include <qvbox.h>
 #include <qpainter.h>
 #include <qwhatsthis.h>
+#include <qlabel.h>
 
 #include <klocale.h>
 #include <knumvalidator.h>
@@ -31,6 +32,8 @@
 #include <kspell.h>
 #include <kcombobox.h>
 #include <kpgpui.h>
+#include <kurlcompletion.h>
+#include <kiconloader.h>
 
 #include "knaccountmanager.h"
 #include "kngroupmanager.h"
@@ -43,8 +46,6 @@
 #include "knscoring.h"
 #include "knconfigmanager.h"
 #include "knpgp.h"
-#include <qlabel.h>
-#include <kiconloader.h>
 
 
 KNConfig::IdentityWidget::IdentityWidget(Identity *d, QWidget *p, const char *n) : BaseWidget(p, n), d_ata(d)
@@ -64,36 +65,36 @@ KNConfig::IdentityWidget::IdentityWidget(Identity *d, QWidget *p, const char *n)
   o_rga->setText(d_ata->o_rga);
 
   e_mail=new KLineEdit(this);
-  l=new QLabel(e_mail, i18n("Email A&ddress:"), this);
+  l=new QLabel(e_mail, i18n("Email a&ddress:"), this);
   topL->addWidget(l, 2,0);
   topL->addMultiCellWidget(e_mail, 2,2, 1,2);
   e_mail->setText(d_ata->e_mail);
 
   r_eplyTo=new KLineEdit(this);
-  l=new QLabel(r_eplyTo, i18n("&Reply-To Address:"), this);
+  l=new QLabel(r_eplyTo, i18n("&Reply-to address:"), this);
   topL->addWidget(l, 3,0);
   topL->addMultiCellWidget(r_eplyTo, 3,3, 1,2);
   r_eplyTo->setText(d_ata->r_eplyTo);
 
   m_ailCopiesTo=new KLineEdit(this);
-  l=new QLabel(m_ailCopiesTo, i18n("&Mail-Copies-To:"), this);
+  l=new QLabel(m_ailCopiesTo, i18n("&Mail-copies-to:"), this);
   topL->addWidget(l, 4,0);
   topL->addMultiCellWidget(m_ailCopiesTo, 4,4, 1,2);
   m_ailCopiesTo->setText(d_ata->m_ailCopiesTo);
 
-  s_igningKey = new QLabel( this );
-  s_igningKey->setFrameStyle( QFrame::Panel | QFrame::Sunken );
-  s_igningKey->setText( d_ata->s_igningKey );
-  l=new QLabel( i18n("Signing Key:"), this );
-  QPushButton *c_hangeBtn = new QPushButton( i18n("Chan&ge..."), this );
-  connect( c_hangeBtn, SIGNAL(clicked()), 
-           this, SLOT(slotSigningKeyChange()) );
-  c_hangeBtn->setAutoDefault( false );
-  topL->addWidget( l, 5, 0 );
-  topL->addWidget( s_igningKey, 5, 1 );
-  topL->addWidget( c_hangeBtn, 5, 2 );
-  QWhatsThis::add( l, i18n("<qt><p>The OpenPGP key you choose here will be "
-                           "used to sign your articles.</p></qt>") );
+  s_igningKey = new Kpgp::SecretKeyRequester(this);
+  s_igningKey->dialogButton()->setText(i18n("Chan&ge..."));
+  s_igningKey->setDialogCaption(i18n("Your OpenPGP Key"));
+  s_igningKey->setDialogMessage(i18n("Select the OpenPGP key which should be "
+				     "used for signing articles."));
+  s_igningKey->setKeyIDs(Kpgp::KeyIDList() << d_ata->s_igningKey);
+  l=new QLabel(s_igningKey, i18n("Signing ke&y:"), this);
+  topL->addWidget(l, 5,0);
+  topL->addMultiCellWidget(s_igningKey, 5,5, 1,2);
+  QString msg = i18n("<qt><p>The OpenPGP key you choose here will be "
+		     "used to sign your articles.</p></qt>");
+  QWhatsThis::add( l, msg );
+  QWhatsThis::add( s_igningKey, msg );
 
   b_uttonGroup = new QButtonGroup(this);
   connect( b_uttonGroup, SIGNAL(clicked(int)),
@@ -107,10 +108,12 @@ KNConfig::IdentityWidget::IdentityWidget(Identity *d, QWidget *p, const char *n)
 
   s_ig = new KLineEdit(this);
 
-  f_ileName = new QLabel(s_ig, i18n("Signature &File:"), this);
+  f_ileName = new QLabel(s_ig, i18n("Signature &file:"), this);
   topL->addWidget(f_ileName, 7, 0 );
   topL->addWidget(s_ig, 7, 1 );
   s_ig->setText(d_ata->s_igPath);
+  c_ompletion = new KURLCompletion();
+  s_ig->setCompletionObject(c_ompletion);
 
   c_hooseBtn = new QPushButton( i18n("Choo&se..."), this);
   connect(c_hooseBtn, SIGNAL(clicked()),
@@ -144,6 +147,7 @@ KNConfig::IdentityWidget::IdentityWidget(Identity *d, QWidget *p, const char *n)
 
 KNConfig::IdentityWidget::~IdentityWidget()
 {
+  delete c_ompletion;
 }
 
 void KNConfig::IdentityWidget::textFileNameChanged(const QString &text)
@@ -161,34 +165,16 @@ void KNConfig::IdentityWidget::apply()
   d_ata->e_mail=e_mail->text();
   d_ata->r_eplyTo=r_eplyTo->text();
   d_ata->m_ailCopiesTo=m_ailCopiesTo->text();
-  d_ata->s_igningKey = s_igningKey->text().local8Bit();
+  d_ata->s_igningKey = s_igningKey->keyIDs().first();
   d_ata->u_seSigFile=s_igFile->isChecked();
   d_ata->u_seSigGenerator=s_igGenerator->isChecked();
-  d_ata->s_igPath=s_ig->text();
+  d_ata->s_igPath=c_ompletion->replacedPath(s_ig->text());
   d_ata->s_igText=s_igEditor->text();
 
   if(d_ata->isGlobal())
     d_ata->save();
 }
 
-
-void KNConfig::IdentityWidget::slotSigningKeyChange()
-{
-  Kpgp::Module *pgp;
-  
-  if ( !(pgp = Kpgp::Module::getKpgp()) )
-    return;
-
-  QCString keyID = s_igningKey->text().local8Bit();
-  keyID = pgp->selectSecretKey( i18n("Your OpenPGP Key"),
-                                i18n("Select the OpenPGP key which should be "
-                                     "used for signing articles."),
-                                keyID );
-  if ( !keyID.isEmpty() )
-    s_igningKey->setText( keyID );
-}
-
-
 void KNConfig::IdentityWidget::slotSignatureType(int type)
 {
   bool sigFromFile = (type==0);
@@ -210,14 +196,14 @@ void KNConfig::IdentityWidget::slotSignatureType(int type)
 
 void KNConfig::IdentityWidget::slotSignatureChoose()
 {
-  QString tmp=KFileDialog::getOpenFileName(s_ig->text(),QString::null,this,i18n("Choose Signature"));
+  QString tmp=KFileDialog::getOpenFileName(c_ompletion->replacedPath(s_ig->text()),QString::null,this,i18n("Choose Signature"));
   if(!tmp.isEmpty()) s_ig->setText(tmp);
 }
 
 
 void KNConfig::IdentityWidget::slotSignatureEdit()
 {
-  QString fileName = s_ig->text().stripWhiteSpace();
+  QString fileName = c_ompletion->replacedPath(s_ig->text()).stripWhiteSpace();
 
   if (fileName.isEmpty()) {
     KMessageBox::sorry(this, i18n("You must specify a filename!"));
@@ -895,14 +881,14 @@ KNConfig::ReadNewsGeneralWidget::ReadNewsGeneralWidget(ReadNewsGeneral *d, QWidg
 
   a_utoCB=new QCheckBox(i18n("Check for new articles a&utomatically"), hgb);
   m_axFetch=new KIntSpinBox(0, 100000, 1, 0, 10, hgb);
-  l1=new QLabel(m_axFetch, i18n("&Maximal number of articles to fetch"), hgb);
-  m_arkCB=new QCheckBox(i18n("Mar&k article as read after"), hgb);
+  l1=new QLabel(m_axFetch, i18n("&Maximum number of articles to fetch:"), hgb);
+  m_arkCB=new QCheckBox(i18n("Mar&k article as read after:"), hgb);
   m_arkSecs=new KIntSpinBox(0, 9999, 1, 0, 10, hgb);
   connect(m_arkCB, SIGNAL(toggled(bool)), m_arkSecs, SLOT(setEnabled(bool)));
   m_arkSecs->setSuffix(i18n(" sec"));
   m_arkCrossCB=new QCheckBox(i18n("Mark c&rossposted articles as read"), hgb);
 
-  s_martScrollingCB=new QCheckBox(i18n("Smart Scrolli&ng"), lgb);
+  s_martScrollingCB=new QCheckBox(i18n("Smart scrolli&ng"), lgb);
   e_xpThrCB=new QCheckBox(i18n("Show &whole thread on expanding"), lgb);
   d_efaultExpandCB=new QCheckBox(i18n("Default to e&xpanded threads"), lgb);
   s_coreCB=new QCheckBox(i18n("Show article &score"), lgb);
@@ -910,10 +896,10 @@ KNConfig::ReadNewsGeneralWidget::ReadNewsGeneralWidget(ReadNewsGeneral *d, QWidg
 
   c_ollCacheSize=new KIntSpinBox(0, 99999, 1, 1, 10, cgb);
   c_ollCacheSize->setSuffix(" KB");
-  l2=new QLabel(c_ollCacheSize, i18n("Cach&e size for headers"), cgb);
+  l2=new QLabel(c_ollCacheSize, i18n("Cach&e size for headers:"), cgb);
   a_rtCacheSize=new KIntSpinBox(0, 99999, 1, 1, 10, cgb);
   a_rtCacheSize->setSuffix(" KB");
-  l3=new QLabel(a_rtCacheSize, i18n("Cache si&ze for articles"), cgb);
+  l3=new QLabel(a_rtCacheSize, i18n("Cache si&ze for articles:"), cgb);
 
   QVBoxLayout *topL=new QVBoxLayout(this, 5);
   QGridLayout *hgbL=new QGridLayout(hgb, 5,2, 8,5);
@@ -1008,12 +994,12 @@ KNConfig::ReadNewsNavigationWidget::ReadNewsNavigationWidget(ReadNewsNavigation
   topL->addWidget(gb);
 
   gbL->addSpacing(fontMetrics().lineSpacing()-4);
-  e_muKMailCB=new QCheckBox(i18n("Emulate the &keyboard behaviour of KMail"), gb);
+  e_muKMailCB=new QCheckBox(i18n("Emulate the &keyboard behavior of KMail"), gb);
   gbL->addWidget(e_muKMailCB);
 
   // ==== Mark All as Read ====================================================
 
-  gb=new QGroupBox(i18n("\"Mark All as Read\" triggers the following actions:"), this);
+  gb=new QGroupBox(i18n("\"Mark All as Read\" Triggers Following Actions"), this);
   gbL=new QVBoxLayout(gb, 8, 5);
   topL->addWidget(gb);
 
@@ -1023,7 +1009,7 @@ KNConfig::ReadNewsNavigationWidget::ReadNewsNavigationWidget(ReadNewsNavigation
 
   // ==== Mark Thread as Read =================================================
 
-  gb=new QGroupBox(i18n("\"Mark Thread as Read\" triggers the following actions:"), this);
+  gb=new QGroupBox(i18n("\"Mark Thread as Read\" Triggers Following Actions"), this);
   gbL=new QVBoxLayout(gb, 8, 5);
   topL->addWidget(gb);
 
@@ -1035,7 +1021,7 @@ KNConfig::ReadNewsNavigationWidget::ReadNewsNavigationWidget(ReadNewsNavigation
 
   // ==== Ignore Thread =======================================================
 
-  gb=new QGroupBox(i18n("\"Ignore Thread\" triggers the following actions:"), this);
+  gb=new QGroupBox(i18n("\"Ignore Thread\" Triggers Following Actions"), this);
   gbL=new QVBoxLayout(gb, 8, 5);
   topL->addWidget(gb);
 
@@ -1109,7 +1095,7 @@ KNConfig::ReadNewsViewerWidget::ReadNewsViewerWidget(ReadNewsViewer *d, QWidget
   b_rowser->insertItem("Opera");
   b_rowser->insertItem("Other");
   connect(b_rowser, SIGNAL(activated(int)), SLOT(slotBrowserTypeChanged(int)));
-  l1=new QLabel(b_rowser, i18n("Open &links with"), bgb);
+  l1=new QLabel(b_rowser, i18n("Open &links with:"), bgb);
   b_rowserCommand = new KLineEdit(bgb);
   c_hooseBrowser= new QPushButton(i18n("Choo&se..."),bgb);
   connect(c_hooseBrowser, SIGNAL(clicked()), SLOT(slotChooseBrowser()));
@@ -1405,7 +1391,7 @@ KNConfig::DisplayedHeaderConfDialog::DisplayedHeaderConfDialog(KNDisplayedHeader
   n_ameE=new KLineEdit(nameW);
   connect(n_ameE, SIGNAL(textChanged(const QString&)), SLOT(slotNameChanged(const QString&)));
   n_ameE->setMaxLength(64);
-  nameL->addWidget(new QLabel(n_ameE, i18n("Displayed Na&me:"),nameW),1,0);
+  nameL->addWidget(new QLabel(n_ameE, i18n("Displayed na&me:"),nameW),1,0);
   nameL->addWidget(n_ameE,1,1);
   nameL->setColStretch(1,1);
 
@@ -1415,20 +1401,20 @@ KNConfig::DisplayedHeaderConfDialog::DisplayedHeaderConfDialog(KNDisplayedHeader
   QVBoxLayout *ngbL = new QVBoxLayout(ngb, 8, 5);
   ngbL->setAutoAdd(true);
   ngbL->addSpacing(fontMetrics().lineSpacing()-4);
-  n_ameCB[0]=new QCheckBox(i18n("&large"), ngb);
-  n_ameCB[1]=new QCheckBox(i18n("&bold"), ngb);
-  n_ameCB[2]=new QCheckBox(i18n("&italic"), ngb);
-  n_ameCB[3]=new QCheckBox(i18n("&underlined"), ngb);
+  n_ameCB[0]=new QCheckBox(i18n("&Large"), ngb);
+  n_ameCB[1]=new QCheckBox(i18n("&Bold"), ngb);
+  n_ameCB[2]=new QCheckBox(i18n("&Italic"), ngb);
+  n_ameCB[3]=new QCheckBox(i18n("&Underlined"), ngb);
   topL->addWidget(ngb,1,0);
 
   QGroupBox *vgb=new QGroupBox(i18n("Value"), page);
   QVBoxLayout *vgbL = new QVBoxLayout(vgb, 8, 5);
   vgbL->setAutoAdd(true);
   vgbL->addSpacing(fontMetrics().lineSpacing()-4);
-  v_alueCB[0]=new QCheckBox(i18n("l&arge"), vgb);
-  v_alueCB[1]=new QCheckBox(i18n("bol&d"), vgb);
-  v_alueCB[2]=new QCheckBox(i18n("i&talic"), vgb);
-  v_alueCB[3]=new QCheckBox(i18n("u&nderlined"), vgb);
+  v_alueCB[0]=new QCheckBox(i18n("L&arge"), vgb);
+  v_alueCB[1]=new QCheckBox(i18n("Bol&d"), vgb);
+  v_alueCB[2]=new QCheckBox(i18n("I&talic"), vgb);
+  v_alueCB[3]=new QCheckBox(i18n("U&nderlined"), vgb);
   topL->addWidget(vgb,1,1);
 
   topL->setColStretch(0,1);
@@ -1816,19 +1802,19 @@ KNConfig::PostNewsTechnicalWidget::PostNewsTechnicalWidget(PostNewsTechnical *d,
   ggbL->addRowSpacing(0, fontMetrics().lineSpacing()-4);
   c_harset=new QComboBox(ggb);
   c_harset->insertStringList(d->composerCharsets());
-  ggbL->addWidget(new QLabel(c_harset, i18n("Cha&rset"), ggb), 1,0);
+  ggbL->addWidget(new QLabel(c_harset, i18n("Cha&rset:"), ggb), 1,0);
   ggbL->addWidget(c_harset, 1,1);
 
   e_ncoding=new QComboBox(ggb);
   e_ncoding->insertItem(i18n("Allow 8-bit"));
   e_ncoding->insertItem(i18n("7-bit (Quoted-Printable)"));
-  ggbL->addWidget(new QLabel(e_ncoding, i18n("Enco&ding"), ggb), 2,0);
+  ggbL->addWidget(new QLabel(e_ncoding, i18n("Enco&ding:"), ggb), 2,0);
   ggbL->addWidget(e_ncoding, 2,1);
 
   u_seOwnCSCB=new QCheckBox(i18n("Use o&wn default charset when replying"), ggb);
   ggbL->addMultiCellWidget(u_seOwnCSCB, 3,3, 0,1);
 
-  g_enMIdCB=new QCheckBox(i18n("&Generate Message-Id"), ggb);
+  g_enMIdCB=new QCheckBox(i18n("&Generate message-id"), ggb);
   connect(g_enMIdCB, SIGNAL(toggled(bool)), this, SLOT(slotGenMIdCBToggled(bool)));
   ggbL->addMultiCellWidget(g_enMIdCB, 4,4, 0,1);
   h_ost=new KLineEdit(ggb);
@@ -2052,14 +2038,14 @@ KNConfig::PostNewsComposerWidget::PostNewsComposerWidget(PostNewsComposer *d, QW
   replyL->addRowSpacing(0, fontMetrics().lineSpacing()-4);
 
   i_ntro=new KLineEdit(replyB);
-  replyL->addMultiCellWidget(new QLabel(i_ntro,i18n("&Introduction Phrase:"), replyB),1,1,0,1);
+  replyL->addMultiCellWidget(new QLabel(i_ntro,i18n("&Introduction phrase:"), replyB),1,1,0,1);
   replyL->addMultiCellWidget(i_ntro, 2,2,0,1);
   replyL->addMultiCellWidget(new QLabel(i18n("Placeholders: %NAME=name, %EMAIL=email address,\n%DATE=date, %MSID=message-id, %GROUP=group name"), replyB),3,3,0,1);
 
   r_ewrapCB=new QCheckBox(i18n("Rewrap quoted te&xt automatically"), replyB);
   replyL->addMultiCellWidget(r_ewrapCB, 4,4,0,1);
 
-  a_uthSigCB=new QCheckBox(i18n("Include the a&uthors signature"), replyB);
+  a_uthSigCB=new QCheckBox(i18n("Include the a&uthor's signature"), replyB);
   replyL->addMultiCellWidget(a_uthSigCB, 5,5,0,1);
 
   c_ursorOnTopCB=new QCheckBox(i18n("Put the cursor &below the introduction phrase"), replyB);
@@ -2076,7 +2062,7 @@ KNConfig::PostNewsComposerWidget::PostNewsComposerWidget(PostNewsComposer *d, QW
   editorL->addRowSpacing(0, fontMetrics().lineSpacing()-4);
 
   e_ditor=new KLineEdit(editorB);
-  editorL->addWidget(new QLabel(e_ditor, i18n("Specify Edi&tor:"), editorB),1,0);
+  editorL->addWidget(new QLabel(e_ditor, i18n("Specify edi&tor:"), editorB),1,0);
   editorL->addWidget(e_ditor,1,1);
   QPushButton *btn = new QPushButton(i18n("Choo&se..."),editorB);
   connect(btn, SIGNAL(clicked()), SLOT(slotChooseEditor()));
@@ -2177,7 +2163,7 @@ KNConfig::PrivacyWidget::PrivacyWidget(QWidget *p, const char *n)
   QBoxLayout *topLayout = new QVBoxLayout(this, 5);
   c_onf = new Kpgp::Config(this,"knode pgp config",false);
   topLayout->addWidget(c_onf);
-  QGroupBox *optBox = new QGroupBox(i18n("KNode specific options"), this);
+  QGroupBox *optBox = new QGroupBox(i18n("KNode Specific Options"), this);
   topLayout->addWidget(optBox);
   QBoxLayout *groupL = new QVBoxLayout(optBox, KDialog::spacingHint());
   groupL->addSpacing(fontMetrics().lineSpacing());
@@ -2225,19 +2211,19 @@ KNConfig::CleanupWidget::CleanupWidget(Cleanup *d, QWidget *p, const char *n) :
 
   g_roupDays=new KIntSpinBox(0, 99999, 1, 0, 10, groupsB);
   g_roupDays->setSuffix(i18n(" days"));
-  g_roupDaysL=new QLabel(g_roupDays,i18n("&Purge groups every"), groupsB);
+  g_roupDaysL=new QLabel(g_roupDays,i18n("&Purge groups every:"), groupsB);
   groupsL->addWidget(g_roupDaysL,2,0);
   groupsL->addWidget(g_roupDays,2,1,Qt::AlignRight);
 
   r_eadDays=new KIntSpinBox(0, 99999, 1, 0, 10, groupsB);
   r_eadDays->setSuffix(i18n(" days"));
-  r_eadDaysL=new QLabel(r_eadDays, i18n("&Keep read articles"), groupsB);
+  r_eadDaysL=new QLabel(r_eadDays, i18n("&Keep read articles:"), groupsB);
   groupsL->addWidget(r_eadDaysL,3,0);
   groupsL->addWidget(r_eadDays,3,1,Qt::AlignRight);
 
   u_nreadDays=new KIntSpinBox(0, 99999, 1, 0, 10, groupsB);
   u_nreadDays->setSuffix(i18n(" days"));
-  u_nreadDaysL=new QLabel(u_nreadDays, i18n("Keep u&nread articles"), groupsB);
+  u_nreadDaysL=new QLabel(u_nreadDays, i18n("Keep u&nread articles:"), groupsB);
   groupsL->addWidget(u_nreadDaysL,4,0);
   groupsL->addWidget(u_nreadDays,4,1,Qt::AlignRight);
 
@@ -2263,7 +2249,7 @@ KNConfig::CleanupWidget::CleanupWidget(Cleanup *d, QWidget *p, const char *n) :
 
   f_olderDays=new KIntSpinBox(0, 99999, 1, 0, 10, foldersB);
   f_olderDays->setSuffix(i18n(" days"));
-  f_olderDaysL=new QLabel(f_olderDays,i18n("P&urge folders every"), foldersB);
+  f_olderDaysL=new QLabel(f_olderDays,i18n("P&urge folders every:"), foldersB);
   foldersL->addWidget(f_olderDaysL,2,0);
   foldersL->addWidget(f_olderDays,2,1,Qt::AlignRight);
 
@@ -2332,7 +2318,7 @@ KNConfig::CacheWidget::CacheWidget(Cache *d, QWidget *p, const char *n)
   QVBoxLayout *topL=new QVBoxLayout(this, 5);
 
   // memory
-  QGroupBox *memGB=new QGroupBox(i18n("Memory cache"), this);
+  QGroupBox *memGB=new QGroupBox(i18n("Memory Cache"), this);
   topL->addWidget(memGB);
   QGridLayout *memL=new QGridLayout(memGB, 3,2, 8,5);
   memL->addRowSpacing(0, fontMetrics().lineSpacing()-4);
@@ -2350,7 +2336,7 @@ KNConfig::CacheWidget::CacheWidget(Cache *d, QWidget *p, const char *n)
 
 
   // disk
-  QGroupBox *diskGB=new QGroupBox(i18n("Disk cache"), this);
+  QGroupBox *diskGB=new QGroupBox(i18n("Disk Cache"), this);
   topL->addWidget(diskGB);
   QGridLayout *diskL=new QGridLayout(diskGB, 3,2, 8,5);
   diskL->addRowSpacing(0, fontMetrics().lineSpacing()-4);
