@@ -17,7 +17,8 @@
 #ifndef KNFOLDERMANAGER_H
 #define KNFOLDERMANAGER_H
 
-#include <qlist.h>
+#include <qglobal.h>
+#include <qptrlist.h>
 
 class KNListView;
 class KNFolder;
@@ -77,7 +78,7 @@ class KNFolderManager
     void createListItem(KNFolder *f);
         
     KNFolder  *c_urrentFolder;
-    QList<KNFolder> f_List;
+    QPtrList<KNFolder> f_List;
     int l_astId;
     KNListView *v_iew;
     KNArticleManager *a_rtManager;
