@@ -15,7 +15,7 @@
 */
 
 #include <ksimpleconfig.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 
 #include "utilities.h"
