@@ -15,6 +15,7 @@
 */
 
 #include <qhbox.h>
+#include <qinputdialog.h>
 
 #include <kaccel.h>
 #include <kconfig.h>
@@ -79,11 +80,9 @@ KNMainWindow::KNMainWindow()
   sb->setItemAlignment (SB_MAIN,AlignLeft | AlignVCenter);
   sb->insertItem(QString::null, SB_FILTER,2);
   sb->setItemAlignment (SB_FILTER,AlignLeft | AlignVCenter);
-
-  s_tatusGroup = new KStatusBarLabel( QString::null, SB_GROUP, sb );
-  sb->addWidget( s_tatusGroup );
-//   sb->insertItem(QString::null,SB_GROUP,3);
-//   sb->setItemAlignment (SB_GROUP,AlignLeft | AlignVCenter);
+  s_tatusGroup = new KStatusBarLabel( QString::null, SB_GROUP, sb );  
+  s_tatusGroup->setAlignment(AlignLeft | AlignVCenter);
+  sb->addWidget( s_tatusGroup, 3 );   
 
   //setup splitter behaviour
   manager()->setSplitterHighResolution(true);
@@ -340,8 +339,8 @@ void KNMainWindow::setStatusMsg(const QString& text, int id)
     }
     s_tatusGroup->setText( mtext );
   }
-  else {
-    statusBar()->changeItem(text, id);
+  else {      
+    statusBar()->changeItem(text, id);  
   }
 }
 
@@ -529,6 +528,7 @@ void KNMainWindow::configChanged()
   p.setColor(QColorGroup::Base, app->backgroundColor());
   p.setColor(QColorGroup::Text, app->textColor());
   c_olView->setPalette(p);
+  c_olView->setAlternateBackground(app->backgroundColor());
   h_drView->setPalette(p);
 
   if (knGlobals.cfgManager->readNewsGeneral()->showScore()) {
@@ -589,7 +589,7 @@ void KNMainWindow::initActions()
                               SLOT(slotAccGetNewHdrs()), actionCollection(), "account_dnlHeaders");
   a_ctAccDelete             = new KAction(i18n("&Delete Account"), "editdelete", 0, this,
                               SLOT(slotAccDelete()), actionCollection(), "account_delete");
-  a_ctAccPostNewArticle     = new KAction(i18n("&Post to Newsgroup..."), "filenew", Key_P , this,
+  a_ctAccPostNewArticle     = new KAction(i18n("&Post to Newsgroup..."), "mail_new", Key_P , this,
                               SLOT(slotAccPostNewArticle()), actionCollection(), "article_postNew");
 
   //collection-view - groups
@@ -603,12 +603,14 @@ void KNMainWindow::initActions()
                               SLOT(slotGrpExpire()), actionCollection(), "group_expire");
   a_ctGrpReorganize         = new KAction(i18n("Re&organize Group"), 0, this,
                               SLOT(slotGrpReorganize()), actionCollection(), "group_reorg");
-  a_ctGrpUnsubscribe        = new KAction(i18n("&Unsubscribe from Group"), "news_unsubscribe", 0, this,
+  a_ctGrpUnsubscribe        = new KAction(i18n("&Unsubscribe From Group"), "news_unsubscribe", 0, this,
                               SLOT(slotGrpUnsubscribe()), actionCollection(), "group_unsubscribe");
   a_ctGrpSetAllRead         = new KAction(i18n("Mark All as &Read"), "goto", 0, this,
                               SLOT(slotGrpSetAllRead()), actionCollection(), "group_allRead");
   a_ctGrpSetAllUnread       = new KAction(i18n("Mark All as U&nread"), 0, this,
                               SLOT(slotGrpSetAllUnread()), actionCollection(), "group_allUnread");
+  a_ctGrpSetUnread          = new KAction(i18n("Mark Last as U&nread..."), 0, this,
+                              SLOT(slotGrpSetUnread()), actionCollection(), "group_unread");
 
   //collection-view - folder
   a_ctFolNew                = new KAction(i18n("&New Folder"), "folder_new", 0, this,
@@ -625,9 +627,9 @@ void KNMainWindow::initActions()
                               SLOT(slotFolCompactAll()), actionCollection(), "folder_compact_all");
   a_ctFolEmpty              = new KAction(i18n("&Empty Folder"), 0, this,
                               SLOT(slotFolEmpty()), actionCollection(), "folder_empty");
-  a_ctFolMboxImport         = new KAction(i18n("&Import MBox Folder"), 0, this,
+  a_ctFolMboxImport         = new KAction(i18n("&Import MBox Folder..."), 0, this,
                               SLOT(slotFolMBoxImport()), actionCollection(), "folder_MboxImport");
-  a_ctFolMboxExport         = new KAction(i18n("E&xport as MBox Folder"), 0, this,
+  a_ctFolMboxExport         = new KAction(i18n("E&xport as MBox Folder..."), 0, this,
                               SLOT(slotFolMBoxExport()), actionCollection(), "folder_MboxExport");
 
   //header-view - list-handling
@@ -649,8 +651,10 @@ void KNMainWindow::initActions()
   a_ctArtFilter->setShortcutConfigurable(false);
   a_ctArtFilterKeyb         = new KAction(i18n("Filter"), Key_F6, actionCollection(), "view_Filter_Keyb");
   a_ctArtFilterKeyb->plugAccel(a_ccel);
-  a_ctArtSearch             = new KAction(i18n("&Search Articles..."),"find" , Key_F4 , this,
+  a_ctArtSearch             = new KAction(i18n("&Search Articles..."),"mail_find" , Key_F4 , this,
                               SLOT(slotArtSearch()), actionCollection(), "article_search");
+  a_ctArtFind               = new KAction(i18n("F&ind in Article..."),KStdAccel::shortcut(KStdAccel::Find) , this,
+                              SLOT(slotArtFind()), actionCollection(), "find_in_article");
   a_ctArtRefreshList        = new KAction(i18n("&Refresh List"),"reload", KStdAccel::shortcut(KStdAccel::Reload), this,
                               SLOT(slotArtRefreshList()), actionCollection(), "view_Refresh");
   a_ctArtCollapseAll        = new KAction(i18n("&Collapse All Threads"), 0 , this,
@@ -672,13 +676,13 @@ void KNMainWindow::initActions()
                               SLOT(slotArtSetThreadRead()), actionCollection(), "thread_read");
   a_ctArtSetThreadUnread    = new KAction(i18n("Mark T&hread as Unread"), CTRL+Key_U , this,
                               SLOT(slotArtSetThreadUnread()), actionCollection(), "thread_unread");
-  a_ctArtOpenNewWindow      = new KAction(i18n("Open in own &Window"), "window_new", Key_O , this,
+  a_ctArtOpenNewWindow      = new KAction(i18n("Open in Own &Window"), "window_new", Key_O , this,
                               SLOT(slotArtOpenNewWindow()), actionCollection(), "article_ownWindow");
 
   // scoring
   a_ctScoresEdit            = new KAction(i18n("&Edit Scoring Rules..."), "edit", CTRL+Key_E, this,
                               SLOT(slotScoreEdit()), actionCollection(), "scoreedit");
-  a_ctReScore               = new KAction(i18n("Recalculate &Scores..."), 0, this,
+  a_ctReScore               = new KAction(i18n("Recalculate &Scores"), 0, this,
                               SLOT(slotReScore()),actionCollection(),"rescore");
   a_ctScoreLower            = new KAction(i18n("&Lower Score for Author..."), CTRL+Key_L, this,
                               SLOT(slotScoreLower()), actionCollection(), "scorelower");
@@ -1206,6 +1210,7 @@ void KNMainWindow::slotCollectionSelected(QListViewItem *i)
     a_ctGrpUnsubscribe->setEnabled(enabled);
     a_ctGrpSetAllRead->setEnabled(enabled);
     a_ctGrpSetAllUnread->setEnabled(enabled);
+    a_ctGrpSetUnread->setEnabled(enabled);
     a_ctArtFilter->setEnabled(enabled);
     a_ctArtFilterKeyb->setEnabled(enabled);
     a_ctArtRefreshList->setEnabled(enabled);
@@ -1733,6 +1738,18 @@ void KNMainWindow::slotGrpSetAllUnread()
   a_rtManager->setAllRead(false);
 }
 
+void KNMainWindow::slotGrpSetUnread()
+{
+  kdDebug(5003) << "KNMainWindow::slotGrpSetUnread()" << endl;
+  int groupLength=g_rpManager->currentGroup()->length();
+
+  bool ok = FALSE;
+  int res = QInputDialog::getInteger(
+                i18n( "Mark Last as Unread" ),
+                i18n( "Enter how many articles should be marked unread:" ), groupLength, 1, groupLength, 1, &ok, this );
+  if ( ok )
+    a_rtManager->setAllRead(res, false);
+}
 
 void KNMainWindow::slotFolNew()
 {
@@ -1874,6 +1891,13 @@ void KNMainWindow::slotArtSearch()
 }
 
 
+void KNMainWindow::slotArtFind()
+{
+  kdDebug(5003) << "KNMainWindow::slotArtFind()" << endl;
+  a_rtView->find();
+}
+
+
 void KNMainWindow::slotArtRefreshList()
 {
   kdDebug(5003) << "KNMainWindow::slotArtRefreshList()" << endl;
