@@ -202,7 +202,8 @@ class KNMainWindow : public KDockMainWindow
               *a_ctGrpReorganize,
               *a_ctGrpUnsubscribe,
               *a_ctGrpSetAllRead,
-              *a_ctGrpSetAllUnread;
+              *a_ctGrpSetAllUnread,
+              *a_ctGrpSetUnread;
 
     //collection-view - folder
     KAction   *a_ctFolNew,
@@ -221,6 +222,7 @@ class KNMainWindow : public KDockMainWindow
     KAction               *a_ctArtSortHeadersKeyb,
                           *a_ctArtFilterKeyb,
                           *a_ctArtSearch,
+                          *a_ctArtFind,
                           *a_ctArtRefreshList,
                           *a_ctArtCollapseAll,
                           *a_ctArtExpandAll,
@@ -288,6 +290,7 @@ class KNMainWindow : public KDockMainWindow
     void slotGrpUnsubscribe();
     void slotGrpSetAllRead();
     void slotGrpSetAllUnread();
+    void slotGrpSetUnread();
 
     void slotFolNew();
     void slotFolNewChild();
@@ -302,6 +305,7 @@ class KNMainWindow : public KDockMainWindow
     void slotArtSortHeaders(int i);
     void slotArtSortHeadersKeyb();
     void slotArtSearch();
+    void slotArtFind();
     void slotArtRefreshList();
     void slotArtCollapseAll();
     void slotArtExpandAll();
