@@ -1,7 +1,7 @@
 /*
 * gencfg.cpp -- Implementation of class KGeneralCfg.
 * Author:  Sirtaj Singh Kang
-* Version:  $Id: gencfg.cpp,v 1.17 2002/02/22 07:42:26 mlaurent Exp $
+* Version:  $Id: gencfg.cpp,v 1.18 2002/07/01 18:26:04 binner Exp $
 * Generated:  Wed Jul 29 03:47:49 EST 1998
 */
 
@@ -63,29 +63,29 @@ KGeneralCfg::makeWidget(QWidget * parent)
   _displayStyleGroup->insert(rb_icon,   KMailDrop::Icon);
 
   // Layout
-  captionLayout->addWidget(new QLabel(i18n("Caption"), w));
+  captionLayout->addWidget(new QLabel(i18n("Caption:"), w));
   captionLayout->addWidget(_caption);
   styleLayout->addWidget(rb_plain);
   styleLayout->addWidget(rb_colour);
   styleLayout->addWidget(rb_icon);
 
-  displayLayout->addWidget(new QLabel(i18n("Normal"), w),  0, 1);
-  displayLayout->addWidget(new QLabel(i18n("New mail"), w),     0, 2);
+  displayLayout->addWidget(new QLabel(i18n("Normal:"), w),  0, 1);
+  displayLayout->addWidget(new QLabel(i18n("New mail:"), w),     0, 2);
 
-  displayLayout->addWidget(new QLabel(i18n("Text"), w),         2, 0);
-  displayLayout->addWidget(new QLabel(i18n("Icon"), w),         3, 0);
+  displayLayout->addWidget(new QLabel(i18n("Text:"), w),         2, 0);
+  displayLayout->addWidget(new QLabel(i18n("Icon:"), w),         3, 0);
 
   QLabel * l;
 
-  l = new QLabel(i18n("&Background"), w);
+  l = new QLabel(i18n("&Background:"), w);
   l->setBuddy(_bg);
   displayLayout->addWidget(l, 1, 0);
 
-  l = new QLabel(i18n("&Text"), w);
+  l = new QLabel(i18n("&Text:"), w);
   l->setBuddy(_fg);
   displayLayout->addWidget(l, 2, 0);
 
-  l = new QLabel(i18n("&Icon"), w);
+  l = new QLabel(i18n("&Icon:"), w);
   l->setBuddy(_icon);
   displayLayout->addWidget(l, 3, 0);
 
