@@ -1,12 +1,10 @@
 /*
 * maildrop.cpp -- Implementation of class KMailDrop.
 * Author:  Sirtaj Singh Kang
-* Version:  $Id: maildrop.cpp,v 1.8 2000/08/15 12:36:46 hausmann Exp $
+* Version:  $Id: maildrop.cpp,v 1.9 2001/12/13 20:11:57 mueller Exp $
 * Generated:  Sat Nov 29 20:07:45 EST 1997
 */
 
-#include<qstring.h>
-#include<qcolor.h>
 #include<assert.h>
 #include<qapplication.h>
 
