@@ -1,13 +1,12 @@
 /*
 * moncfg.cpp -- Implementation of class KMonitorCfg.
 * Author:	Sirtaj Singh Kang
-* Version:	$Id: moncfg.cpp,v 1.1 1999/07/22 18:17:00 tibirna Exp $
+* Version:	$Id: moncfg.cpp,v 1.3 2001/12/02 18:58:46 gebauer Exp $
 * Generated:	Wed Jul 29 03:47:49 EST 1998
 */
 
 #include <assert.h>
 //#include <qwidget.h>
-//#include <kapp.h>
 
 #include "moncfg.h"
 #include "maildrop.h"
@@ -22,3 +21,4 @@ KMonitorCfg::KMonitorCfg( KMailDrop *drop )
 		this, SLOT(monitorDead())); 
 }
 
+#include "moncfg.moc"
