@@ -1,7 +1,7 @@
 /*
 * pollcfg.cpp -- Implementation of class KPollCfg.
 * Author:	Sirtaj Singh Kang
-* Version:	$Id: pollcfg.cpp,v 1.5 2001/12/13 20:11:57 mueller Exp $
+* Version:	$Id: pollcfg.cpp,v 1.6 2002/07/01 18:26:04 binner Exp $
 * Generated:	Mon Aug  3 01:51:07 EST 1998
 */
 
@@ -45,7 +45,7 @@ QWidget *KPollCfg::makeWidget(QWidget * parent)
 
   topLayout->addStretch(1);
 
-	l->addWidget(new QLabel(i18n("Check Frequency (sec)"), dlg));
+	l->addWidget(new QLabel(i18n("Check frequency (sec):"), dlg));
   l->addWidget(_freq);
 
 	return dlg;
