@@ -73,10 +73,10 @@ namespace KPF
     popup_->insertSeparator(Separator);
 
     popup_->insertItem
-      (SmallIcon("viewmag"),      i18n("Monitor..."),     Monitor,   Monitor);
+      (SmallIcon("viewmag"),      i18n("Monitor"),     Monitor,   Monitor);
 
     popup_->insertItem
-      (SmallIcon("configure"),    i18n("Configure..."),   Configure, Configure);
+      (SmallIcon("configure"),    i18n("Preferences..."),   Configure, Configure);
 
     popup_->insertItem
       (SmallIcon("remove"),       i18n("Remove"),         Remove,    Remove);
@@ -86,6 +86,15 @@ namespace KPF
 
     popup_->insertItem
       (SmallIcon("player_pause"), i18n("Pause"),          Pause,     Pause);
+
+    monitorWindow_ = new ActiveMonitorWindow(server_);
+
+    connect
+      (
+       monitorWindow_,
+       SIGNAL(dying(ActiveMonitorWindow *)),
+       SLOT(slotActiveMonitorWindowDying(ActiveMonitorWindow *))
+      );
   }
 
   AppletItem::~AppletItem()
@@ -259,13 +268,19 @@ namespace KPF
     void
   AppletItem::slotActiveMonitorWindowDying(ActiveMonitorWindow *)
   {
+    // We used to delete it here, but let's not. See if this is a CPU hog.
+#if 0
     delete monitorWindow_;
     monitorWindow_ = 0;
+#endif
+    monitorWindow_->hide();
   }
 
     void
   AppletItem::slotConfigDialogDying(SingleServerConfigDialog *)
   {
+    graph_->setTooltip();
+
     configDialog_->delayedDestruct();
     configDialog_ = 0;
   }
@@ -279,6 +294,8 @@ namespace KPF
     void
   AppletItem::monitorServer()
   {
+    // We used to delete it here, but let's not. See if this is a CPU hog.
+#if 0
     if (0 != monitorWindow_)
     {
       monitorWindow_->show();
@@ -293,8 +310,10 @@ namespace KPF
        SIGNAL(dying(ActiveMonitorWindow *)),
        SLOT(slotActiveMonitorWindowDying(ActiveMonitorWindow *))
       );
+#endif
 
     monitorWindow_->show();
+    monitorWindow_->raise();
   }
 
     void
