@@ -836,7 +836,7 @@ namespace KPF
 }
 
 K_EXPORT_COMPONENT_FACTORY( kpfpropertiesdialogplugin, 
-                            KPF::PropertiesDialogPluginFactory( "kpf" ) );
+                            KPF::PropertiesDialogPluginFactory( "kpf" ) )
 
 #include "PropertiesDialogPlugin.moc"
 // vim:ts=2:sw=2:tw=78:et
