@@ -27,7 +27,6 @@
 #include <qfileinfo.h>
 #include <qregexp.h>
 #include <kglobal.h>
-#include <kiconloader.h>
 
 #include <kmimemagic.h>
 
@@ -93,15 +92,7 @@ namespace KPF
     if ('/' != d->root.at(d->root.length() - 1))
       d->root += '/';
 
-
-    // Was an icon requested ?
-    QRegExp iconExp("^?icon=(.*)$");
-
-    if (iconExp.search(d->path) != -1) {
-      d->root = "";
-      d->path = KGlobal::iconLoader()->iconPath(iconExp.cap(1), KIcon::Small);
-    }
-    else if (d->path.right(1) == "/")
+    if (d->path.right(1) == "/")
     {
       // A directory was requested 
       kpfDebug << "Directory requested" << endl;
