@@ -415,7 +415,8 @@ namespace KPF
 
     QString unquoted;
 
-    for (uint i = 0; i < quoted.length() - 2; ++i)
+    uint i;
+    for (i = 0; i < quoted.length() - 2; ++i)
     {
       if ('%' == quoted[i])
       {
@@ -469,7 +470,7 @@ namespace KPF
       }
     }
 
-    for (uint i = quoted.length() - 2; i < quoted.length(); ++i)
+    for (; i < quoted.length(); ++i)
     {
       if ('%' == quoted[i])
       {
