@@ -1,7 +1,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: docking.cpp,v 1.24 2001/02/11 23:29:20 porten Exp $
+ * $Id: docking.cpp,v 1.27 2001/12/13 20:12:18 mueller Exp $
  *
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
@@ -24,18 +24,13 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <qtooltip.h>
-#include <qdir.h>
-#include <qpoint.h>
 #include <kwin.h>
 #include <klocale.h>
-#include <kglobal.h>
 #include <kiconloader.h>
 #include <kpopupmenu.h>
 
 #include "docking.h"
 #include "main.h"
-#include "kpppconfig.h"
 #include "pppstats.h"
 
 extern KPPPWidget   *p_kppp;
