@@ -2,7 +2,7 @@
  *
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: general.h,v 1.34 2002/01/01 14:00:52 porten Exp $
+ * $Id: general.h,v 1.37 2002/09/09 17:58:39 aseigo Exp $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -27,7 +27,6 @@
 #define _GENERAL_H_
 
 #include <qwidget.h>
-#include <qpainter.h>
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qcheckbox.h>
@@ -35,13 +34,10 @@
 #include <qpushbutton.h>
 #include <kcolorbutton.h>
 
-#include "groupbox.h"
-
 class QSlider;
-
 class KIntNumInput;
 
-class GeneralWidget : public KGroupBox {
+class GeneralWidget : public QWidget {
   Q_OBJECT
 public:
   GeneralWidget( QWidget *parent=0, const char *name=0 );
@@ -55,30 +51,10 @@ private slots:
   void  quit_toggled(bool);
   void  docking_toggled(bool on);
 
-private:
-  QGroupBox 	*box;
-
-  QLabel        *label1;
-  QLabel 	*label3;
-  QLabel 	*label4;
-  QLabel 	*label5;
-  QLabel 	*label6;
-  QLabel 	*labeltmp;
-
-  QCheckBox 	*chkbox1;
-  QCheckBox 	*chkbox2;
-  QCheckBox 	*chkbox3;
-  QCheckBox 	*chkbox4;
-  QCheckBox 	*chkbox5;
-  QCheckBox 	*chkbox6;
-  QCheckBox 	*chkbox7;
-
-  QLabel        *versionlabel;
-  KIntNumInput 	*pppdtimeout;
 };
 
 
-class ModemWidget : public KGroupBox {
+class ModemWidget : public QWidget {
   Q_OBJECT
 public:
   ModemWidget( QWidget *parent=0, const char *name=0 );
@@ -108,7 +84,7 @@ private:
 };
 
 
-class ModemWidget2 : public KGroupBox {
+class ModemWidget2 : public QWidget {
   Q_OBJECT
 public:
   ModemWidget2( QWidget *parent=0, const char *name=0 );
@@ -134,7 +110,7 @@ private:
   QSlider       *volume;
 };
 
-class GraphSetup : public KCheckGroupBox {
+class GraphSetup : public QWidget {
   Q_OBJECT
 public:
   GraphSetup(QWidget *parent = 0, const char *name = 0);
@@ -146,21 +122,14 @@ private slots:
 private:
   void save();
 
+  QGroupBox *grpColor;
+  QCheckBox *enable_check;
+
   KColorButton *bg_color;
   KColorButton *text_color;
   KColorButton *in_color;
   KColorButton *out_color;
 
-  QLabel *bg_text;
-  QLabel *text_text;
-  QLabel *in_text;
-  QLabel *out_text;
-};
-
-class AboutWidget : public KGroupBox {
-  Q_OBJECT
-public:
-  AboutWidget( QWidget *parent=0, const char *name=0 );
 };
 
 #endif
