@@ -23,16 +23,15 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include <qfileinfo.h>
 #include <qprogressdialog.h>
 #include <qdir.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kdebug.h>
 
-QList<LogInfo> logList;
+QPtrList<LogInfo> logList;
 QProgressDialog *dlg;
 
 int loadLogs() {
