@@ -20,12 +20,17 @@
 
 #include <qpainter.h>
 #include <qcombobox.h>
-
+#include <qfile.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <klistview.h>
+#include <qcombobox.h>
+#include <kdebug.h>
+#include <kmessagebox.h>
 
 #include "monthly.h"
+#include "export.h"
+#include <qstringlist.h>
 
 static void formatBytes(int bytes, QString &result) {
   if(bytes < 1024)
@@ -125,8 +130,8 @@ MonthlyWidget::MonthlyWidget(QWidget *parent) :
   lv->addColumn(i18n("Until"));
   lv->addColumn(i18n("Duration"));
   lv->addColumn(i18n("Costs"));
-  lv->addColumn(i18n("Bytes in"));
-  lv->addColumn(i18n("Bytes out"));
+  lv->addColumn(i18n("Bytes In"));
+  lv->addColumn(i18n("Bytes Out"));
   lv->setColumnAlignment(1, AlignRight);
   lv->setColumnAlignment(2, AlignRight);
   lv->setColumnAlignment(3, AlignRight);
@@ -150,7 +155,7 @@ MonthlyWidget::MonthlyWidget(QWidget *parent) :
 
   cboConnections = new QComboBox(false, this);            // add a combo box to select connections
   cboConnections->setMaximumWidth(200);                   // a resonable size
-  cboConnections->insertItem(i18n("All connections"));    // default to all connections
+  cboConnections->insertItem(i18n("All Connections"));    // default to all connections
   connect(cboConnections, SIGNAL(activated(int)),
 	  this, SLOT(slotConnections(int)));
 
@@ -159,6 +164,8 @@ MonthlyWidget::MonthlyWidget(QWidget *parent) :
   next = bbox->addButton(i18n("Next Month"));
   bbox->addStretch(1);
   today = bbox->addButton(i18n("Current Month"));
+  bbox->addStretch(1);
+  exportBttn = bbox->addButton(i18n("Export..."));
 
   connect(prev, SIGNAL(released()),
 	  this, SLOT(prevMonth()));
@@ -166,6 +173,8 @@ MonthlyWidget::MonthlyWidget(QWidget *parent) :
 	  this, SLOT(nextMonth()));
   connect(today, SIGNAL(released()),
 	  this, SLOT(currentMonth()));
+  connect(exportBttn, SIGNAL(clicked()),
+	  this, SLOT(exportWizard()));
 
   bbox->addStretch(8);
   bbox->layout();
@@ -194,18 +203,12 @@ int bestlen(QWidget *w, const char *s) {
 }
 
 void MonthlyWidget::plotMonth() {
-  QString months[] = {i18n("January"),
-		      i18n("February"),
-		      i18n("March"),
-		      i18n("April"),
-		      i18n("May"),
-		      i18n("June"),
-		      i18n("July"),
-		      i18n("August"),
-		      i18n("September"),
-		      i18n("October"),
-		      i18n("November"),
-		      i18n("December")};
+  QStringList months;
+  for (int i=1; i<13; i++)
+      months.append(KGlobal::locale()->monthName(i, false/*short*/));
+
+  // current showed month
+  currMonth = months[_month-1];
 
   // name of the current connection
   QString con;
@@ -277,10 +280,9 @@ void MonthlyWidget::plotMonth() {
       QString s_lifrom, s_liuntil, s_costs;
       s_lifrom = KGlobal::locale()->formatTime(li->from().time(), false);
       s_liuntil = KGlobal::locale()->formatTime(li->until().time(), false);
-      s_costs.sprintf("%6.2f",
-                      li->sessionCosts());
+      s_costs = KGlobal::locale()->formatMoney(li->sessionCosts());
 
-    	(void) new LogListItem(li, lv, con, day, s_lifrom, s_liuntil, s_duration, s_costs, _bin, _bout);
+      (void) new LogListItem(li, lv, con, day, s_lifrom, s_liuntil, s_duration, s_costs, _bin, _bout);
     }
   }
 
@@ -306,24 +308,26 @@ void MonthlyWidget::plotMonth() {
     formatDuration(duration,
                    s_duration);
 
-    QString s_costs;
-    s_costs.sprintf("%6.2f", costs);
+    QString s_costs(KGlobal::locale()->formatMoney(costs, QString::null, 2));
 
     (void) new LogListItem(0, lv,
-			   i18n("%1 connections").arg(count),
+			   i18n("%n connection", "%n connections", count),
 			   QString::null, QString::null, QString::null,
 			   s_duration, s_costs, _bin, _bout);
   }
 
   QString t;
-  if(lv->childCount() > 0)
+  if(lv->childCount() > 0) {
+    exportBttn->setEnabled(true); // export possibility
     t = i18n("Connection log for %1 %2")
 	      .arg(months[_month-1])
 	      .arg(_year);
-  else
+  } else {
+    exportBttn->setEnabled(false); // nothing to export
     t = i18n("No connection log for %1 %2 available")
 	      .arg(months[_month-1])
 	      .arg(_year);
+  }
 
   title->setText(t);
 }
@@ -356,5 +360,156 @@ void MonthlyWidget::currentMonth() {
   plotMonth();
 }
 
+void MonthlyWidget::exportWizard() {
+  QString date = QString(currMonth+"-%1").arg(_year);  // e.g.: June-2001
+
+  ExportWizard *wizard = new ExportWizard(0, date);
+  wizard->exec();
+  if (wizard->filename.isEmpty()) { // wizard aborted...
+    return;
+  }
+  if (QFile::exists(wizard->filename)) {  // overwrite?
+    if (KMessageBox::Continue!=KMessageBox::warningContinueCancel(0, i18n("A document with this name already exists."), i18n("Overwrite file?"), i18n("Overwrite") /*, true*/)) { // no
+      return;
+    }
+  }
+
+  // open file
+  Export *exportIFace = wizard->createExportFilter();
+  if (exportIFace == NULL) { // error
+    return;
+  }
+
+  if (!exportIFace->openFile()) {  // error opening
+    KMessageBox::sorry(0, i18n("An error occurred while trying to open this file"), i18n("Sorry"), true);
+    delete exportIFace;
+    return; // abort...
+  }
+
+  // start writing data
+  exportIFace->addHeadline(i18n("Connection"), i18n("Day"), i18n("From"), i18n("Until"),
+			   i18n("Duration"), i18n("Costs"), i18n("Bytes In"), i18n("Bytes Out") );
+
+  // name of the current connection
+  QString con;
+
+  // for collecting monthly statistics
+  int count = 0;
+  double costs = 0;
+  int bin = 0, bout = 0;
+  int duration = 0;
+
+  for(int i = 0; i < (int)logList.count(); i++) {
+    LogInfo *li = logList.at(i);
+
+    if(li->from().date().month() == _month && li->from().date().year() == _year) {
+      // get connection name for this line
+      con = li->connectionName();
+
+      // this connection name not in the list and combo box
+      if(lstConnections.findIndex(con) == -1) {
+          lstConnections.append(con);
+        cboConnections->insertItem(con);
+      }
+      // if all connections or the selected one
+      if(cboConnections->currentText() != con &&
+         cboConnections->currentItem() != 0)
+        continue;
+
+      count++;
+      costs += li->sessionCosts();
+      if(bin >= 0) {
+        if(li->bytesIn() < 0)
+          bin = -1;
+        else
+          bin += li->bytesIn();
+      }
+
+      if(bout >= 0) {
+        if(li->bytesOut() < 0)
+          bout = -1;
+        else
+          bout += li->bytesOut();
+      }
+
+      duration += li->from().secsTo(li->until());
+
+      QString _bin, _bout, b;
+      if(li->bytesIn() >= 0)
+        formatBytes(li->bytesIn(), _bin);
+      else
+        _bin = i18n("n/a");
+
+      if(li->bytesOut() >= 0)
+        formatBytes(li->bytesOut(), _bout);
+      else
+        _bout = i18n("n/a");
+
+      if(li->bytes() > 0)
+        formatBytes(li->bytes(), b);
+      else
+        b = i18n("n/a");
+
+      QString day;
+      day.sprintf("%2d", li->from().date().day());
+      QString con = li->connectionName();
+
+      QString s_duration;
+      formatDuration(li->from().secsTo(li->until()),
+                     s_duration);
+
+      QString s_lifrom, s_liuntil, s_costs;
+      s_lifrom = KGlobal::locale()->formatTime(li->from().time(), false);
+      s_liuntil = KGlobal::locale()->formatTime(li->until().time(), false);
+      s_costs = KGlobal::locale()->formatMoney(li->sessionCosts());
+
+      // call export method
+      exportIFace->addDataline(con, day, s_lifrom, s_liuntil, s_duration,
+			       s_costs, _bin, _bout);
+    }
+  }
+
+  if(count) {
+    QString _bin, _bout, _b;
+
+    if(bin < 0)
+      _bin = i18n("n/a");
+    else
+      formatBytes(bin, _bin);
+
+    if(bout < 0)
+      _bout = i18n("n/a");
+    else
+      formatBytes(bout, _bout);
+
+    if(bin < 0 || bout < 0)
+      _b = i18n("n/a");
+    else
+      formatBytes(bout + bin, _b);
+
+    QString s_duration;
+    formatDuration(duration,
+                   s_duration);
+
+    QString s_costs(KGlobal::locale()->formatMoney(costs, QString::null, 2));
+
+    // call export methods
+    exportIFace->addEmptyLine();
+    exportIFace->addDataline(i18n("%n connection", "%n connections", count), QString::null, QString::null, QString::null, s_duration,
+			     s_costs, _bin, _bout);
+    exportIFace->setFinishCode();
+
+    // write buffer to file and close file
+    if (!exportIFace->closeFile())  {
+      KMessageBox::sorry(0, i18n("An error occurred while trying to write to this file"), i18n("Sorry"), true);
+      delete exportIFace;
+      return;
+    }
+
+  }
+  delete exportIFace;
+}
+
+
 
 #include "monthly.moc"
