@@ -1,7 +1,7 @@
 /*
  *            kPPP: A front end for pppd for the KDE project
  *
- * $Id: miniterm.cpp,v 1.40 2002/03/12 18:08:00 malte Exp $
+ * $Id: miniterm.cpp,v 1.42 2002/04/20 13:02:40 binner Exp $
  *
  * Copyright (C) 1997 Bernd Johannes Wuebben
  *                    wuebben@math.cornell.edu
@@ -118,12 +118,12 @@ void MiniTerm::init() {
 
   int lock = Modem::modem->lockdevice();
   if (lock == 1) {
-    statusbar->setText(i18n("Sorry, modem device is locked."));
+    statusbar->setText(i18n("Modem device is locked."));
     return;
   }
 
   if (lock == -1) {
-    statusbar->setText(i18n("Sorry, can't create modem lock file."));
+    statusbar->setText(i18n("Unable to create modem lock file."));
     return;
   }
 
@@ -180,7 +180,7 @@ void MiniTerm::readChar(unsigned char c) {
 void MiniTerm::cancelbutton() {
   Modem::modem->stop();
 
-  statusbar->setText(i18n("Hanging up ..."));
+  statusbar->setText(i18n("Hanging up..."));
   kapp->processEvents();
   KApplication::flushX();
 
