@@ -1,7 +1,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: modem.cpp,v 1.48 2001/12/13 20:12:18 mueller Exp $
+ * $Id: modem.cpp,v 1.51 2002/09/28 05:46:25 aseigo Exp $
  *
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
@@ -114,20 +114,20 @@ bool Modem::opentty() {
   //  int flags;
 
   if((modemfd = Requester::rq->openModem(gpppdata.modemDevice()))<0) {
-    errmsg = i18n("Sorry, can't open modem.");
+    errmsg = i18n("Unable to open modem.");
     return false;
   }
 
 #if 0
   if(gpppdata.UseCDLine()) {
     if(ioctl(modemfd, TIOCMGET, &flags) == -1) {
-      errmsg = i18n("Sorry, can't detect state of CD line.");
+      errmsg = i18n("Unable to detect state of CD line.");
       ::close(modemfd);
       modemfd = -1;
       return false;
     }
     if ((flags&TIOCM_CD) == 0) {
-      errmsg = i18n("Sorry, the modem is not ready.");
+      errmsg = i18n("The modem is not ready.");
       ::close(modemfd);
       modemfd = -1;
       return false;
@@ -143,7 +143,7 @@ bool Modem::opentty() {
     tcsendbreak(modemfd, 0);
     sleep(1);
     if(tcgetattr(modemfd, &tty) < 0){
-      errmsg = i18n("Sorry, the modem is busy.");
+      errmsg = i18n("The modem is busy.");
       ::close(modemfd);
       modemfd = -1;
       return false;
@@ -188,7 +188,7 @@ bool Modem::opentty() {
   tcdrain(modemfd);
 
   if(tcsetattr(modemfd, TCSANOW, &tty) < 0){
-    errmsg = i18n("Sorry, the modem is busy.");
+    errmsg = i18n("The modem is busy.");
     ::close(modemfd);
     modemfd=-1;
     return false;
@@ -312,10 +312,12 @@ bool Modem::writeLine(const char *buf) {
     if(wr < 0) {
       // TODO do something meaningful with the error code (or ignore it
       kdError(5002) << "write() in Modem::writeLine failed" << endl;
+      delete[] b;
       return false;
     }
     l -= wr;
   }
+  delete[] b;
   return true;
 }
 
@@ -327,7 +329,6 @@ bool Modem::hangup() {
   // kppp. If people complain about kppp being stuck, this piece of code
   // is most likely the reason.
   struct termios temptty;
-  int  modemstat;
 
   if(modemfd >= 0) {
 
@@ -355,7 +356,7 @@ bool Modem::hangup() {
       closetty();
       close(modemfd);
       modemfd = -1;
-      errmsg = i18n("Sorry, the modem doesn't respond.");
+      errmsg = i18n("The modem does not respond.");
       return false;
     }
 
@@ -365,6 +366,7 @@ bool Modem::hangup() {
     cfsetispeed(&temptty, B0);
     tcsetattr(modemfd, TCSAFLUSH, &temptty);
 #else
+    int modemstat;
     ioctl(modemfd, TIOCMGET, &modemstat);
     modemstat &= ~TIOCM_DTR;
     ioctl(modemfd, TIOCMSET, &modemstat);
