@@ -3,7 +3,7 @@
  *
  *            kPPP: A front end for pppd for the KDE project
  *
- * $Id: modemcmds.h,v 1.13 2002/02/01 14:55:32 winkvist Exp $
+ * $Id: modemcmds.h,v 1.14 2002/04/07 18:57:07 cumming Exp $
  *
  * Copyright (C) 1997 Bernd Johannes Wuebben
  * wuebben@math.cornell.edu
@@ -32,13 +32,13 @@
 #define _MODEMCMDS_H_
 
 #include <qgroupbox.h>
-#include <qdialog.h>
+#include <kdialogbase.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <pppdata.h>
 
-class ModemCommands : public QDialog {
+class ModemCommands : public KDialogBase {
 
 Q_OBJECT
 
@@ -48,16 +48,13 @@ public:
   ~ModemCommands() {}
 
 private slots:
-  void cancelbutton();
-  void okbutton();
+  void slotCancel();
+  void slotOk();
 
 private:
 
   QGroupBox *box;
 
-  QPushButton *ok;
-  QPushButton *cancel;
-
   QLineEdit *initstr[int(PPPData::NumInitStrings)];
 
   QLineEdit *initresp;
