@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppdargs.cpp,v 1.20 1999/10/09 00:26:50 kalle Exp $
+ * $Id: pppdargs.cpp,v 1.23 2001/12/02 18:59:07 gebauer Exp $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -27,8 +27,8 @@
 
 #include <qlayout.h>
 #include <kbuttonbox.h>
-#include <kwm.h>
-#include <kapp.h>
+#include <kwin.h>
+#include <kapplication.h>
 #include "pppdargs.h"
 #include "pppdata.h"
 #include <klocale.h>
@@ -37,7 +37,7 @@ PPPdArguments::PPPdArguments(QWidget *parent, const char *name)
   : QDialog(parent, name, TRUE)
 {
   setCaption(i18n("Customize pppd Arguments"));  
-  KWM::setMiniIcon(winId(), kapp->miniIcon());
+  KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
   QVBoxLayout *l = new QVBoxLayout(this, 10, 10);
   QHBoxLayout *tl = new QHBoxLayout(10);
   l->addLayout(tl);
@@ -118,7 +118,7 @@ void PPPdArguments::removebutton() {
 void PPPdArguments::defaultsbutton() {
   // all of this is a hack
   // save current list
-  QStrList arglist(gpppdata.pppdArgument());
+  QStringList arglist(gpppdata.pppdArgument());
 
   // get defaults
   gpppdata.setpppdArgumentDefaults();
@@ -130,7 +130,7 @@ void PPPdArguments::defaultsbutton() {
 
 
 void PPPdArguments::closebutton() {
-  QStrList arglist;
+  QStringList arglist;
   for(uint i=0; i < arguments->count(); i++)
     arglist.append(arguments->text(i));
   gpppdata.setpppdArgument(arglist);
@@ -143,9 +143,11 @@ void PPPdArguments::init() {
   while(arguments->count())
     arguments->removeItem(0);
 
-  QStrList &arglist = gpppdata.pppdArgument();
-  for(char *arg = arglist.first(); arg; arg = arglist.next())
-    arguments->insertItem(arg);
+  QStringList &arglist = gpppdata.pppdArgument();
+  for ( QStringList::Iterator it = arglist.begin();
+        it != arglist.end();
+        ++it )
+    arguments->insertItem(*it);
 }
 
 
