@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppdata.cpp,v 1.100 2002/08/31 23:54:33 porten Exp $
+ * $Id: pppdata.cpp,v 1.100.2.1 2003/08/31 10:39:15 aacid Exp $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -1171,7 +1171,11 @@ void PPPData::graphingOptions(bool &enable,
 
 
 bool PPPData::graphingEnabled() {
-  return (bool) readNumConfig(GRAPH_GRP, GENABLED, true);
+  if(config) {
+    config->setGroup(GRAPH_GRP);
+    return config->readBoolEntry(GENABLED, true);
+  }
+  else return true;
 }
 
 
