@@ -2,7 +2,7 @@
  *
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppdata.h,v 1.73 2002/02/01 14:55:32 winkvist Exp $
+ * $Id: pppdata.h,v 1.74 2002/08/31 23:54:33 porten Exp $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -184,7 +184,7 @@ public:
   QString currentGroup() { return cgroup; }
 
   // functions to set/get general kppp info
-  const QString Password();
+  QString password() const;
   void setPassword(const QString &);
 
   const QString defaultAccount();
@@ -445,10 +445,8 @@ public:
   void winPosStatWin(int &, int &);
   void setWinPosStatWin(int, int);
 
-public:
-  QString password;
-
 private:
+  QString passwd;
   KConfig* config;                       // configuration object
   int highcount;                         // index of highest account
   int caccount;                          // index of the current account
