@@ -2,7 +2,7 @@
  *
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: ppplog.cpp,v 1.38 2002/01/19 07:48:37 waba Exp $
+ * $Id: ppplog.cpp,v 1.40 2002/07/18 12:48:14 mhunter Exp $
  *
  * (c) 1998 Mario Weilguni <mweilguni@kde.org>
  *
@@ -151,7 +151,7 @@ void PPPL_AnalyseLog(QStringList &list, QStringList &result) {
 	  "configuration request! Contact your provider!") },
 
     {"unrecognized option",
-     I18N_NOOP("You have passed an invalid option to pppd. See `man pppd' "
+     I18N_NOOP("You have passed an invalid option to pppd. See 'man pppd' "
           "for a complete list of valid arguments.") },
 
     // terminator
@@ -188,7 +188,7 @@ void PPPL_AnalyseLog(QStringList &list, QStringList &result) {
   }
 
   if (result.isEmpty())
-    result.append(i18n("Sorry. Can't help you here."));
+    result.append(i18n("Unable to provide help."));
 }
 
 
@@ -278,7 +278,7 @@ void PPPL_ShowLog() {
     fclose(f);
     umask(old_umask);
 
-    QString msg = i18n("The PPP log has been saved\nas \"%1\"!\n\nIf you want to send a bug report or have\nproblems connecting to the internet, please\nattach this file. It will help the maintainers\nto find the bug and to improve KPPP").arg(s);
+    QString msg = i18n("The PPP log has been saved\nas \"%1\"!\n\nIf you want to send a bug report, or have\nproblems connecting to the Internet, please\nattach this file. It will help the maintainers\nto find the bug and to improve KPPP").arg(s);
     KMessageBox::information(0, msg);
   }
   delete dlg;
