@@ -2,7 +2,7 @@
  *
  *            Kppp: A pppd front end for the KDE project
  *
- * $Id: pwentry.cpp,v 1.4 1999/08/15 17:39:35 porten Exp $
+ * $Id: pwentry.cpp,v 1.5 2002/03/18 21:04:53 staikos Exp $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -43,8 +43,9 @@ PWEntry::PWEntry( QWidget *parent, const char *name )
 		 90);
    }
    else{
-     setGeometry( QApplication::desktop()->width()/2 - 150,
-		  QApplication::desktop()->height()/2 - 50, 300, 90 );
+     int scnum = QApplication::desktop()->screenNumber(parent);
+     QRect desk = QApplication::desktop()->screenGeometry(scnum);
+     setGeometry( desk.center().x() - 150, desk.center().y() - 50, 300, 90 );
    }
 
    frame = new QGroupBox(name, this );
