@@ -9,21 +9,22 @@
 #include <klocale.h>
 
 charSelector::charSelector(QWidget *parent, const char* name)
-           : QDialog(parent, name, false)
+           : KDialog(parent, name, false)
 {
   testLayout = new QVBoxLayout(this);
-  testLayout->setSpacing(2);
-  testLayout->setMargin(2);
+  testLayout->setSpacing( spacingHint() );
+  testLayout->setMargin( marginHint() );
 
   charSelect = new KCharSelect(this, QString::null, "", 0);
   testLayout->addWidget(charSelect);
 
-  QHBoxLayout *buttonLayout = new QHBoxLayout;
-  buttonLayout->setSpacing(6);
-  buttonLayout->setMargin(3);
+  connect(charSelect, SIGNAL(doubleClicked()), SLOT(insertText()));
 
-  insertButton = new QPushButton(i18n("Insert Char"), this);
-  connect(insertButton, SIGNAL(clicked()), this, SLOT(insertText()));
+  QHBoxLayout *buttonLayout = new QHBoxLayout;
+  buttonLayout->setSpacing( spacingHint() );
+
+  insertButton = new QPushButton(i18n("&Insert Char"), this);
+  connect(insertButton, SIGNAL(clicked()), SLOT(insertText()));
   buttonLayout->addWidget(insertButton);
 
   QSpacerItem *spacer = new QSpacerItem(50, 20, QSizePolicy::Expanding, QSizePolicy::Expanding);
