@@ -2,7 +2,7 @@
 
  Main KSirc start
 
- $$Id: ksirc.cpp,v 1.67 2002/02/28 10:57:55 hausmann Exp $$
+ $$Id: ksirc.cpp,v 1.71 2002/09/25 15:34:29 hausmann Exp $$
 
  Main start file that defines 3 global vars, etc
 
@@ -26,7 +26,7 @@
 #include "version.h"
 
 static const char *description =
-        I18N_NOOP("KDE Irc client");
+        I18N_NOOP("KDE IRC client");
 
 //QDict<KSircTopLevel> TopList;
 //QDict<KSircMessageReceiver> TopList;
@@ -35,6 +35,7 @@ class KCmdLineOptions options[] =
 {
     { "nick <nickname>", I18N_NOOP( "Nickname to use." ), 0 } ,
     { "server <server>", I18N_NOOP( "Server to connect to on startup." ), 0 },
+    { "channel <#channel>", I18N_NOOP( "Channel to connect to on startup." ), 0 },
     { 0, 0, 0 }
 };
 
@@ -49,13 +50,13 @@ public:
         if ( !controller || !sm.allowsInteraction() ) return true;
 
         // if the controller is hidden KMWSessionManaged won't send the fake close event.
-        // we want it in any way however. 
+        // we want it in any way however.
         if ( controller->isHidden() ) {
             QCloseEvent e;
             QApplication::sendEvent( controller, &e );
         }
 
-        return true; 
+        return true;
     }
 };
 
@@ -63,8 +64,8 @@ int main( int argc, char ** argv )
 {
     KAboutData aboutData( "ksirc", I18N_NOOP("KSirc"),
         KSIRC_VERSION, description, KAboutData::License_Artistic,
-        "(c) 1997-2001, The KSirc Developers");
-    aboutData.addAuthor("Andrew Stanley-Jones","Original Author", "asj@chowtown.cban.com");
+        I18N_NOOP("(c) 1997-2001, The KSirc Developers"));
+    aboutData.addAuthor("Andrew Stanley-Jones",I18N_NOOP("Original Author"), "asj@chowtown.cban.com");
     aboutData.addAuthor("Waldo Bastian",0, "bastian@kde.org");
     aboutData.addAuthor("Carsten Pfeiffer",0, "pfeiffer@kde.org");
     aboutData.addAuthor("Malte Starostik",0, "malte@kde.org");
@@ -101,12 +102,22 @@ int main( int argc, char ** argv )
 
         QCString nickName = args->getOption( "nick" );
         QCString server = args->getOption( "server" );
+        QCString channel = args->getOption( "channel" );
 
         if ( !nickName.isEmpty() )
             ksopts->nick = nickName;
 
-        if ( !server.isEmpty() )
+        if ( !server.isEmpty() ) {
             sc->new_ksircprocess( QString::fromLocal8Bit( server ) );
+            if ( !channel.isEmpty() ) {
+                QStringList channels = QStringList::split( ',', QString::fromLocal8Bit( channel ) );
+                QStringList::ConstIterator it = channels.begin();
+                QStringList::ConstIterator end = channels.end();
+                for ( ; it != end; ++it )
+                    sc->new_toplevel( *it );
+            }
+            sc->new_toplevel( QString::fromLocal8Bit( server ) );
+        }
 
         args->clear();
     }
