@@ -6,6 +6,7 @@
 #include <qptrlist.h>
 
 class KSircProcess;
+class QTextCodec;
 
 struct filterRule {
     const char *desc;
@@ -22,7 +23,7 @@ public:
   KSircMessageReceiver(KSircProcess *_proc);
   virtual ~KSircMessageReceiver();
 
-    virtual void sirc_receive(QString str, bool broadcast = false) = 0;
+    virtual void sirc_receive(QCString str, bool broadcast = false) = 0;
 
     virtual void control_message(int, QString) = 0;
 
@@ -39,4 +40,23 @@ private:
 
 };
 
+class UnicodeMessageReceiver : public KSircMessageReceiver
+{
+public:
+    UnicodeMessageReceiver( KSircProcess *process );
+
+    virtual void sirc_receive(QCString str, bool broadcast = false);
+    virtual void sirc_receive(QString str, bool broadcast = false) = 0;
+
+protected:
+    void setEncoding( const QString &encoding );
+    QString encoding() const;
+
+    QTextCodec *encoder() const;
+
+private:
+    QString m_encoding;
+    QTextCodec *m_encoder;
+};
+
 #endif
