@@ -1,9 +1,9 @@
 #include <stdio.h>
-#include "../config.h"
+
 
 #include "ptabdialog.h"
 #include "commands.h"
-#include <iostream.h>
+#include <iostream>
 
 PObject *
 PTabDialog::createWidget(CreateArgs &ca)
