@@ -2,7 +2,7 @@
 
  Server Controller
 
- $$Id: servercontroller.cpp,v 1.139 2002/02/28 10:43:33 hausmann Exp $$
+ $$Id: servercontroller.cpp,v 1.149.2.1 2002/12/06 16:11:45 lunakl Exp $$
 
  Main Server Controller.  Displays server connection window, and makes
  new server connection on demand.
@@ -13,7 +13,7 @@
 
    new_connection(): Creates popup asking for new connection
 
-   new_ksircporcess(QString):
+   new_ksircprocess(QString):
       Args:
          QString: new server name or IP to connect to.
       Action:
@@ -84,6 +84,10 @@
 #include <kstdaccel.h>
 #include <kstandarddirs.h>
 #include <khelpmenu.h>
+#include <kstdaction.h>
+#include <kaction.h>
+#include <knotifydialog.h>
+#include <netwm.h>
 
 #include <qfile.h>
 
@@ -105,6 +109,7 @@ servercontroller::servercontroller( QWidget*, const char* name )
     : KMainWindow( 0, name )
 {
   we_are_exiting = false;
+  m_notificationCount = 0;
   MenuBar = menuBar();
   KWin::setIcons( winId(), kapp->icon(), kapp->miniIcon() );
 
@@ -132,7 +137,7 @@ servercontroller::servercontroller( QWidget*, const char* name )
   setFrameBorderWidth(5);
 
   QPopupMenu *file = new QPopupMenu(this, QString(name) + "_menu_file");
-  file->insertItem(i18n("&Quit"), this, SLOT(endksirc()), KStdAccel::quit());
+  KStdAction::quit(this, SLOT(endksirc()), actionCollection())->plug(file);
   MenuBar->insertItem(i18n("&File"), file);
 
   connections = new QPopupMenu(this, QString(name) + "_menu_connections");
@@ -147,15 +152,14 @@ servercontroller::servercontroller( QWidget*, const char* name )
   //insertChild(options);
   options->setCheckable(TRUE);
 
-  options->insertItem(i18n("&Global Fonts..."),
-		      this, SLOT(font_prefs()));
-  options->insertItem(i18n("&Filter Rule Editor..."),
+  options->insertItem(SmallIcon( "filter" ), i18n("&Filter Rule Editor..."),
 		      this, SLOT(filter_rule_editor()));
   options->insertSeparator();
-  options->insertItem(i18n("&Preferences..."),
-		      this, SLOT(general_prefs()));
+  KStdAction::configureNotifications(this, SLOT(notification_prefs()), actionCollection())->plug(options);
 
-  MenuBar->insertItem(i18n("&Options"), options);
+  KStdAction::preferences(this, SLOT(general_prefs()), actionCollection())->plug(options);
+
+  MenuBar->insertItem(i18n("&Settings"), options);
 
   KHelpMenu *help = new KHelpMenu( this, kapp->aboutData() );
   MenuBar->insertItem(i18n("&Help"), help->menu() );
@@ -168,6 +172,7 @@ servercontroller::servercontroller( QWidget*, const char* name )
   pic_ppl = UserIcon("channels");
   pic_icon = UserIcon("ksirc_b");
   pic_dock = UserIcon("ksirc_dock");
+  pic_info = UserIcon("info");
 
   setCaption( i18n("Server Control") );
   KWin::setIcons(winId(), pic_icon, pic_server);
@@ -283,12 +288,18 @@ void servercontroller::ToggleAutoCreate()
 void servercontroller::general_prefs()
 {
   KSPrefs *kp = new KSPrefs();
-  connect(kp, SIGNAL(update()),
+  connect(kp, SIGNAL(update(int)),
           this, SLOT(configChange()));
   kp->resize(550, 450);
   kp->show();
 }
 
+void servercontroller::notification_prefs()
+{
+  KNotifyDialog::configure(this, "Notification Configuration Dialog");
+}
+
+
 void servercontroller::filter_rule_editor()
 {
   FilterRuleEditor *fe = new FilterRuleEditor();
@@ -297,22 +308,15 @@ void servercontroller::filter_rule_editor()
   fe->show();
 }
 
-void servercontroller::font_prefs()
-{
-    QFont font = ksopts->defaultFont;
-    if ( KFontDialog::getFont( font ) == KFontDialog::Accepted )
-	font_update( font );
-}
-
 void servercontroller::font_update(const QFont &font)
 {
   ksopts->defaultFont = font;
 /*  configChange(); */
+
   KConfig *kConfig = kapp->config();
   kConfig->setGroup("GlobalOptions");
-  kConfig->writeEntry("MainFont", font);
   kConfig->sync();
-  QApplication::setFont( font, true, "KSTextView" );
+  QApplication::setFont( font, true, "KSirc::TextView" );
 }
 
 void servercontroller::configChange()
@@ -432,8 +436,8 @@ void servercontroller::ProcMessage(QString server, int command, QString args)
   case ProcCommand::changeChannel:
     {
       char *new_s, *old_s;
-      new_s = new char[args.length()];
-      old_s = new char[args.length()];
+      new_s = new char[args.length()+1];
+      old_s = new char[args.length()+1];
       sscanf(args.ascii(), "%s %s", old_s, new_s);
       //  If the channel has a !, it's a control channel, remove the !
       if(old_s[0] == '!')
@@ -493,9 +497,23 @@ void servercontroller::saveGlobalProperties(KConfig *ksc)
   QString group = ksc->group();
 
   ksc->setGroup( "KSircSession" );
-  QMap<QString,QStringList>::ConstIterator it = m_sessionConfig.begin();
-  for (; it != m_sessionConfig.end(); ++it )
-    ksc->writeEntry( it.key(), *it );
+  SessionConfigMap::ConstIterator it = m_sessionConfig.begin();
+  for (; it != m_sessionConfig.end(); ++it ) {
+
+      ChannelSessionInfoList infoList = *it;
+
+      QStringList channels;
+      QStringList desktops;
+
+      for ( ChannelSessionInfoList::ConstIterator sessionInfoIt = infoList.begin();
+          sessionInfoIt != infoList.end(); ++sessionInfoIt ) {
+	  channels << ( *sessionInfoIt ).name;
+	  desktops << QString::number( ( *sessionInfoIt ).desktop );
+      }
+
+      KConfigGroup( ksc, "KSircSession" ).writeEntry( it.key(), channels );
+      KConfigGroup( ksc, "KSircSessionDesktopNumbers" ).writeEntry( it.key(), desktops );
+  }
 
   ksc->setGroup("ServerController");
   ksc->writeEntry("Docked", !isVisible());
@@ -519,11 +537,33 @@ void servercontroller::readGlobalProperties(KConfig *ksc)
     QMap<QString,QString>::Iterator it = keyMap.begin();
 
     while(it != keyMap.end()) {
+	QString server = it.key();
 	//	debug("%s", it.key().latin1());
-	new_ksircprocess(it.key()); // sets up proc_list
-	QStringList channels = ksc->readListEntry(it.key());
+	new_ksircprocess( server ); // sets up proc_list
+	QStringList channels = ksc->readListEntry( server );
+
+	QStringList desktops = KConfigGroup( ksc, "KSircSessionDesktopNumbers" ).readListEntry( server );
+
 	for(uint i = 0; i < channels.count(); i++){
-	    proc_list[it.key()]->new_toplevel(*(channels.at(i)));
+
+	    QString channel = channels[ i ];
+
+	    proc_list[ server ]->new_toplevel( channel );
+
+	    KSircTopLevel *topLevel = dynamic_cast<KSircTopLevel *>( proc_list[ server ]->getWindowList()[ channel ] );
+	    if ( !topLevel || !topLevel->isTopLevel() )
+		continue;
+
+	    QStringList::ConstIterator desktopNumberIt = desktops.at( i );
+	    if ( desktopNumberIt == desktops.end() )
+		continue;
+
+	    int desktop = ( *desktopNumberIt ).toInt();
+	    if ( desktop == -1 )
+		continue;
+
+	    NETWinInfo winInfo( qt_xdisplay(), topLevel->winId(), qt_xrootwin(), NET::WMDesktop );
+	    winInfo.setDesktop( desktop );
 	}
 	++it;
     }
@@ -543,15 +583,25 @@ void servercontroller::readGlobalProperties(KConfig *ksc)
 }
 
 void servercontroller::saveSessionConfig()
-{  
+{
     QDictIterator<KSircProcess> ksp(proc_list);
     for (; ksp.current(); ++ksp ) {
-	QStringList channels;
+	ChannelSessionInfoList channels;
 
 	QDictIterator<KSircMessageReceiver> ksm(ksp.current()->getWindowList());
 	for (; ksm.current(); ++ksm )
-	    if(ksm.currentKey()[0] != '!') // Ignore !ksm's (system created)
-		channels << ksm.currentKey();
+	    if(ksm.currentKey()[0] != '!') { // Ignore !ksm's (system created)
+		ChannelSessionInfo sessionInfo;
+
+		sessionInfo.name = ksm.currentKey();
+		KSircTopLevel *topLev = dynamic_cast<KSircTopLevel *>( ksm.current() );
+		if ( topLev && topLev->isTopLevel() ) {
+		    NETWinInfo winInfo( qt_xdisplay(), topLev->winId(), qt_xrootwin(), NET::WMDesktop );
+		    sessionInfo.desktop = winInfo.desktop();
+		}
+
+		channels << sessionInfo;
+	    }
 
 	if ( !channels.isEmpty() )
 	    m_sessionConfig[ ksp.currentKey() ] = channels;
@@ -643,11 +693,31 @@ QListViewItem * servercontroller::findChild( QListViewItem *parent,
     return 0L;
 }
 
+void servercontroller::increaseNotificationCount()
+{
+    if ( m_notificationCount == 0 )
+    {
+        // change icon
+        dockWidget->setPixmap( pic_info );
+    }
+    m_notificationCount++;
+}
+
+void servercontroller::decreaseNotificationCount()
+{
+    m_notificationCount--;
+    if ( m_notificationCount == 0 )
+    {
+        // change icon back
+        dockWidget->setPixmap( pic_dock );
+    }
+}
+
 scInside::scInside ( QWidget * parent, const char * name, WFlags
 		     f )
   : QFrame(parent, name, f)
 {
-  ASConn = new QLabel(i18n("Active Server Connections"), this, "servercontroller_label");
+  ASConn = new QLabel(i18n("Active server connections:"), this, "servercontroller_label");
   QFont asfont = ASConn->font();
   asfont.setBold(TRUE);
   ASConn->setFont(asfont);
@@ -682,15 +752,15 @@ dockServerController::dockServerController(servercontroller *_sc, const char *_n
   KPopupMenu *pop = contextMenu();
   pop->setName("dockServerController_menu_pop");
 
-  pop->insertItem(i18n("&Global Fonts..."),
-                  sc, SLOT(font_prefs()));
-  pop->insertItem(i18n("&Filter Rule Editor..."),
-                  sc, SLOT(filter_rule_editor()));
-  pop->insertItem(SmallIcon("configure"), i18n("&Preferences..."),
-                  sc, SLOT(general_prefs()));
+  pop->insertItem(SmallIcon( "filter" ), i18n("&Filter Rule Editor..."),
+                  _sc, SLOT(filter_rule_editor()));
+
+  KStdAction::preferences(_sc, SLOT(general_prefs()),
+                  _sc->actionCollection())->plug(pop);
+
   pop->insertSeparator();
-  pop->insertItem(i18n("New Server..."),
-                  sc, SLOT(new_connection()));
+  pop->insertItem(i18n("&New Server..."),
+                  _sc, SLOT(new_connection()));
 
   if ( !_sc->pic_dock.isNull() )
     setPixmap( _sc->pic_dock );
