@@ -2,7 +2,7 @@
 
  TopLevel IRC Channel/query Window
 
- $$Id: toplevel.cpp,v 1.206.2.2 2002/06/15 05:25:22 waba Exp $$
+ $$Id: toplevel.cpp,v 1.233 2002/11/05 09:00:32 hausmann Exp $$
 
  This is the main window with which the user interacts.  It handles
  both normal channel conversations and private conversations.
@@ -51,6 +51,7 @@
 #include <qregexp.h>
 #include <qcursor.h>
 #include <qtimer.h>
+#include <qtextcodec.h>
 
 #include <kapplication.h>
 #include <kdebug.h>
@@ -63,7 +64,9 @@
 #include <ktempfile.h>
 #include <kio/netaccess.h>
 #include <kstatusbar.h>
-
+#include <kstdaction.h>
+#include <kaction.h>
+#include <kcharsets.h>
 
 extern DisplayMgr *displayMgr;
 //QPopupMenu *KSircTopLevel::user_controls = 0L;
@@ -85,8 +88,9 @@ KSircTopLevel::initColors()
 
 KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const QString &cname, const char * name)
     : KMainWindow(0, name, 0/*no WDestructiveClose !*/),
-      KSircMessageReceiver(_proc),
-      channel_name(cname)
+      UnicodeMessageReceiver(_proc),
+      channel_name(cname),
+      lastBeep( QTime::currentTime() )
 {
     // prevent us from being quitted when closing a channel-window. Only
     // closing the servercontroller shall quit.
@@ -129,18 +133,39 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const QString &cname, const ch
   file = new QPopupMenu(this, QString(QObject::name()) + "_popup_file");
   file->setCheckable(true);
 
-  file->insertItem(i18n("&New..."), this, SLOT(newWindow()), CTRL + Key_N);
+  KAction *act = KStdAction::openNew( this, SLOT( newWindow() ), actionCollection() );
+  act->plug( file );
   file->insertSeparator();
   file->insertItem(i18n("&Save to Logfile..."), this, SLOT(saveCurrLog()), CTRL + Key_S);
 
   tsitem = file->insertItem(i18n("Time St&amp"), this, SLOT(toggleTimestamp()), CTRL + Key_A);
   file->setItemChecked(tsitem, ksopts->timeStamp);
-  file->insertItem(i18n("Ascii &Table"), selector, SLOT(show()));
-  beepitem = file->insertItem(i18n("Bee&p on Change"), this, SLOT(toggleBeep()), CTRL + Key_P);
+  file->insertItem(i18n("ASCII &Table"), selector, SLOT(show()));
+  beepitem = file->insertItem(i18n("N&otify on Change"), this, SLOT(toggleBeep()), CTRL + Key_P);
   file->setItemChecked(beepitem, ksopts->beepOnMsg);
-  
+
+  encodingAction = new KSelectAction( i18n( "&Encoding" ), 0, this );
+  connect( encodingAction, SIGNAL( activated() ), this, SLOT( setEncoding() ) );
+  QStringList encodings = KGlobal::charsets()->descriptiveEncodingNames();
+
+  // remove utf16/ucs2 as it just doesn't work for IRC
+  QStringList::Iterator encodingIt = encodings.begin();
+  while ( encodingIt != encodings.end() ) {
+    if ( ( *encodingIt ).find( "utf16" ) != -1 ||
+         ( *encodingIt ).find( "iso-10646" ) != -1 )
+      encodingIt = encodings.remove( encodingIt );
+    else
+      ++encodingIt;
+  }
+  encodings.prepend( i18n( "Default" ) );
+
+  encodingAction->setItems( encodings );
+  encodingAction->plug( file );
+  encodingAction->setCurrentItem( 0 );
+
   file->insertSeparator();
-  file->insertItem(i18n("&Close"), this, SLOT(terminate()), CTRL + Key_W );
+  act = KStdAction::close( this, SLOT( terminate() ), actionCollection() );
+  act->plug( file );
 
   kmenu = menuBar();
   kmenu->insertItem(i18n("&Channel"), file, 2, -1);
@@ -191,9 +216,11 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const QString &cname, const ch
   pan = f->pan;
 
   edit = new QPopupMenu(this);
-  edit->insertItem(i18n("&Copy"), mainw, SLOT(copy()), CTRL + Key_C);
-  edit->insertItem(i18n("&Paste"), this, SLOT(pasteToWindow()), CTRL + Key_V);
-  edit->insertItem(i18n("&Clear Window"), this, SLOT(clearWindow()), CTRL + Key_L);
+  act = KStdAction::copy( mainw, SLOT( copy() ), actionCollection() );
+  act->plug( edit );
+  act = KStdAction::paste( this, SLOT( pasteToWindow() ), actionCollection() );
+  act->plug( edit );
+  edit->insertItem(i18n("C&lear Window"), this, SLOT(clearWindow()), CTRL + Key_L);
   kmenu->insertItem(i18n("&Edit"), edit, -1, -1);
 
   clearWindow();
@@ -203,7 +230,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const QString &cname, const ch
   initColors();
 
   ksb_main->addWidget(linee, mainw->width());
-  ksb_main->insertItem("Lag: Wait", KSB_MAIN_LAG, true);
+  ksb_main->insertItem(i18n("Lag: Wait"), KSB_MAIN_LAG, true);
 
   // don't show the nick lists in a private chat or the default window
   if (isPrivateChat() || channel_name.startsWith("!no_channel"))
@@ -237,8 +264,8 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const QString &cname, const ch
   connect(linee, SIGNAL(notTab()),
           this, SLOT(lineeNotTab()));
 
-  connect(linee, SIGNAL(returnPressed()), // Connect return in sle to send
-          this, SLOT(sirc_line_return()));// the line to dsirc
+  connect( linee, SIGNAL( returnPressed() ),
+           this, SLOT( returnPressed() ) );
 
   linee->setFocus();  // Give SLE focus
 
@@ -341,8 +368,8 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const QString &cname, const ch
                      SLOT(TabNickCompletion()));  // TabNickCompletion() slot
   accel->connectItem(accel->insertItem(CTRL + Key_N),
                      this, SLOT(newWindow()));
-  accel->connectItem(accel->insertItem(CTRL + Key_S),
-                     this, SLOT(toggleTimestamp()));
+//  accel->connectItem(accel->insertItem(CTRL + Key_S),
+//                     this, SLOT(toggleTimestamp()));
 
   // Drag & Drop
   connect( mainw, SIGNAL( textDropped(const QString&) ),
@@ -351,9 +378,8 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const QString &cname, const ch
            SLOT( slotDropURLs(const QStringList&) ));
   connect( nicks, SIGNAL( urlsDropped( const QStringList&, const QString& )),
            SLOT( slotDccURLs( const QStringList&, const QString& )));
+  connect( this, SIGNAL( changed(bool) ), this, SLOT( beep(bool) ));
 
-  connect( this, SIGNAL( changed(bool) ), this, SLOT( beep() ));
-  
   f->mainw->setAcceptFiles( isPrivateChat() );
   resize(600, 360);
 }
@@ -377,7 +403,7 @@ KSircTopLevel::~KSircTopLevel()
   if ( isPublicChat() ) {
       kdDebug() << "*** parting channel: " << channel_name << endl;
       QString str = QString("/part ") + channel_name + "\n";
-      emit outputLine(str);
+      emit outputUnicodeLine(str);
   }
 
   delete user_controls;
@@ -398,6 +424,23 @@ void KSircTopLevel::setMode(QString mode, int mode_type, QString currentNick)
   linee->setFocus();
 }
 
+void KSircTopLevel::setNick( const QString& nick )
+{
+    m_currentNick = nick;
+    while (!m_currentNick.isEmpty() &&
+          (m_currentNick[0].latin1() == '@' || m_currentNick[0].latin1() == '*'))
+      m_currentNick.remove(0, 1);
+}
+
+void KSircTopLevel::setEncoding()
+{
+  int index = encodingAction->currentItem();
+  if ( index == 0 ) // default (locale) encoding
+    UnicodeMessageReceiver::setEncoding( QString::null );
+  else
+    UnicodeMessageReceiver::setEncoding( KGlobal::charsets()->encodingForName( encodingAction->currentText() ) );
+}
+
 void KSircTopLevel::insertText()
 {
   linee->setText(linee->text() + selector->currentText());
@@ -508,14 +551,22 @@ void KSircTopLevel::sirc_receive(QString str, bool broadcast)
       // Get the need list box item, with colour, etc all set
       if (parse_input(line.message))
       {
-        // If we shuold add anything, add it.
+        // If we should add anything, add it.
         // Don't announce server messages as they are
         // spread through all channels anyway
-        bool addressedLine = line.message.find( ksopts->nick ) >= 0;
+        bool addressedLine = line.message.contains( m_currentNick, false /*case sensitive*/ ) &&
+          line.message.find( ">" ) < line.message.find( m_currentNick, 0, false /*case sensitive*/ );
+
+        // detect /msg's -- needed when auto-create-window is off
+        if ( line.message.find( QRegExp( "^\\[~b.+~b\\].+$" ) ) == 0 )
+            addressedLine = true;
+
         if ( addressedLine )
           addressed = true;
-        if ( !line.wasBroadcast )
-          emit changed( addressedLine );
+        if ( !line.wasBroadcast ) {
+          // This line is addressed to me if it contains my nick, or is in a private chat
+          emit changed( addressedLine || isPrivateChat() );
+        }
       }
     }
     LineBuffer.clear(); // Clear it since it's been added
@@ -528,40 +579,17 @@ void KSircTopLevel::sirc_receive(QString str, bool broadcast)
   }
 }
 
-void KSircTopLevel::sirc_line_return()
+void KSircTopLevel::sirc_line_return(const QString &text)
 {
 
   /* Take line from SLE, and output if to dsirc */
 
-  QString s = linee->text();
+  QString s = text;
 
   if(s.length() == 0)
     return;
 
   tab_pressed = 0; // new line, zero the counter.
-
-  //
-  // Lookup the nick completion
-  // Do this before we append the linefeed!!
-  //
-
-  int pos2;
-  if(ksopts->nickCompletion){
-    if (!tab_nick.isEmpty())
-    {
-      addCompleteNick(tab_nick);
-      tab_nick = QString::null;
-    }
-    if(s.find(QRegExp("^[^ :]+: "), 0) != -1){
-      pos2 = s.find(": ", 0);
-      if(pos2 < 1){
-        kdDebug() << "Evil string: " << s << endl;
-      }
-      else
-        s.replace(0, pos2, findNick(s.mid(0, pos2)));
-    }
-  }
-
   s += '\n'; // Append a need carriage return :)
 
   if((uint) nick_ring.at() < (nick_ring.count() - 1))
@@ -601,7 +629,7 @@ void KSircTopLevel::sirc_write(const QString &str)
         return;
       }
       else {
-        emit outputLine(plain + "\n");
+        emit outputUnicodeLine(plain + "\n");
         emit open_toplevel(name);
       }
       // Finish sending /join
@@ -625,9 +653,13 @@ void KSircTopLevel::sirc_write(const QString &str)
            plain.startsWith( "/exit" ) ||
            plain.startsWith( "/quit" )) {
     linee->setText( QString::null );
-    emit requestQuit( command );
+    emit requestQuit( command.ascii() );
     return;
   }
+  else if ( plain.startsWith( "/away" ) ) {
+    QString awayEvalCommand = QString::fromLatin1( "/eval $publicAway = %1\n" ).arg( ksopts->publicAway ? '1' : '0' );
+    emit outputUnicodeLine( awayEvalCommand );
+  }
 
   //
   // Look at the command, if we're assigned a channel name, default
@@ -638,7 +670,7 @@ void KSircTopLevel::sirc_write(const QString &str)
     if(plain[0].latin1() != '/'){
       command.prepend(QString::fromLatin1("/msg %1 ").arg(channel_name));
     }
-    else if(plain.startsWith("/me")) {
+    else if(plain.startsWith("/me ")) {
       command.remove(0, 3);
       command.prepend(QString("/de ") + channel_name);
     }
@@ -647,7 +679,7 @@ void KSircTopLevel::sirc_write(const QString &str)
   // Write out line
 
   scrollToBottom();
-  emit outputLine(command);
+  emit outputUnicodeLine(command);
 }
 
 bool KSircTopLevel::parse_input(const QString &string)
@@ -732,6 +764,20 @@ bool KSircTopLevel::parse_input(const QString &string)
   return true;
 }
 
+void KSircTopLevel::returnPressed()
+{
+  QString s = linee->text();
+  if ( s.startsWith( "/j " ) || s.startsWith( "/join " ) ) {
+    s.remove( 0, s.find( "#" ) );
+    QStringList fragments = QStringList::split( ",", s );
+    QStringList::ConstIterator it = fragments.begin();
+    QStringList::ConstIterator end = fragments.end();
+    for ( ; it != end; ++it )
+      sirc_line_return( "/join " + *it );
+  } else
+    sirc_line_return( s );
+}
+
 void KSircTopLevel::UserSelected(int index)
 {
   if(index >= 0)
@@ -834,12 +880,12 @@ void KSircTopLevel::gotFocus()
     if(have_focus == 0){
       if(channel_name[0] == '#'){
         QString str = QString("/join %1\n").arg(channel_name);
-        emit outputLine(str);
+        emit outputUnicodeLine(str);
         emit outputLine("/eval $query=''\n");
       }
       else if (channel_name[0] != '!')
       {
-          emit outputLine(QString("/eval $query='%1'\n").arg(channel_name));
+          emit outputUnicodeLine(QString("/eval $query='%1'\n").arg(channel_name));
       }
       have_focus = 1;
       emit currentWindow(this);
@@ -938,7 +984,7 @@ void KSircTopLevel::control_message(int command, QString str)
       if(ok == TRUE){
         lag -= (lag*100.0 - int(lag*100.0))/100.0;
         QString s_lag;
-                s_lag.sprintf("Lag: %.2f", lag);
+        s_lag.sprintf("Lag: %.2f", lag);
         ksb_main->changeItem(s_lag, KSB_MAIN_LAG);
       }
       else{
@@ -1046,7 +1092,11 @@ void KSircTopLevel::slotTextDropped( const QString& _text )
 {
   if (_text.isEmpty())
     return;
-  QString text = linee->text() + _text;
+  QString text = linee->text();
+  int curPos = linee->cursorPosition();
+
+  text = text.mid( 0, curPos ) + _text + text.mid( curPos );
+
   if (text[text.length()-1] != '\n')
      text += "\n";
   int lines = text.contains("\n");
@@ -1079,7 +1129,7 @@ void KSircTopLevel::slotTextDropped( const QString& _text )
         QString line = *it;
         if ( line[0].latin1() == '/' )
         {
-            if ( commands == Ask )
+           if ( commands == Ask )
                 switch ( KMessageBox::questionYesNo( this, i18n(
                     "The text you pasted contains lines that start with /.\n"
                     "Should they be interpreted as IRC commands?" ) ) )
@@ -1095,7 +1145,7 @@ void KSircTopLevel::slotTextDropped( const QString& _text )
                 line.prepend( "/say " );
         }
         linee->setText( line );
-        sirc_line_return();
+        sirc_line_return(line);
     }
 
     linee->setText("");
@@ -1105,6 +1155,7 @@ void KSircTopLevel::slotTextDropped( const QString& _text )
   else{
     text.replace(QRegExp("\n"), "");
     linee->setText(text);
+    linee->setCursorPosition( curPos + _text.length() );
   }
 }
 
@@ -1138,7 +1189,7 @@ void KSircTopLevel::saveCurrLog()
 {
     KURL url = KFileDialog::getSaveFileName(QString::null,
                                             "*.log", 0L,
-                                            i18n("Save chat / query logfile"));
+                                            i18n("Save Chat/Query Logfile"));
 
     KTempFile temp;
     QTextStream *str = temp.textStream();
@@ -1203,6 +1254,11 @@ void KSircTopLevel::scrollToBottom()
 //    mainw->ensureVisible( 0, mainw->contentsHeight() );
 }
 
+void KSircTopLevel::outputUnicodeLine( const QString &message )
+{
+  emit outputLine( encoder()->fromUnicode( message ) );
+}
+
 void KSircTopLevel::setTopicIntern( const QString &topic )
 {
     QString command = QString::fromLatin1( "/topic %1 %2\n" ).arg( channel_name ).arg( topic );
@@ -1210,10 +1266,22 @@ void KSircTopLevel::setTopicIntern( const QString &topic )
     linee->setFocus();
 }
 
-void KSircTopLevel::beep()
+void KSircTopLevel::beep(bool pers)
 {
-    if (ksopts->beepOnMsg)
-        KNotifyClient::beep();
+    QTime ctime = QTime::currentTime();
+    if (ksopts->beepOnMsg) {
+        // beep only every 2 seconds otherwise it'll get very noisy in the room ;)
+        if ( QABS( lastBeep.secsTo( ctime ) ) > 1 ) {
+          if ( pers ) {
+              KNotifyClient::event(QString::fromLatin1("ChannelPersonal"),
+                  i18n("Your nick appeared on channel %1").arg(channel_name));
+          } else {
+              KNotifyClient::event(QString::fromLatin1("ChannelChanged"),
+                  i18n("Channel %1 changed").arg(channel_name));
+          }
+          lastBeep = ctime;
+        }
+    }
 }
 
 void KSircTopLevel::toggleBeep()
