@@ -71,13 +71,13 @@ KSoundPageConfig::KSoundPageConfig( QWidget *parent, const char* name,
     extprg_edit = new KURLRequester(extprg_box);
     l->addWidget(extprg_edit, 2, 4);
 
-    extprg_label = new QLabel(extprg_edit,i18n("&Announcement program"), extprg_box);
+    extprg_label = new QLabel(extprg_edit,i18n("&Announcement program:"), extprg_box);
     l->addWidget(extprg_label, 2, 2);
 
     client_edit = new KURLRequester(extprg_box);
     l->addWidget(client_edit, 4, 4);
 
-    client_label = new QLabel(client_edit,i18n("&Talk client"), extprg_box);
+    client_label = new QLabel(client_edit,i18n("&Talk client:"), extprg_box);
     l->addWidget(client_label, 4, 2);
 
     toplay->addSpacing(30);
@@ -97,7 +97,7 @@ KSoundPageConfig::KSoundPageConfig( QWidget *parent, const char* name,
     sound_list->setAcceptDrops(true);
     sound_list->installEventFilter(this);
 
-    sound_label = new QLabel(sound_list,i18n("&Sound File"), sound_box);
+    sound_label = new QLabel(sound_list,i18n("&Sound file:"), sound_box);
     lay->addWidget(sound_label);
 
     QBoxLayout* l2 = new QHBoxLayout(lay, 10);
@@ -189,15 +189,15 @@ void KSoundPageConfig::sound_listDropEvent(QDropEvent* e){
     if ("file:" != url.left(5)) {      // for now, only file URLs are supported
 
       KMessageBox::sorry(this,
-        i18n("Sorry, this type of URL is currently unsupported"\
+        i18n("This type of URL is currently unsupported "\
               "by the KDE System Sound Module"),
 		i18n("Unsupported URL"));
 
     } else { // Now check for the ending ".wav"
 
       if (".WAV" != url.right(4).upper()) {
-         msg = i18n("Sorry, but \n%1\ndoes not seem "\
-                            "to be a WAV--file.").arg(url);
+         msg = i18n("%1\ndoes not appear "\
+                            "to be a WAV file.").arg(url);
 
         KMessageBox::sorry(this, msg, i18n("Improper File Extension"));
 
