@@ -2,33 +2,33 @@
  * Copyright (c) 1983 Regents of the University of California.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
- *    may be used to endorse or promote products derived from this software
- *    without specific prior written permission.
+ *  Redistribution and use in source and binary forms, with or
+ *    without modification, are permitted provided that the following
+ *    conditions are met:
  *
- * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ *    - Redistributions of source code must retain the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer.
+ *
+ *    - Redistributions in binary form must reproduce the above
+ *      copyright notice, this list of conditions and the following
+ *      disclaimer in the documentation and/or other materials
+ *      provided with the distribution.
+ *
+ *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY
+ *    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
+ *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
+ *    PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR
+ *    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ *    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+ *    TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ *    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ *    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ *    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
+ *    IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
+ *    THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * (BSD License, from kdelibs/doc/common/bsd-license.html)
  */
 
 /* Autoconf: */
@@ -63,7 +63,7 @@
 #include <string.h>
 #include <pwd.h>
 #include <netdb.h>
-#include "print.h"
+#include "proto.h"
 #include "announce.h"
 #include "readconf.h"
 #include "defs.h"
@@ -95,12 +95,12 @@ int announce(NEW_CTL_MSG *request, const char *remote_machine, char *disp, int
     int returncode;
 
     if (strstr(remote_machine,"\033")) {
-        syslog(LOG_WARNING, 
-               "blocked VT100 FLASH BOMB to user: %s (from field in packet contains bomb)", 
+        syslog(LOG_WARNING,
+               "blocked VT100 FLASH BOMB to user: %s (from field in packet contains bomb)",
                request->r_name);
     } else if (strstr(request->l_name,"\033")) {
         syslog(LOG_WARNING,
-               "blocked VT100 FLASH BOMB to user: %s (apparently from: %s)", 
+               "blocked VT100 FLASH BOMB to user: %s (apparently from: %s)",
                request->r_name, remote_machine);
     } else {
         if ((pid = fork())) {
@@ -120,12 +120,13 @@ int announce(NEW_CTL_MSG *request, const char *remote_machine, char *disp, int
         pw_buf = getpwnam(request->r_name);
 
 	/* XXX: Not good
-	 *  1.	If setuid or setgid fails, you should fail, too
-	 *  2.	You should also set the supplementary groups using
+	 * 	You should also set the supplementary groups using
 	 *  	setgroups/initgroups
 	 */
-        if (setgid(pw_buf -> pw_gid) || setuid(pw_buf -> pw_uid))
-            syslog(LOG_WARNING, "Warning: setuid: %m");
+        if (setgid(pw_buf -> pw_gid) || setuid(pw_buf -> pw_uid)) {
+            syslog(LOG_WARNING, "Warning: setgid/setuid as %s: %s", request->r_name, strerror(errno));
+            _exit(1);
+        }
 
         /** Also set $HOME once and for all that follows (not used for text
             announce, but doesn't harm) */
@@ -137,7 +138,7 @@ int announce(NEW_CTL_MSG *request, const char *remote_machine, char *disp, int
 #endif
             returncode = print_std_mesg( request, remote_machine, usercfg, 0 );
         _exit(returncode);
-        
+
     }
     return (FAILED);
 }
@@ -157,7 +158,7 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
   char * adisp_begin, *disp_ptr, * disp_end;
   char extprg [S_MESSG]; /* Program used for notification. */
   int Xannounceok = 0; /* Set to 1 if at least one Xannounceok succeeded */
-  
+
 #ifdef PROC_FIND_USER
   if ((Options.XAnnounce) && (strlen(disp) >= 2)) {
 #else
@@ -167,7 +168,7 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
     /*
      * He is in X (probably :-) -> try to connect with external program
      */
-      
+
    /*  No more needed : ktalkdlg will play sound itself.
         Other external programs can do whatever they want...
         Maybe a config for this could be useful to know whether the
@@ -188,7 +189,7 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
      */
     if ((!usercfg) || (!read_user_config("ExtPrg", extprg, S_MESSG)))
         /* try to read extprg from user config file, otherwise : */
-        strcpy(extprg,Options.extprg); /* take default */            
+        strcpy(extprg,Options.extprg); /* take default */
 
     /* disp can be a LIST of displays, such as ":0 :1", or
          ":0 hostname:0". Let's announce on ALL displays found.
@@ -209,10 +210,10 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
         pipe( readPipe );
         switch (pid = fork()) {
             case -1: {
-                syslog(LOG_ERR,"Announce : Fork failed ! - %m");
+                syslog(LOG_ERR,"Announce : Fork failed ! - %s", strerror(errno));
                 return ( FAILED );
             }
-            case 0: {                
+            case 0: {
 
                 close(readPipe[0]); // we do not need to read the pipe in the child
 
@@ -221,9 +222,9 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
 
                 if (Options.debug_mode)
                 {
-                    syslog(LOG_DEBUG, "Trying to run '%s' at '%s' as '%s'", extprg, 
+                    syslog(LOG_DEBUG, "Trying to run '%s' at '%s' as '%s'", extprg,
                            getenv("DISPLAY"), request->r_name );
-                    if (callee) message("With mention of callee : %s",callee);
+                    if (callee) debug("With mention of callee : %s",callee);
                 }
                 /*
                  * point stdout of external program to the pipe
@@ -232,15 +233,15 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
                 dup2( readPipe[1], STDOUT_FILENO );
 
                 if (callee)
-                    execl( extprg, extprg, line_buf, callee, 0 );
+                    execl( extprg, extprg, line_buf, callee, NULL );
                 else
-                    execl( extprg, extprg, line_buf, 0 );
-                
+                    execl( extprg, extprg, line_buf, NULL );
+
                 /*
                  * failure - tell it to father
                  * exit with status=42
                  */
-                syslog(LOG_WARNING, "error while execl(%s): %m", extprg);
+                syslog(LOG_WARNING, "error while execl(%s): %s", extprg, strerror(errno));
                 _exit( 42 );
             }
             default: {
@@ -263,15 +264,18 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
                  * does this work on systems other than BSD&Linux??
                  */
                 if (fcntl(readPipe[0], F_SETFL, O_NONBLOCK)== -1)
-                        message("Failed to make pipe non-blocking!!");
+                        debug("Failed to make pipe non-blocking!!");
 
                 /* Stop this loop when:
                  *  the child exited with a value > 0 AND the pipe is empty
                  * Maybe we can add a time-out? (what is reasonable)
                  */
                 while (c > 0 || (exited < 1)){
-                    status = wait_process(pid);                           // this may cause some 'no child process' warnings
-                    exited += (WIFEXITED(status) || WIFSIGNALED(status)); // non-zero when exited OR non-caught signal
+                    if ( exited < 1 )
+                    {
+                        status = wait_process(pid);
+                        exited += (WIFEXITED(status) || WIFSIGNALED(status)); // non-zero when exited OR non-caught signal
+                    }
                     c = read( readPipe[0], &ch_aux, 1 );                  // this is many times -1 because no data in pipe
 
                     if (ch_aux == '#') Xannounceok = 1;
@@ -283,9 +287,9 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
                  * 42 is: failure to start external program.
                  */
                 if (Xannounceok == 1) {
-                    message("OK - Child process responded");
+                    debug("OK - Child process responded");
                 } else
-                    message("External program failed with exit status: %i", WEXITSTATUS(status));
+                    debug("External program failed with exit status: %i", WEXITSTATUS(status));
 
                 // close the pipes: (is this neccesary?):
                 close( readPipe[0] );
@@ -302,11 +306,11 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
 
     if (Xannounceok) {
 #ifndef NO_TEXT_ANNOUNCE_IF_X
-        // never defined. Define it if you don't want text announce in 
+        // never defined. Define it if you don't want text announce in
         // addition to X announce
         if ((request->r_tty[0]!='\0') && ((int)request->r_tty[3]<(int)'f'))  {
 	  // Not a pseudo terminal (such as an xterm, ...)
-            message("Doing also text announce on %s",request->r_tty);
+            debug("Doing also text announce on %s",request->r_tty);
             print_std_mesg(request, remote_machine, usercfg, 1 /*force no sound*/);
         }
 #endif
@@ -318,7 +322,7 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
 #endif /* HAVE_KDE */
 
 /*
- * See if the user is accepting messages. If so, announce that 
+ * See if the user is accepting messages. If so, announce that
  * a talk is requested.
  */
 
@@ -328,7 +332,7 @@ int print_std_mesg( NEW_CTL_MSG *request, const char *remote_machine, int
   char full_tty[32];
   FILE *tf;
   struct stat stbuf;
-  
+
   (void)snprintf(full_tty, sizeof(full_tty), "%s/%s", _PATH_DEV, request->r_tty);
   if (access(full_tty, 0) != 0)
     return (FAILED);
@@ -350,7 +354,7 @@ int print_std_mesg( NEW_CTL_MSG *request, const char *remote_machine, int
 }
 
 /*
- * Build a block of characters containing the message. 
+ * Build a block of characters containing the message.
  * It is sent blank filled and in a single block to
  * try to keep the message in one piece if the recipient
  * in in vi at the time
@@ -372,13 +376,13 @@ void print_mesg(FILE * tf, NEW_CTL_MSG * request, const char *
 	strcpy(remotemach,remote_machine);
 	/* We have to duplicate it because param_remote_machine is contained
 	   in the hostent structure, and will be erased by gethostbyname. */
-	
+
 	char localname[SYS_NMLN];
 	strcpy(localname,gethostbyname(Options.hostname)->h_name);
 	/* We have to duplicate localname also. Same reasons as above ! */
-	
+
 	const char *remotename = gethostbyname(remotemach)->h_name;
-	
+
 	i = 0;
 	max_size = 0;
 	gettimeofday(&clock, &zone);
@@ -445,13 +449,13 @@ int play_sound(int usercfg)
         because the father will close the file soon !! */
      if ((!usercfg) || (!read_user_config("SoundPlayer",sSoundPlayer,S_CFGLINE)))
          strcpy(sSoundPlayer,Options.soundplayer);
-     message(sSoundPlayer);
+     debug(sSoundPlayer);
      if ((!usercfg) || (!read_user_config("SoundPlayerOpt",sSoundPlayerOpt,S_CFGLINE)))
          strcpy(sSoundPlayerOpt,Options.soundplayeropt);
-     message(sSoundPlayerOpt);
+     debug(sSoundPlayerOpt);
      if ((!usercfg) || (!read_user_config("SoundFile",sSoundFile,S_CFGLINE)))
          strcpy(sSoundFile,Options.soundfile);
-     message(sSoundFile);
+     debug(sSoundFile);
 
      if ((pid = fork())) {
          /* we are the parent, so wait for the child */
@@ -473,11 +477,11 @@ int play_sound(int usercfg)
      else
          returncode = execl(sSoundPlayer,sSoundPlayer/*arg0*/,sSoundFile,NULL);
 
-     message(strerror(errno));
+     debug(strerror(errno));
      syslog(LOG_ERR,"ERROR PLAYING SOUND FILE !!!");
      syslog(LOG_ERR, "%s,%s,%s",sSoundPlayer,sSoundFile,sSoundPlayerOpt);
      syslog(LOG_ERR,"RETURN-CODE : %d",returncode);
-     
+
      _exit(returncode);
      /*NOTREACHED*/
      return 0;
@@ -492,9 +496,9 @@ int sound_or_beep(int usercfg)
      int ret;
      if ((!usercfg) || (!read_bool_user_config("Sound",&bSound)))
          bSound=Options.sound;
-     
-     message("Sound option in sound_or_beep : %d",bSound);
-     
+
+     debug("Sound option in sound_or_beep : %d",bSound);
+
      if (bSound)
        {
 	/* try to play sound, otherwise beeps (if not in X) */
