@@ -125,11 +125,11 @@ void NetManager::configure(Config& config)
 {
    m_refreshTime=config.getEntry("UpdatePeriod",300);
    MyString tmp=stripWhiteSpace(config.getEntry("BroadcastNetwork","0.0.0.0/255.255.255.255;"));
-   tmp=tmp+",";
+   tmp=tmp+";";
    mgetDebug()<<"NetManager::readConfig: "<<tmp<<std::endl;
    MyString netAddressStr=tmp.left(tmp.find('/'));
    tmp=tmp.mid(tmp.find('/')+1);
-   tmp=tmp.left(tmp.find(','));
+   tmp=tmp.left(tmp.find(';'));
    mgetDebug()<<"NetManager::readConfig: broadcastNet "<<netAddressStr<<" with mask "<<tmp<<std::endl;
    int netMask=inet_addr(tmp.c_str());
    int netAddress=inet_addr(netAddressStr.c_str());
@@ -795,7 +795,7 @@ void NetManager::adjustRefreshTime(int serverServer)
    };
    m_servedThisPeriod=0;
    
-};
+}
 
 void NetManager::enableServerServer(int on)
 {
@@ -846,7 +846,7 @@ void NetManager::enableServerServer(int on)
       ::close(m_bcFD);
       m_bcFD=-1;
    };
-};
+}
 
 int NetManager::findServerServer()
 {
@@ -980,7 +980,7 @@ int NetManager::findServerServer()
    ::close(answerFD);
    //return the ip of the server server in network byte order
    return addr.sin_addr.s_addr;
-};
+}
 
 void NetManager::getListFromServerServer( int address)
 {
@@ -1009,7 +1009,7 @@ void NetManager::getListFromServerServer( int address)
    ::close(serverServerFD);
    processScanResults();
    mgetDebug()<<"NetManager::getListFromServerServer succeeded"<<std::endl;
-};
+}
 
 void NetManager::printState()
 {
@@ -1029,7 +1029,7 @@ void NetManager::printState()
    std::cerr<<"Sending "<<m_maxPings<<" echo requests at once"<<std::endl;
    std::cerr<<"Publishing unnamed hosts: "<<m_deliverUnnamedHosts<<std::endl;
    std::cerr<<"Already served "<<m_serveCount<<" times"<<std::endl;
-};
+}
 
 //this one is not used at the moment
 /*int NetManager::uptime()
