@@ -1,23 +1,35 @@
-/*
+/*  -*- c++ -*-
     kmime_header_parsing.cpp
 
-    KMime, the KDE internet mail/usenet news message library.
-    Copyright (c) 2001-2002 the KMime authors.
-    See file AUTHORS for details
+    This file is part of KMime, the KDE internet mail/usenet news message library.
+    Copyright (c) 2001-2002 Marc Mutz <mutz@kde.org>
+
+    KMime is free software; you can redistribute it and/or modify it
+    under the terms of the GNU General Public License, version 2, as
+    published by the Free Software Foundation.
+
+    KMime is distributed in the hope that it will be useful, but
+    WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    General Public License for more details.
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software Foundation,
-    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+    along with this library; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+    In addition, as a special exception, the copyright holders give
+    permission to link the code of this library with any edition of
+    the Qt library by Trolltech AS, Norway (or with modified versions
+    of Qt that use the same license as Qt), and distribute linked
+    combinations including the two.  You must obey the GNU General
+    Public License in all respects for all of the code used other than
+    Qt.  If you modify this file, you may extend this exception to
+    your version of the file, but you are not obligated to do so.  If
+    you do not wish to do so, delete this exception statement from
+    your version.
 */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
 #include "kmime_header_parsing.h"
 
 #include "kmime_codecs.h"
@@ -40,6 +52,30 @@ using namespace KMime::Types;
 
 namespace KMime {
 
+namespace Types {
+
+  QString AddrSpec::asString() const {
+    bool needsQuotes = false;
+    QString result;
+    for ( unsigned int i = 0 ; i < localPart.length() ; ++i ) {
+      const char ch = localPart[i].latin1();
+      if ( ch == '.' || isAText( ch ) )
+	result += ch;
+      else {
+	needsQuotes = true;
+	if ( ch == '\\' || ch == '"' )
+	  result += '\\';
+	result += ch;
+      }
+    }
+    if ( needsQuotes )
+      return '"' + result + "\"@" + domain;
+    else
+      return result + '@' + domain;
+  }
+
+}
+
 namespace HeaderParsing {
 
 // parse the encoded-word (scursor points to after the initial '=')
@@ -477,6 +513,18 @@ bool parsePhrase( const char* & scursor, const char * const send,
   while ( scursor != send ) {
     char ch = *scursor++;
     switch ( ch ) {
+    case '.': // broken, but allow for intorop's sake
+      if ( found == None ) {
+	--scursor;
+	return false;
+      } else {
+	if ( scursor != send && ( *scursor == ' ' || *scursor == '\t' ) )
+	  result += ". ";
+	else
+	  result += '.';
+	successfullyParsed = scursor;
+      }
+      break;
     case '"': // quoted-string
       tmp = QString::null;
       if ( parseGenericQuotedString( scursor, send, tmp, isCRLF, '"', '"' ) ) {
@@ -993,11 +1041,11 @@ bool parseAddress( const char* & scursor, const char * const send,
 }
 
 bool parseAddressList( const char* & scursor, const char * const send,
-		       QValueList<Address> & result, bool isCRLF ) {
+		       AddressList & result, bool isCRLF ) {
   while ( scursor != send ) {
     eatCFWS( scursor, send, isCRLF );
     // end of header: this is OK.
-    if ( scursor != send ) return true;
+    if ( scursor == send ) return true;
     // empty entry: ignore:
     if ( *scursor == ',' ) { scursor++; continue; }
 
@@ -1685,6 +1733,6 @@ bool tryToMakeAnySenseOfDateString( const char* & scursor,
 }
 #endif
 
-}; // namespace HeaderParsing
+} // namespace HeaderParsing
 
-}; // namespace KMime
+} // namespace KMime
