@@ -217,5 +217,5 @@ bool UUEncoded::parse()
 }
 
 
-}; // namespace Parser
-}; // namespace KMime
+} // namespace Parser
+} // namespace KMime
