@@ -1808,4 +1808,4 @@ Module::setEncryptionPreference( const QString& address,
   }
 }
 
-}; // namespace Kpgp
+} // namespace Kpgp
