@@ -467,7 +467,7 @@ Module::showKeyApprovalDlg( void ) const
 
 // -------------------------------------------------------------------------
 
-}; // namespace Kpgp
+} // namespace Kpgp
 
 #endif
 
