@@ -420,11 +420,32 @@ Base::runGpg( const char *cmd, const char *passphrase, bool onlyReadFromGnuPG )
   pipe(pout);
   pipe(perr);
 
-    if(passphrase) {
-      snprintf(gpgcmd, 1023, "LANGUAGE=C gpg --passphrase-fd %d %s",ppass[0],cmd);
-    } else {
-      snprintf(gpgcmd, 1023, "LANGUAGE=C gpg %s",cmd);
+  if( passphrase ) {
+    if( mVersion >= "1.0.7" ) {
+      // GnuPG >= 1.0.7 supports the gpg-agent, so we look for it.
+      if( 0 == getenv("GPG_AGENT_INFO") ) {
+        // gpg-agent not found, so we tell gpg not to use the agent
+        snprintf( gpgcmd, 1023,
+                  "LANGUAGE=C gpg --no-use-agent --passphrase-fd %d %s",
+                  ppass[0], cmd );
+      }
+      else {
+        // gpg-agent seems to be running, so we tell gpg to use the agent
+        snprintf( gpgcmd, 1023,
+                  "LANGUAGE=C gpg --use-agent %s",
+                  cmd );
+      }
     }
+    else {
+      // GnuPG < 1.0.7 doesn't know anything about the gpg-agent
+      snprintf( gpgcmd, 1023,
+                "LANGUAGE=C gpg --passphrase-fd %d %s",
+                ppass[0], cmd );
+    }
+  }
+  else {
+    snprintf(gpgcmd, 1023, "LANGUAGE=C gpg %s",cmd);
+  }
 
   QApplication::flushX();
   if(!(child_pid = fork()))
@@ -444,9 +465,30 @@ Base::runGpg( const char *cmd, const char *passphrase, bool onlyReadFromGnuPG )
 
     //#warning FIXME: there has to be a better way to do this
      /* this is nasty nasty nasty (but it works) */
-    if(passphrase) {
-      snprintf(gpgcmd, 1023, "LANGUAGE=C gpg --passphrase-fd %d %s",ppass[0],cmd);
-    } else {
+    if( passphrase ) {
+      if( mVersion >= "1.0.7" ) {
+        // GnuPG >= 1.0.7 supports the gpg-agent, so we look for it.
+        if( 0 == getenv("GPG_AGENT_INFO") ) {
+          // gpg-agent not found, so we tell gpg not to use the agent
+          snprintf( gpgcmd, 1023,
+                    "LANGUAGE=C gpg --no-use-agent --passphrase-fd %d %s",
+                    ppass[0], cmd );
+        }
+        else {
+          // gpg-agent seems to be running, so we tell gpg to use the agent
+          snprintf( gpgcmd, 1023,
+                    "LANGUAGE=C gpg --use-agent %s",
+                    cmd );
+        }
+      }
+      else {
+        // GnuPG < 1.0.7 doesn't know anything about the gpg-agent
+        snprintf( gpgcmd, 1023,
+                  "LANGUAGE=C gpg --passphrase-fd %d %s",
+                  ppass[0], cmd );
+      }
+    }
+    else {
       snprintf(gpgcmd, 1023, "LANGUAGE=C gpg %s",cmd);
     }
 
@@ -489,7 +531,7 @@ Base::runGpg( const char *cmd, const char *passphrase, bool onlyReadFromGnuPG )
     //kdDebug(5100) << "waitpid returned " << waitpidRetVal << endl;
     do {
       // poll the pipes
-      pollstatus = poll(poller, num_pollers, -1);
+      pollstatus = poll(poller, num_pollers, 10);
       if( 0 < pollstatus ) {
         // Check stdout.
         if (poller[STD_OUT].revents & POLLIN) {
@@ -638,4 +680,4 @@ Base::addUserId()
 }
 
 
-}; // namespace Kpgp
+} // namespace Kpgp
