@@ -346,7 +346,7 @@ KeyID KeySelectionDialog::key() const
     return KeyID();
   else
     return mKeyIds.first();
-};
+}
 
 
 void KeySelectionDialog::initKeylist( const KeyList& keyList,
@@ -1509,7 +1509,7 @@ void SecretKeyRequester::virtual_hook( int id, void* data ) {
   base::virtual_hook( id, data );
 }
 
-}; // namespace Kpgp
+} // namespace Kpgp
 
 
 
