@@ -23,9 +23,6 @@
 
 #include <qfile.h>
 #include <qdom.h>
-#if QT_VERSION < 290
-#  include <qregexp.h>
-#endif
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qcheckbox.h>
@@ -41,20 +38,38 @@
 
 
 //----------------------------------------------------------------------------
-// a small function to encode "<" and ">" to xml
-static inline QString toXml(QString s)
+// a small function to encode attribute values, code stolen from QDom
+static QString toXml(const QString& str)
 {
-  int off = 0;
-  while ((off = s.find('<',off)) >= 0) {
-    s.replace(off,1,"&lt;");
+  QString tmp(str);
+  uint len = tmp.length();
+  uint i = 0;
+  while ( i < len ) {
+    if (tmp[(int)i] == '<') {
+      tmp.replace(i, 1, "&lt;");
+      len += 3;
+      i += 4;
+    } else if (tmp[(int)i] == '"') {
+      tmp.replace(i, 1, "&quot;");
+      len += 5;
+      i += 6;
+    } else if (tmp[(int)i] == '&') {
+       tmp.replace(i, 1, "&amp;");
+       len += 4;
+       i += 5;
+    } else if (tmp[(int)i] == '>') {
+       tmp.replace(i, 1, "&gt;");
+       len += 3;
+       i += 4;
+    } else {
+       ++i;
+    }
   }
-  off = 0;
-  while ((off = s.find('>',off)) >= 0) {
-    s.replace(off,1,"&gt;");
-  }
-  return s;
+
+  return tmp;
 }
 
+
 // small dialog to display the messages from NotifyAction
 NotifyDialog* NotifyDialog::me = 0;
 NotifyDialog::NotesMap NotifyDialog::dict;
@@ -151,9 +166,9 @@ ActionBase* ActionBase::factory(int type, QString value)
 QString ActionBase::userName(int type)
 {
   switch (type) {
-    case SETSCORE: return i18n("adjust score");
-    case NOTIFY:   return i18n("display message");
-    case COLOR:    return i18n("colorize header");
+    case SETSCORE: return i18n("Adjust Score");
+    case NOTIFY:   return i18n("Display Message");
+    case COLOR:    return i18n("Colorize Header");
   default:
     kdWarning(5100) << "unkown type " << type << " in ActionBase::userName()" << endl;
     return 0;
@@ -245,7 +260,7 @@ ActionColor::~ActionColor()
 QString ActionColor::toString() const
 {
   QString a;
-  a += "<Action type=\"COLOR\" value=\"" + color.name() + "\" />";
+  a += "<Action type=\"COLOR\" value=\"" + toXml(color.name()) + "\" />";
   return a;
 }
 
@@ -274,7 +289,7 @@ ActionNotify::ActionNotify(const ActionNotify& an)
 
 QString ActionNotify::toString() const
 {
-  return "<Action type=\"NOTIFY\" value=\"" + note + "\" />";
+  return "<Action type=\"NOTIFY\" value=\"" + toXml(note) + "\" />";
 }
 
 void ActionNotify::apply(ScorableArticle& a) const
@@ -395,11 +410,11 @@ int KScoringExpression::getConditionForName(const QString& s)
 QString KScoringExpression::getNameForCondition(int cond)
 {
   switch (cond) {
-  case CONTAINS: return i18n("contains substring");
-  case MATCH: return i18n("matches regular expression");
-  case EQUALS: return i18n("is exactly the same as");
-  case SMALLER: return i18n("less than");
-  case GREATER: return i18n("greater than");
+  case CONTAINS: return i18n("Contains Substring");
+  case MATCH: return i18n("Matches Regular Expression");
+  case EQUALS: return i18n("Is Exactly the Same As");
+  case SMALLER: return i18n("Less Than");
+  case GREATER: return i18n("Greater Than");
   default:
     kdWarning(5100) << "unknown condition " << cond
                     << " in KScoringExpression::getNameForCondition()" << endl;
@@ -451,7 +466,7 @@ bool KScoringExpression::match(ScorableArticle& a) const
   else
     head = a.getHeaderByType(c_header);
 
-  if (!head.isNull() && !head.isEmpty()) {
+  if (!head.isEmpty()) {
     switch (cond) {
     case EQUALS:
       res = (head.lower() == expr_str.lower());
@@ -606,11 +621,7 @@ void KScoringRule::setExpire(const QString& e)
 {
   if (e != "never") {
     QStringList l = QStringList::split("-",e);
-#if QT_VERSION < 290
-    ASSERT( l.count() == 3 );
-#else
     Q_ASSERT( l.count() == 3 );
-#endif
     expires.setYMD( (*(l.at(0))).toInt(),
         (*(l.at(1))).toInt(),
         (*(l.at(2))).toInt());
@@ -622,16 +633,9 @@ bool KScoringRule::matchGroup(const QString& group) const
 {
   for(GroupList::ConstIterator i=groups.begin(); i!=groups.end();++i) {
     QRegExp e(*i);
-#if QT_VERSION < 290
-    int len;
-    if (e.match(group, 0, &len) != -1 &&
-        ((uint)(len) == group.length()))
-        return true;
-#else
     if (e.search(group, 0) != -1 &&
 	(uint)e.matchedLength() == group.length())
         return true;
-#endif
   }
   return false;
 }
@@ -655,11 +659,7 @@ void KScoringRule::applyRule(ScorableArticle& a) const
   QPtrListIterator<KScoringExpression> it(expressions);
   //kdDebug(5100) << "checking " << expressions.count() << " expressions" << endl;
   for (; it.current(); ++it) {
-#if QT_VERSION < 290
-    ASSERT( it.current() );
-#else
     Q_ASSERT( it.current() );
-#endif
     res = it.current()->match(a);
     if (!res && oper_and) return;
     else if (res && !oper_and) break;
@@ -671,11 +671,7 @@ void KScoringRule::applyRule(ScorableArticle& a /*, const QString& s*/, const QS
 {
   // check if one of the groups match
   for (QStringList::ConstIterator i = groups.begin(); i != groups.end(); ++i) {
-#if QT_VERSION < 290
-    if (QRegExp(*i).match(g) != -1) {
-#else
     if (QRegExp(*i).search(g) != -1) {
-#endif
       applyRule(a);
       return;
     }
@@ -691,11 +687,11 @@ QString KScoringRule::toString() const
 {
   //kdDebug(5100) << "KScoringRule::toString() starts" << endl;
   QString r;
-  r += "<Rule name=\"" + name + "\" linkmode=\"" + getLinkModeName();
+  r += "<Rule name=\"" + toXml(name) + "\" linkmode=\"" + getLinkModeName();
   r += "\" expires=\"" + getExpireDateString() + "\">";
   //kdDebug(5100) << "building grouplist..." << endl;
   for(GroupList::ConstIterator i=groups.begin();i!=groups.end();++i) {
-    r += "<Group name=\"" + *i + "\" />";
+    r += "<Group name=\"" + toXml(*i) + "\" />";
   }
   //kdDebug(5100) << "building expressionlist..." << endl;
   QPtrListIterator<KScoringExpression> eit(expressions);
@@ -778,6 +774,7 @@ void KScoringManager::save()
   if ( !f.open( IO_WriteOnly ) )
     return;
   QTextStream stream(&f);
+  stream.setEncoding(QTextStream::Unicode);
   kdDebug(5100) << "KScoringManager::save() creating xml" << endl;
   createXMLfromInternal().save(stream,2);
   kdDebug(5100) << "KScoringManager::save() finished" << endl;
@@ -844,11 +841,7 @@ void KScoringManager::createInternalFromXML(QDomNode n)
         addRuleInternal(cR);
       }
       else if (s == "Group") {
-#if QT_VERSION < 290
-        CHECK_PTR(cR);
-#else
         Q_CHECK_PTR(cR);
-#endif
         cR->addGroup( e.attribute("name") );
       }
       else if (s == "Expression") {
@@ -858,11 +851,7 @@ void KScoringManager::createInternalFromXML(QDomNode n)
                                                  e.attribute("neg")));
       }
       else if (s == "Action") {
-#if QT_VERSION < 290
-        CHECK_PTR(cR);
-#else
         Q_CHECK_PTR(cR);
-#endif
         cR->addAction(ActionBase::getTypeForName(e.attribute("type")),
                       e.attribute("value"));
       }
@@ -948,10 +937,9 @@ void KScoringManager::setRuleName(KScoringRule *r, const QString& s)
     for (; it.current(); ++it) {
       if ( it.current() != r && it.current()->getName() == text ) {
         kdDebug(5100) << "rule name " << text << " is not uniq" << endl;
-        KLineEditDlg dlg(i18n("the rule name is already assigned, please choose another name"),
-                         text,0);
-        dlg.show();
-        text = dlg.text();
+	text = KLineEditDlg::getText(
+			i18n("the rule name is already assigned, please choose another name"),
+			text,0,0);
         cont = true;
         break;
       }
