@@ -20,20 +20,9 @@
 #include <unistd.h>
 
 #include <qglobal.h>
-#if QT_VERSION >= 290
-#  include <qptrlist.h>
-#  include <qptrstack.h>
-#  include <qregexp.h>
-#  define QRegExp3 QRegExp
-#else
-// remove this after Qt3 becomes mandatory
-#  include <qregexp3.h>
-#  include <qstack.h>
-#  include <qlist.h>
-#  define QPtrList QList
-#  define QPtrListIterator QListIterator
-#  define QPtrStack QStack
-#endif
+#include <qptrlist.h>
+#include <qptrstack.h>
+#include <qregexp.h>
 
 #include <qobject.h>
 #include <qstring.h>
@@ -204,7 +193,7 @@ class KScoringExpression
   QString header;
   const char* c_header;
   Condition cond;
-  QRegExp3 expr;
+  QRegExp expr;
   QString expr_str;
   int expr_int;
 };
