@@ -3,8 +3,8 @@
 // Contents:   Function definitions for content transfer encodings
 // Maintainer: Doug Sauder <dwsauder@fwb.gulf.net>
 // WWW:        http://www.fwb.gulf.net/~dwsauder/mimepp.html
-// $Revision: 1.6.14.1 $
-// $Date: 2002/08/05 22:21:23 $
+// $Revision: 1.8 $
+// $Date: 2002/08/03 14:14:40 $
 //
 // Copyright (c) 1996, 1997 Douglas W. Sauder
 // All rights reserved.
@@ -420,7 +420,7 @@ static int encode_base64(const char* aIn, size_t aInLen, char* aOut,
         out[outPos++] = base64tab[c3 & 0x3F];
 		lineLen += 4;
         if (lineLen >= MAXLINE-3) {
-			char* cp = DW_EOL;
+			const char* cp = DW_EOL;
             out[outPos++] = *cp++;
 			if (*cp) {
 				out[outPos++] = *cp;
@@ -429,7 +429,7 @@ static int encode_base64(const char* aIn, size_t aInLen, char* aOut,
         }
     }
     /* Encode the remaining one or two characters. */
-	char* cp;
+	const char* cp;
     switch (inLen % 3) {
     case 0:
 		cp = DW_EOL;
