@@ -3,8 +3,8 @@
 // Contents:   Definitions for DwEntity
 // Maintainer: Doug Sauder <dwsauder@fwb.gulf.net>
 // WWW:        http://www.fwb.gulf.net/~dwsauder/mimepp.html
-// $Revision: 1.13 $
-// $Date: 2001/12/25 14:34:36 $
+// $Revision: 1.18.6.1 $
+// $Date: 2003/07/28 21:31:48 $
 //
 // Copyright (c) 1996, 1997 Douglas W. Sauder
 // All rights reserved.
@@ -27,6 +27,7 @@
 #include <mimelib/config.h>
 #include <mimelib/debug.h>
 #include <mimelib/string.h>
+#include <mimelib/enum.h>
 #include <mimelib/entity.h>
 #include <mimelib/headers.h>
 #include <mimelib/body.h>
@@ -75,7 +76,7 @@ void DwEntityParser::Parse()
                     break;
                 }
                 // Check for LF LF
-                else if (pos < bufEnd && buf[pos+1] == '\n') {
+                else if (pos+1 < bufEnd && buf[pos+1] == '\n') {
                     break;
                 }
                 lineStart = pos;
@@ -228,13 +229,10 @@ void DwEntity::Parse()
 }
 
 
-void DwEntity::Assemble()
+void DwEntity::Assemble(DwHeaders& aHeaders, DwBody& aBody)
 {
-    if (!mIsModified) return;
-    mBody->Assemble();
-    mHeaders->Assemble();
     mString = "";
-    mString += mHeaders->AsString();
+    mString += aHeaders.AsString();
 
     int len = mString.length();
 #if defined(DW_EOL_CRLF)
@@ -243,15 +241,40 @@ void DwEntity::Assemble()
     if (len>=2 && (mString[len-1]!='\n' || mString[len-2]!='\n'))
 #endif
     {
-      mString += DW_EOL;
+        if ( (mString[len-1] == '\n') &&
+             mHeaders->HasContentType() &&
+             (mHeaders->ContentType().Type()    == DwMime::kTypeMultipart) )
+        {
+            /* this is the case when we should not add an DW_EOL since
+               another newline is already added by DwBody::Assemble()
+               right before a boundary string.
+               Why is this bad for multipart-mixed? Well, multipart-
+               mixed can be part of a multipart-signed and an additional
+               empty line makes the mail invalid for a verification
+               (the signature was computed based on the same content,
+               but with a single newline).
+            */
+        }
+        else
+            mString += DW_EOL;
     }
-    mString += mBody->AsString();
+    mString += aBody.AsString();
     mIsModified = 0;
 }
 
 
+void DwEntity::Assemble()
+{
+    if (!mIsModified) return;
+    mBody->Assemble();
+    mHeaders->Assemble();
+    Assemble( *mHeaders, *mBody );
+}
+
+
 DwHeaders& DwEntity::Headers() const
 {
+    ASSERT(mHeaders != 0);
     return *mHeaders;
 }
 
